Cython: message_faster.pyx

Generated by Cython 3.0.9

Yellow lines hint at Python interaction.
Click on a line that starts with a "`+`" to see the C code that Cython generated for it.

Raw output: message_faster.c

    +001: from datetime import datetime as dt

      __pyx_t_7 = PyList_New(1); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 1, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_7);
      __Pyx_INCREF(__pyx_n_s_datetime);
      __Pyx_GIVEREF(__pyx_n_s_datetime);
      if (__Pyx_PyList_SET_ITEM(__pyx_t_7, 0, __pyx_n_s_datetime)) __PYX_ERR(0, 1, __pyx_L1_error);
      __pyx_t_4 = __Pyx_Import(__pyx_n_s_datetime, __pyx_t_7, 0); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 1, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_4);
      __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
      __pyx_t_7 = __Pyx_ImportFrom(__pyx_t_4, __pyx_n_s_datetime); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 1, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_7);
      if (PyDict_SetItem(__pyx_d, __pyx_n_s_dt, __pyx_t_7) < 0) __PYX_ERR(0, 1, __pyx_L1_error)
      __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
      __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
    /* … */
      __pyx_t_7 = __Pyx_PyDict_NewPresized(0); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 1, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_7);
      if (PyDict_SetItem(__pyx_d, __pyx_n_s_test, __pyx_t_7) < 0) __PYX_ERR(0, 1, __pyx_L1_error)
      __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;

    +002: from datetime import timezone

      __pyx_t_4 = PyList_New(1); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 2, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_4);
      __Pyx_INCREF(__pyx_n_s_timezone);
      __Pyx_GIVEREF(__pyx_n_s_timezone);
      if (__Pyx_PyList_SET_ITEM(__pyx_t_4, 0, __pyx_n_s_timezone)) __PYX_ERR(0, 2, __pyx_L1_error);
      __pyx_t_7 = __Pyx_Import(__pyx_n_s_datetime, __pyx_t_4, 0); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 2, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_7);
      __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
      __pyx_t_4 = __Pyx_ImportFrom(__pyx_t_7, __pyx_n_s_timezone); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 2, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_4);
      if (PyDict_SetItem(__pyx_d, __pyx_n_s_timezone, __pyx_t_4) < 0) __PYX_ERR(0, 2, __pyx_L1_error)
      __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
      __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;

     003:

     004: import cython

     005:

     006: from libc.stdint cimport (int8_t, int16_t, int32_t, int64_t, uint8_t, uint16_t,

     007:                           uint32_t, uint64_t)

     008: from libc.stdlib cimport free, malloc

     009: from libc.string cimport memcpy

     010: from libc.time cimport gmtime_r, time, time_t, tm

     011:

     012: DEF DESCRIBED_FORMAT_CODE_SIZE = 3

     013:

     014:

     015: @cython.no_gc_clear

     016: @cython.final

     017: @cython.freelist(1000)

    +018: cdef class Message:

    struct __pyx_obj_19amqp10_codec_faster_14message_faster_Message {
      PyObject_HEAD
      struct __pyx_vtabstruct_19amqp10_codec_faster_14message_faster_Message *__pyx_vtab;
      PyObject *body;
      PyObject *application_properties;
      PyObject *properties;
      PyObject *amqp_value;
      PyObject *header;
      PyObject *annotations;
    };
    /* … */
    struct __pyx_vtabstruct_19amqp10_codec_faster_14message_faster_Message {
      struct __pyx_obj_19amqp10_codec_faster_14message_faster_Message *(*unmarshal_c)(struct __pyx_obj_19amqp10_codec_faster_14message_faster_Message *, __Pyx_memviewslice, int __pyx_skip_dispatch);
      __Pyx_memviewslice (*marshal_c)(struct __pyx_obj_19amqp10_codec_faster_14message_faster_Message *, int __pyx_skip_dispatch);
    };
    static struct __pyx_vtabstruct_19amqp10_codec_faster_14message_faster_Message *__pyx_vtabptr_19amqp10_codec_faster_14message_faster_Message;
    static struct __pyx_obj_19amqp10_codec_faster_14message_faster_Message *__pyx_f_19amqp10_codec_faster_14message_faster_7Message_unmarshal_c(struct __pyx_obj_19amqp10_codec_faster_14message_faster_Message *, __Pyx_memviewslice, int __pyx_skip_dispatch);
    static __Pyx_memviewslice __pyx_f_19amqp10_codec_faster_14message_faster_7Message_marshal_c(struct __pyx_obj_19amqp10_codec_faster_14message_faster_Message *, int __pyx_skip_dispatch);

     019:     cdef:

    +020:         public object body

    /* Python wrapper */
    static PyObject *__pyx_pw_19amqp10_codec_faster_14message_faster_7Message_4body_1__get__(PyObject *__pyx_v_self); /*proto*/
    static PyObject *__pyx_pw_19amqp10_codec_faster_14message_faster_7Message_4body_1__get__(PyObject *__pyx_v_self) {
      CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
      PyObject *__pyx_r = 0;
      __Pyx_RefNannyDeclarations
      __Pyx_RefNannySetupContext("__get__ (wrapper)", 0);
      __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
      __pyx_r = __pyx_pf_19amqp10_codec_faster_14message_faster_7Message_4body___get__(((struct __pyx_obj_19amqp10_codec_faster_14message_faster_Message *)__pyx_v_self));

      /* function exit code */
      __Pyx_RefNannyFinishContext();
      return __pyx_r;
    }

    static PyObject *__pyx_pf_19amqp10_codec_faster_14message_faster_7Message_4body___get__(struct __pyx_obj_19amqp10_codec_faster_14message_faster_Message *__pyx_v_self) {
      PyObject *__pyx_r = NULL;
      __Pyx_XDECREF(__pyx_r);
      __Pyx_INCREF(__pyx_v_self->body);
      __pyx_r = __pyx_v_self->body;
      goto __pyx_L0;

      /* function exit code */
      __pyx_L0:;
      __Pyx_XGIVEREF(__pyx_r);
      __Pyx_RefNannyFinishContext();
      return __pyx_r;
    }

    /* Python wrapper */
    static int __pyx_pw_19amqp10_codec_faster_14message_faster_7Message_4body_3__set__(PyObject *__pyx_v_self, PyObject *__pyx_v_value); /*proto*/
    static int __pyx_pw_19amqp10_codec_faster_14message_faster_7Message_4body_3__set__(PyObject *__pyx_v_self, PyObject *__pyx_v_value) {
      CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
      int __pyx_r;
      __Pyx_RefNannyDeclarations
      __Pyx_RefNannySetupContext("__set__ (wrapper)", 0);
      __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
      __pyx_r = __pyx_pf_19amqp10_codec_faster_14message_faster_7Message_4body_2__set__(((struct __pyx_obj_19amqp10_codec_faster_14message_faster_Message *)__pyx_v_self), ((PyObject *)__pyx_v_value));

      /* function exit code */
      __Pyx_RefNannyFinishContext();
      return __pyx_r;
    }

    static int __pyx_pf_19amqp10_codec_faster_14message_faster_7Message_4body_2__set__(struct __pyx_obj_19amqp10_codec_faster_14message_faster_Message *__pyx_v_self, PyObject *__pyx_v_value) {
      int __pyx_r;
      __Pyx_INCREF(__pyx_v_value);
      __Pyx_GIVEREF(__pyx_v_value);
      __Pyx_GOTREF(__pyx_v_self->body);
      __Pyx_DECREF(__pyx_v_self->body);
      __pyx_v_self->body = __pyx_v_value;

      /* function exit code */
      __pyx_r = 0;
      __Pyx_RefNannyFinishContext();
      return __pyx_r;
    }

    /* Python wrapper */
    static int __pyx_pw_19amqp10_codec_faster_14message_faster_7Message_4body_5__del__(PyObject *__pyx_v_self); /*proto*/
    static int __pyx_pw_19amqp10_codec_faster_14message_faster_7Message_4body_5__del__(PyObject *__pyx_v_self) {
      CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
      int __pyx_r;
      __Pyx_RefNannyDeclarations
      __Pyx_RefNannySetupContext("__del__ (wrapper)", 0);
      __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
      __pyx_r = __pyx_pf_19amqp10_codec_faster_14message_faster_7Message_4body_4__del__(((struct __pyx_obj_19amqp10_codec_faster_14message_faster_Message *)__pyx_v_self));

      /* function exit code */
      __Pyx_RefNannyFinishContext();
      return __pyx_r;
    }

    static int __pyx_pf_19amqp10_codec_faster_14message_faster_7Message_4body_4__del__(struct __pyx_obj_19amqp10_codec_faster_14message_faster_Message *__pyx_v_self) {
      int __pyx_r;
      __Pyx_INCREF(Py_None);
      __Pyx_GIVEREF(Py_None);
      __Pyx_GOTREF(__pyx_v_self->body);
      __Pyx_DECREF(__pyx_v_self->body);
      __pyx_v_self->body = Py_None;

      /* function exit code */
      __pyx_r = 0;
      __Pyx_RefNannyFinishContext();
      return __pyx_r;
    }

    +021:         public object application_properties

    /* Python wrapper */
    static PyObject *__pyx_pw_19amqp10_codec_faster_14message_faster_7Message_22application_properties_1__get__(PyObject *__pyx_v_self); /*proto*/
    static PyObject *__pyx_pw_19amqp10_codec_faster_14message_faster_7Message_22application_properties_1__get__(PyObject *__pyx_v_self) {
      CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
      PyObject *__pyx_r = 0;
      __Pyx_RefNannyDeclarations
      __Pyx_RefNannySetupContext("__get__ (wrapper)", 0);
      __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
      __pyx_r = __pyx_pf_19amqp10_codec_faster_14message_faster_7Message_22application_properties___get__(((struct __pyx_obj_19amqp10_codec_faster_14message_faster_Message *)__pyx_v_self));

      /* function exit code */
      __Pyx_RefNannyFinishContext();
      return __pyx_r;
    }

    static PyObject *__pyx_pf_19amqp10_codec_faster_14message_faster_7Message_22application_properties___get__(struct __pyx_obj_19amqp10_codec_faster_14message_faster_Message *__pyx_v_self) {
      PyObject *__pyx_r = NULL;
      __Pyx_XDECREF(__pyx_r);
      __Pyx_INCREF(__pyx_v_self->application_properties);
      __pyx_r = __pyx_v_self->application_properties;
      goto __pyx_L0;

      /* function exit code */
      __pyx_L0:;
      __Pyx_XGIVEREF(__pyx_r);
      __Pyx_RefNannyFinishContext();
      return __pyx_r;
    }

    /* Python wrapper */
    static int __pyx_pw_19amqp10_codec_faster_14message_faster_7Message_22application_properties_3__set__(PyObject *__pyx_v_self, PyObject *__pyx_v_value); /*proto*/
    static int __pyx_pw_19amqp10_codec_faster_14message_faster_7Message_22application_properties_3__set__(PyObject *__pyx_v_self, PyObject *__pyx_v_value) {
      CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
      int __pyx_r;
      __Pyx_RefNannyDeclarations
      __Pyx_RefNannySetupContext("__set__ (wrapper)", 0);
      __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
      __pyx_r = __pyx_pf_19amqp10_codec_faster_14message_faster_7Message_22application_properties_2__set__(((struct __pyx_obj_19amqp10_codec_faster_14message_faster_Message *)__pyx_v_self), ((PyObject *)__pyx_v_value));

      /* function exit code */
      __Pyx_RefNannyFinishContext();
      return __pyx_r;
    }

    static int __pyx_pf_19amqp10_codec_faster_14message_faster_7Message_22application_properties_2__set__(struct __pyx_obj_19amqp10_codec_faster_14message_faster_Message *__pyx_v_self, PyObject *__pyx_v_value) {
      int __pyx_r;
      __Pyx_INCREF(__pyx_v_value);
      __Pyx_GIVEREF(__pyx_v_value);
      __Pyx_GOTREF(__pyx_v_self->application_properties);
      __Pyx_DECREF(__pyx_v_self->application_properties);
      __pyx_v_self->application_properties = __pyx_v_value;

      /* function exit code */
      __pyx_r = 0;
      __Pyx_RefNannyFinishContext();
      return __pyx_r;
    }

    /* Python wrapper */
    static int __pyx_pw_19amqp10_codec_faster_14message_faster_7Message_22application_properties_5__del__(PyObject *__pyx_v_self); /*proto*/
    static int __pyx_pw_19amqp10_codec_faster_14message_faster_7Message_22application_properties_5__del__(PyObject *__pyx_v_self) {
      CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
      int __pyx_r;
      __Pyx_RefNannyDeclarations
      __Pyx_RefNannySetupContext("__del__ (wrapper)", 0);
      __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
      __pyx_r = __pyx_pf_19amqp10_codec_faster_14message_faster_7Message_22application_properties_4__del__(((struct __pyx_obj_19amqp10_codec_faster_14message_faster_Message *)__pyx_v_self));

      /* function exit code */
      __Pyx_RefNannyFinishContext();
      return __pyx_r;
    }

    static int __pyx_pf_19amqp10_codec_faster_14message_faster_7Message_22application_properties_4__del__(struct __pyx_obj_19amqp10_codec_faster_14message_faster_Message *__pyx_v_self) {
      int __pyx_r;
      __Pyx_INCREF(Py_None);
      __Pyx_GIVEREF(Py_None);
      __Pyx_GOTREF(__pyx_v_self->application_properties);
      __Pyx_DECREF(__pyx_v_self->application_properties);
      __pyx_v_self->application_properties = Py_None;

      /* function exit code */
      __pyx_r = 0;
      __Pyx_RefNannyFinishContext();
      return __pyx_r;
    }

    +022:         public object properties

    /* Python wrapper */
    static PyObject *__pyx_pw_19amqp10_codec_faster_14message_faster_7Message_10properties_1__get__(PyObject *__pyx_v_self); /*proto*/
    static PyObject *__pyx_pw_19amqp10_codec_faster_14message_faster_7Message_10properties_1__get__(PyObject *__pyx_v_self) {
      CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
      PyObject *__pyx_r = 0;
      __Pyx_RefNannyDeclarations
      __Pyx_RefNannySetupContext("__get__ (wrapper)", 0);
      __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
      __pyx_r = __pyx_pf_19amqp10_codec_faster_14message_faster_7Message_10properties___get__(((struct __pyx_obj_19amqp10_codec_faster_14message_faster_Message *)__pyx_v_self));

      /* function exit code */
      __Pyx_RefNannyFinishContext();
      return __pyx_r;
    }

    static PyObject *__pyx_pf_19amqp10_codec_faster_14message_faster_7Message_10properties___get__(struct __pyx_obj_19amqp10_codec_faster_14message_faster_Message *__pyx_v_self) {
      PyObject *__pyx_r = NULL;
      __Pyx_XDECREF(__pyx_r);
      __Pyx_INCREF(__pyx_v_self->properties);
      __pyx_r = __pyx_v_self->properties;
      goto __pyx_L0;

      /* function exit code */
      __pyx_L0:;
      __Pyx_XGIVEREF(__pyx_r);
      __Pyx_RefNannyFinishContext();
      return __pyx_r;
    }

    /* Python wrapper */
    static int __pyx_pw_19amqp10_codec_faster_14message_faster_7Message_10properties_3__set__(PyObject *__pyx_v_self, PyObject *__pyx_v_value); /*proto*/
    static int __pyx_pw_19amqp10_codec_faster_14message_faster_7Message_10properties_3__set__(PyObject *__pyx_v_self, PyObject *__pyx_v_value) {
      CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
      int __pyx_r;
      __Pyx_RefNannyDeclarations
      __Pyx_RefNannySetupContext("__set__ (wrapper)", 0);
      __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
      __pyx_r = __pyx_pf_19amqp10_codec_faster_14message_faster_7Message_10properties_2__set__(((struct __pyx_obj_19amqp10_codec_faster_14message_faster_Message *)__pyx_v_self), ((PyObject *)__pyx_v_value));

      /* function exit code */
      __Pyx_RefNannyFinishContext();
      return __pyx_r;
    }

    static int __pyx_pf_19amqp10_codec_faster_14message_faster_7Message_10properties_2__set__(struct __pyx_obj_19amqp10_codec_faster_14message_faster_Message *__pyx_v_self, PyObject *__pyx_v_value) {
      int __pyx_r;
      __Pyx_INCREF(__pyx_v_value);
      __Pyx_GIVEREF(__pyx_v_value);
      __Pyx_GOTREF(__pyx_v_self->properties);
      __Pyx_DECREF(__pyx_v_self->properties);
      __pyx_v_self->properties = __pyx_v_value;

      /* function exit code */
      __pyx_r = 0;
      __Pyx_RefNannyFinishContext();
      return __pyx_r;
    }

    /* Python wrapper */
    static int __pyx_pw_19amqp10_codec_faster_14message_faster_7Message_10properties_5__del__(PyObject *__pyx_v_self); /*proto*/
    static int __pyx_pw_19amqp10_codec_faster_14message_faster_7Message_10properties_5__del__(PyObject *__pyx_v_self) {
      CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
      int __pyx_r;
      __Pyx_RefNannyDeclarations
      __Pyx_RefNannySetupContext("__del__ (wrapper)", 0);
      __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
      __pyx_r = __pyx_pf_19amqp10_codec_faster_14message_faster_7Message_10properties_4__del__(((struct __pyx_obj_19amqp10_codec_faster_14message_faster_Message *)__pyx_v_self));

      /* function exit code */
      __Pyx_RefNannyFinishContext();
      return __pyx_r;
    }

    static int __pyx_pf_19amqp10_codec_faster_14message_faster_7Message_10properties_4__del__(struct __pyx_obj_19amqp10_codec_faster_14message_faster_Message *__pyx_v_self) {
      int __pyx_r;
      __Pyx_INCREF(Py_None);
      __Pyx_GIVEREF(Py_None);
      __Pyx_GOTREF(__pyx_v_self->properties);
      __Pyx_DECREF(__pyx_v_self->properties);
      __pyx_v_self->properties = Py_None;

      /* function exit code */
      __pyx_r = 0;
      __Pyx_RefNannyFinishContext();
      return __pyx_r;
    }

    +023:         public object amqp_value

    /* Python wrapper */
    static PyObject *__pyx_pw_19amqp10_codec_faster_14message_faster_7Message_10amqp_value_1__get__(PyObject *__pyx_v_self); /*proto*/
    static PyObject *__pyx_pw_19amqp10_codec_faster_14message_faster_7Message_10amqp_value_1__get__(PyObject *__pyx_v_self) {
      CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
      PyObject *__pyx_r = 0;
      __Pyx_RefNannyDeclarations
      __Pyx_RefNannySetupContext("__get__ (wrapper)", 0);
      __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
      __pyx_r = __pyx_pf_19amqp10_codec_faster_14message_faster_7Message_10amqp_value___get__(((struct __pyx_obj_19amqp10_codec_faster_14message_faster_Message *)__pyx_v_self));

      /* function exit code */
      __Pyx_RefNannyFinishContext();
      return __pyx_r;
    }

    static PyObject *__pyx_pf_19amqp10_codec_faster_14message_faster_7Message_10amqp_value___get__(struct __pyx_obj_19amqp10_codec_faster_14message_faster_Message *__pyx_v_self) {
      PyObject *__pyx_r = NULL;
      __Pyx_XDECREF(__pyx_r);
      __Pyx_INCREF(__pyx_v_self->amqp_value);
      __pyx_r = __pyx_v_self->amqp_value;
      goto __pyx_L0;

      /* function exit code */
      __pyx_L0:;
      __Pyx_XGIVEREF(__pyx_r);
      __Pyx_RefNannyFinishContext();
      return __pyx_r;
    }

    /* Python wrapper */
    static int __pyx_pw_19amqp10_codec_faster_14message_faster_7Message_10amqp_value_3__set__(PyObject *__pyx_v_self, PyObject *__pyx_v_value); /*proto*/
    static int __pyx_pw_19amqp10_codec_faster_14message_faster_7Message_10amqp_value_3__set__(PyObject *__pyx_v_self, PyObject *__pyx_v_value) {
      CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
      int __pyx_r;
      __Pyx_RefNannyDeclarations
      __Pyx_RefNannySetupContext("__set__ (wrapper)", 0);
      __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
      __pyx_r = __pyx_pf_19amqp10_codec_faster_14message_faster_7Message_10amqp_value_2__set__(((struct __pyx_obj_19amqp10_codec_faster_14message_faster_Message *)__pyx_v_self), ((PyObject *)__pyx_v_value));

      /* function exit code */
      __Pyx_RefNannyFinishContext();
      return __pyx_r;
    }

    static int __pyx_pf_19amqp10_codec_faster_14message_faster_7Message_10amqp_value_2__set__(struct __pyx_obj_19amqp10_codec_faster_14message_faster_Message *__pyx_v_self, PyObject *__pyx_v_value) {
      int __pyx_r;
      __Pyx_INCREF(__pyx_v_value);
      __Pyx_GIVEREF(__pyx_v_value);
      __Pyx_GOTREF(__pyx_v_self->amqp_value);
      __Pyx_DECREF(__pyx_v_self->amqp_value);
      __pyx_v_self->amqp_value = __pyx_v_value;

      /* function exit code */
      __pyx_r = 0;
      __Pyx_RefNannyFinishContext();
      return __pyx_r;
    }

    /* Python wrapper */
    static int __pyx_pw_19amqp10_codec_faster_14message_faster_7Message_10amqp_value_5__del__(PyObject *__pyx_v_self); /*proto*/
    static int __pyx_pw_19amqp10_codec_faster_14message_faster_7Message_10amqp_value_5__del__(PyObject *__pyx_v_self) {
      CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
      int __pyx_r;
      __Pyx_RefNannyDeclarations
      __Pyx_RefNannySetupContext("__del__ (wrapper)", 0);
      __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
      __pyx_r = __pyx_pf_19amqp10_codec_faster_14message_faster_7Message_10amqp_value_4__del__(((struct __pyx_obj_19amqp10_codec_faster_14message_faster_Message *)__pyx_v_self));

      /* function exit code */
      __Pyx_RefNannyFinishContext();
      return __pyx_r;
    }

    static int __pyx_pf_19amqp10_codec_faster_14message_faster_7Message_10amqp_value_4__del__(struct __pyx_obj_19amqp10_codec_faster_14message_faster_Message *__pyx_v_self) {
      int __pyx_r;
      __Pyx_INCREF(Py_None);
      __Pyx_GIVEREF(Py_None);
      __Pyx_GOTREF(__pyx_v_self->amqp_value);
      __Pyx_DECREF(__pyx_v_self->amqp_value);
      __pyx_v_self->amqp_value = Py_None;

      /* function exit code */
      __pyx_r = 0;
      __Pyx_RefNannyFinishContext();
      return __pyx_r;
    }

    +024:         public object header

    /* Python wrapper */
    static PyObject *__pyx_pw_19amqp10_codec_faster_14message_faster_7Message_6header_1__get__(PyObject *__pyx_v_self); /*proto*/
    static PyObject *__pyx_pw_19amqp10_codec_faster_14message_faster_7Message_6header_1__get__(PyObject *__pyx_v_self) {
      CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
      PyObject *__pyx_r = 0;
      __Pyx_RefNannyDeclarations
      __Pyx_RefNannySetupContext("__get__ (wrapper)", 0);
      __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
      __pyx_r = __pyx_pf_19amqp10_codec_faster_14message_faster_7Message_6header___get__(((struct __pyx_obj_19amqp10_codec_faster_14message_faster_Message *)__pyx_v_self));

      /* function exit code */
      __Pyx_RefNannyFinishContext();
      return __pyx_r;
    }

    static PyObject *__pyx_pf_19amqp10_codec_faster_14message_faster_7Message_6header___get__(struct __pyx_obj_19amqp10_codec_faster_14message_faster_Message *__pyx_v_self) {
      PyObject *__pyx_r = NULL;
      __Pyx_XDECREF(__pyx_r);
      __Pyx_INCREF(__pyx_v_self->header);
      __pyx_r = __pyx_v_self->header;
      goto __pyx_L0;

      /* function exit code */
      __pyx_L0:;
      __Pyx_XGIVEREF(__pyx_r);
      __Pyx_RefNannyFinishContext();
      return __pyx_r;
    }

    /* Python wrapper */
    static int __pyx_pw_19amqp10_codec_faster_14message_faster_7Message_6header_3__set__(PyObject *__pyx_v_self, PyObject *__pyx_v_value); /*proto*/
    static int __pyx_pw_19amqp10_codec_faster_14message_faster_7Message_6header_3__set__(PyObject *__pyx_v_self, PyObject *__pyx_v_value) {
      CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
      int __pyx_r;
      __Pyx_RefNannyDeclarations
      __Pyx_RefNannySetupContext("__set__ (wrapper)", 0);
      __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
      __pyx_r = __pyx_pf_19amqp10_codec_faster_14message_faster_7Message_6header_2__set__(((struct __pyx_obj_19amqp10_codec_faster_14message_faster_Message *)__pyx_v_self), ((PyObject *)__pyx_v_value));

      /* function exit code */
      __Pyx_RefNannyFinishContext();
      return __pyx_r;
    }

    static int __pyx_pf_19amqp10_codec_faster_14message_faster_7Message_6header_2__set__(struct __pyx_obj_19amqp10_codec_faster_14message_faster_Message *__pyx_v_self, PyObject *__pyx_v_value) {
      int __pyx_r;
      __Pyx_INCREF(__pyx_v_value);
      __Pyx_GIVEREF(__pyx_v_value);
      __Pyx_GOTREF(__pyx_v_self->header);
      __Pyx_DECREF(__pyx_v_self->header);
      __pyx_v_self->header = __pyx_v_value;

      /* function exit code */
      __pyx_r = 0;
      __Pyx_RefNannyFinishContext();
      return __pyx_r;
    }

    /* Python wrapper */
    static int __pyx_pw_19amqp10_codec_faster_14message_faster_7Message_6header_5__del__(PyObject *__pyx_v_self); /*proto*/
    static int __pyx_pw_19amqp10_codec_faster_14message_faster_7Message_6header_5__del__(PyObject *__pyx_v_self) {
      CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
      int __pyx_r;
      __Pyx_RefNannyDeclarations
      __Pyx_RefNannySetupContext("__del__ (wrapper)", 0);
      __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
      __pyx_r = __pyx_pf_19amqp10_codec_faster_14message_faster_7Message_6header_4__del__(((struct __pyx_obj_19amqp10_codec_faster_14message_faster_Message *)__pyx_v_self));

      /* function exit code */
      __Pyx_RefNannyFinishContext();
      return __pyx_r;
    }

    static int __pyx_pf_19amqp10_codec_faster_14message_faster_7Message_6header_4__del__(struct __pyx_obj_19amqp10_codec_faster_14message_faster_Message *__pyx_v_self) {
      int __pyx_r;
      __Pyx_INCREF(Py_None);
      __Pyx_GIVEREF(Py_None);
      __Pyx_GOTREF(__pyx_v_self->header);
      __Pyx_DECREF(__pyx_v_self->header);
      __pyx_v_self->header = Py_None;

      /* function exit code */
      __pyx_r = 0;
      __Pyx_RefNannyFinishContext();
      return __pyx_r;
    }

    +025:         public object annotations

    /* Python wrapper */
    static PyObject *__pyx_pw_19amqp10_codec_faster_14message_faster_7Message_11annotations_1__get__(PyObject *__pyx_v_self); /*proto*/
    static PyObject *__pyx_pw_19amqp10_codec_faster_14message_faster_7Message_11annotations_1__get__(PyObject *__pyx_v_self) {
      CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
      PyObject *__pyx_r = 0;
      __Pyx_RefNannyDeclarations
      __Pyx_RefNannySetupContext("__get__ (wrapper)", 0);
      __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
      __pyx_r = __pyx_pf_19amqp10_codec_faster_14message_faster_7Message_11annotations___get__(((struct __pyx_obj_19amqp10_codec_faster_14message_faster_Message *)__pyx_v_self));

      /* function exit code */
      __Pyx_RefNannyFinishContext();
      return __pyx_r;
    }

    static PyObject *__pyx_pf_19amqp10_codec_faster_14message_faster_7Message_11annotations___get__(struct __pyx_obj_19amqp10_codec_faster_14message_faster_Message *__pyx_v_self) {
      PyObject *__pyx_r = NULL;
      __Pyx_XDECREF(__pyx_r);
      __Pyx_INCREF(__pyx_v_self->annotations);
      __pyx_r = __pyx_v_self->annotations;
      goto __pyx_L0;

      /* function exit code */
      __pyx_L0:;
      __Pyx_XGIVEREF(__pyx_r);
      __Pyx_RefNannyFinishContext();
      return __pyx_r;
    }

    /* Python wrapper */
    static int __pyx_pw_19amqp10_codec_faster_14message_faster_7Message_11annotations_3__set__(PyObject *__pyx_v_self, PyObject *__pyx_v_value); /*proto*/
    static int __pyx_pw_19amqp10_codec_faster_14message_faster_7Message_11annotations_3__set__(PyObject *__pyx_v_self, PyObject *__pyx_v_value) {
      CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
      int __pyx_r;
      __Pyx_RefNannyDeclarations
      __Pyx_RefNannySetupContext("__set__ (wrapper)", 0);
      __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
      __pyx_r = __pyx_pf_19amqp10_codec_faster_14message_faster_7Message_11annotations_2__set__(((struct __pyx_obj_19amqp10_codec_faster_14message_faster_Message *)__pyx_v_self), ((PyObject *)__pyx_v_value));

      /* function exit code */
      __Pyx_RefNannyFinishContext();
      return __pyx_r;
    }

    static int __pyx_pf_19amqp10_codec_faster_14message_faster_7Message_11annotations_2__set__(struct __pyx_obj_19amqp10_codec_faster_14message_faster_Message *__pyx_v_self, PyObject *__pyx_v_value) {
      int __pyx_r;
      __Pyx_INCREF(__pyx_v_value);
      __Pyx_GIVEREF(__pyx_v_value);
      __Pyx_GOTREF(__pyx_v_self->annotations);
      __Pyx_DECREF(__pyx_v_self->annotations);
      __pyx_v_self->annotations = __pyx_v_value;

      /* function exit code */
      __pyx_r = 0;
      __Pyx_RefNannyFinishContext();
      return __pyx_r;
    }

    /* Python wrapper */
    static int __pyx_pw_19amqp10_codec_faster_14message_faster_7Message_11annotations_5__del__(PyObject *__pyx_v_self); /*proto*/
    static int __pyx_pw_19amqp10_codec_faster_14message_faster_7Message_11annotations_5__del__(PyObject *__pyx_v_self) {
      CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
      int __pyx_r;
      __Pyx_RefNannyDeclarations
      __Pyx_RefNannySetupContext("__del__ (wrapper)", 0);
      __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
      __pyx_r = __pyx_pf_19amqp10_codec_faster_14message_faster_7Message_11annotations_4__del__(((struct __pyx_obj_19amqp10_codec_faster_14message_faster_Message *)__pyx_v_self));

      /* function exit code */
      __Pyx_RefNannyFinishContext();
      return __pyx_r;
    }

    static int __pyx_pf_19amqp10_codec_faster_14message_faster_7Message_11annotations_4__del__(struct __pyx_obj_19amqp10_codec_faster_14message_faster_Message *__pyx_v_self) {
      int __pyx_r;
      __Pyx_INCREF(Py_None);
      __Pyx_GIVEREF(Py_None);
      __Pyx_GOTREF(__pyx_v_self->annotations);
      __Pyx_DECREF(__pyx_v_self->annotations);
      __pyx_v_self->annotations = Py_None;

      /* function exit code */
      __pyx_r = 0;
      __Pyx_RefNannyFinishContext();
      return __pyx_r;
    }

     026:

    +027:     def __init__(self):

    /* Python wrapper */
    static int __pyx_pw_19amqp10_codec_faster_14message_faster_7Message_1__init__(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
    static int __pyx_pw_19amqp10_codec_faster_14message_faster_7Message_1__init__(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
      CYTHON_UNUSED Py_ssize_t __pyx_nargs;
      CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
      int __pyx_r;
      __Pyx_RefNannyDeclarations
      __Pyx_RefNannySetupContext("__init__ (wrapper)", 0);
      #if CYTHON_ASSUME_SAFE_MACROS
      __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
      #else
      __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return -1;
      #endif
      __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
      if (unlikely(__pyx_nargs > 0)) {
        __Pyx_RaiseArgtupleInvalid("__init__", 1, 0, 0, __pyx_nargs); return -1;}
      if (unlikely(__pyx_kwds) && __Pyx_NumKwargs_VARARGS(__pyx_kwds) && unlikely(!__Pyx_CheckKeywordStrings(__pyx_kwds, "__init__", 0))) return -1;
      __pyx_r = __pyx_pf_19amqp10_codec_faster_14message_faster_7Message___init__(((struct __pyx_obj_19amqp10_codec_faster_14message_faster_Message *)__pyx_v_self));

      /* function exit code */
      __Pyx_RefNannyFinishContext();
      return __pyx_r;
    }

    static int __pyx_pf_19amqp10_codec_faster_14message_faster_7Message___init__(struct __pyx_obj_19amqp10_codec_faster_14message_faster_Message *__pyx_v_self) {
      int __pyx_r;
    /* … */
      /* function exit code */
      __pyx_r = 0;
      __Pyx_RefNannyFinishContext();
      return __pyx_r;
    }

    +028:         self.body = None

      __Pyx_INCREF(Py_None);
      __Pyx_GIVEREF(Py_None);
      __Pyx_GOTREF(__pyx_v_self->body);
      __Pyx_DECREF(__pyx_v_self->body);
      __pyx_v_self->body = Py_None;

    +029:         self.header = None

      __Pyx_INCREF(Py_None);
      __Pyx_GIVEREF(Py_None);
      __Pyx_GOTREF(__pyx_v_self->header);
      __Pyx_DECREF(__pyx_v_self->header);
      __pyx_v_self->header = Py_None;

    +030:         self.application_properties = None

      __Pyx_INCREF(Py_None);
      __Pyx_GIVEREF(Py_None);
      __Pyx_GOTREF(__pyx_v_self->application_properties);
      __Pyx_DECREF(__pyx_v_self->application_properties);
      __pyx_v_self->application_properties = Py_None;

    +031:         self.amqp_value = None

      __Pyx_INCREF(Py_None);
      __Pyx_GIVEREF(Py_None);
      __Pyx_GOTREF(__pyx_v_self->amqp_value);
      __Pyx_DECREF(__pyx_v_self->amqp_value);
      __pyx_v_self->amqp_value = Py_None;

    +032:         self.properties = None

      __Pyx_INCREF(Py_None);
      __Pyx_GIVEREF(Py_None);
      __Pyx_GOTREF(__pyx_v_self->properties);
      __Pyx_DECREF(__pyx_v_self->properties);
      __pyx_v_self->properties = Py_None;

    +033:         self.annotations = None

      __Pyx_INCREF(Py_None);
      __Pyx_GIVEREF(Py_None);
      __Pyx_GOTREF(__pyx_v_self->annotations);
      __Pyx_DECREF(__pyx_v_self->annotations);
      __pyx_v_self->annotations = Py_None;

     034:

    +035:     cpdef Message unmarshal_c(self, unsigned char[:] buffer):

    static PyObject *__pyx_pw_19amqp10_codec_faster_14message_faster_7Message_3unmarshal_c(PyObject *__pyx_v_self,
    #if CYTHON_METH_FASTCALL
    PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
    #else
    PyObject *__pyx_args, PyObject *__pyx_kwds
    #endif
    ); /*proto*/
    static struct __pyx_obj_19amqp10_codec_faster_14message_faster_Message *__pyx_f_19amqp10_codec_faster_14message_faster_7Message_unmarshal_c(CYTHON_UNUSED struct __pyx_obj_19amqp10_codec_faster_14message_faster_Message *__pyx_v_self, __Pyx_memviewslice __pyx_v_buffer, CYTHON_UNUSED int __pyx_skip_dispatch) {
      struct __pyx_obj_19amqp10_codec_faster_14message_faster_Message *__pyx_v_msg = 0;
      Py_ssize_t __pyx_v_offset;
      Py_ssize_t __pyx_v_buffer_length;
      uint8_t __pyx_v_described_format_code;
      unsigned char *__pyx_v_buffer_p;
      struct __pyx_obj_19amqp10_codec_faster_14message_faster_Message *__pyx_r = NULL;
    /* … */
      /* function exit code */
      __pyx_L1_error:;
      __Pyx_XDECREF(__pyx_t_1);
      __Pyx_XDECREF(__pyx_t_4);
      __Pyx_AddTraceback("amqp10_codec_faster.message_faster.Message.unmarshal_c", __pyx_clineno, __pyx_lineno, __pyx_filename);
      __pyx_r = 0;
      __pyx_L0:;
      __Pyx_XDECREF((PyObject *)__pyx_v_msg);
      __Pyx_XGIVEREF((PyObject *)__pyx_r);
      __Pyx_RefNannyFinishContext();
      return __pyx_r;
    }

    /* Python wrapper */
    static PyObject *__pyx_pw_19amqp10_codec_faster_14message_faster_7Message_3unmarshal_c(PyObject *__pyx_v_self,
    #if CYTHON_METH_FASTCALL
    PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
    #else
    PyObject *__pyx_args, PyObject *__pyx_kwds
    #endif
    ); /*proto*/
    PyDoc_STRVAR(__pyx_doc_19amqp10_codec_faster_14message_faster_7Message_2unmarshal_c, "unmarshal_c(self, buffer: unsigned_char[:]) -> Message");
    static PyMethodDef __pyx_mdef_19amqp10_codec_faster_14message_faster_7Message_3unmarshal_c = {"unmarshal_c", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_19amqp10_codec_faster_14message_faster_7Message_3unmarshal_c, __Pyx_METH_FASTCALL|METH_KEYWORDS, __pyx_doc_19amqp10_codec_faster_14message_faster_7Message_2unmarshal_c};
    static PyObject *__pyx_pw_19amqp10_codec_faster_14message_faster_7Message_3unmarshal_c(PyObject *__pyx_v_self,
    #if CYTHON_METH_FASTCALL
    PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
    #else
    PyObject *__pyx_args, PyObject *__pyx_kwds
    #endif
    ) {
      __Pyx_memviewslice __pyx_v_buffer = { 0, 0, { 0 }, { 0 }, { 0 } };
      #if !CYTHON_METH_FASTCALL
      CYTHON_UNUSED Py_ssize_t __pyx_nargs;
      #endif
      CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
      PyObject *__pyx_r = 0;
      __Pyx_RefNannyDeclarations
      __Pyx_RefNannySetupContext("unmarshal_c (wrapper)", 0);
      #if !CYTHON_METH_FASTCALL
      #if CYTHON_ASSUME_SAFE_MACROS
      __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
      #else
      __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
      #endif
      #endif
      __pyx_kwvalues = __Pyx_KwValues_FASTCALL(__pyx_args, __pyx_nargs);
      {
        PyObject **__pyx_pyargnames[] = {&__pyx_n_s_buffer,0};
      PyObject* values[1] = {0};
        if (__pyx_kwds) {
          Py_ssize_t kw_args;
          switch (__pyx_nargs) {
            case  1: values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
            CYTHON_FALLTHROUGH;
            case  0: break;
            default: goto __pyx_L5_argtuple_error;
          }
          kw_args = __Pyx_NumKwargs_FASTCALL(__pyx_kwds);
          switch (__pyx_nargs) {
            case  0:
            if (likely((values[0] = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_buffer)) != 0)) {
              (void)__Pyx_Arg_NewRef_FASTCALL(values[0]);
              kw_args--;
            }
            else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 35, __pyx_L3_error)
            else goto __pyx_L5_argtuple_error;
          }
          if (unlikely(kw_args > 0)) {
            const Py_ssize_t kwd_pos_args = __pyx_nargs;
            if (unlikely(__Pyx_ParseOptionalKeywords(__pyx_kwds, __pyx_kwvalues, __pyx_pyargnames, 0, values + 0, kwd_pos_args, "unmarshal_c") < 0)) __PYX_ERR(0, 35, __pyx_L3_error)
          }
        } else if (unlikely(__pyx_nargs != 1)) {
          goto __pyx_L5_argtuple_error;
        } else {
          values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
        }
        __pyx_v_buffer = __Pyx_PyObject_to_MemoryviewSlice_ds_unsigned_char(values[0], PyBUF_WRITABLE); if (unlikely(!__pyx_v_buffer.memview)) __PYX_ERR(0, 35, __pyx_L3_error)
      }
      goto __pyx_L6_skip;
      __pyx_L5_argtuple_error:;
      __Pyx_RaiseArgtupleInvalid("unmarshal_c", 1, 1, 1, __pyx_nargs); __PYX_ERR(0, 35, __pyx_L3_error)
      __pyx_L6_skip:;
      goto __pyx_L4_argument_unpacking_done;
      __pyx_L3_error:;
      {
        Py_ssize_t __pyx_temp;
        for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
          __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
        }
      }
      __PYX_XCLEAR_MEMVIEW(&__pyx_v_buffer, 1);
      __Pyx_AddTraceback("amqp10_codec_faster.message_faster.Message.unmarshal_c", __pyx_clineno, __pyx_lineno, __pyx_filename);
      __Pyx_RefNannyFinishContext();
      return NULL;
      __pyx_L4_argument_unpacking_done:;
      __pyx_r = __pyx_pf_19amqp10_codec_faster_14message_faster_7Message_2unmarshal_c(((struct __pyx_obj_19amqp10_codec_faster_14message_faster_Message *)__pyx_v_self), __pyx_v_buffer);
      int __pyx_lineno = 0;
      const char *__pyx_filename = NULL;
      int __pyx_clineno = 0;

      /* function exit code */
      __PYX_XCLEAR_MEMVIEW(&__pyx_v_buffer, 1);
      {
        Py_ssize_t __pyx_temp;
        for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
          __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
        }
      }
      __Pyx_RefNannyFinishContext();
      return __pyx_r;
    }

    static PyObject *__pyx_pf_19amqp10_codec_faster_14message_faster_7Message_2unmarshal_c(struct __pyx_obj_19amqp10_codec_faster_14message_faster_Message *__pyx_v_self, __Pyx_memviewslice __pyx_v_buffer) {
      PyObject *__pyx_r = NULL;
      __Pyx_XDECREF(__pyx_r);
      __pyx_t_1 = ((PyObject *)__pyx_f_19amqp10_codec_faster_14message_faster_7Message_unmarshal_c(__pyx_v_self, __pyx_v_buffer, 1)); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 35, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_1);
      __pyx_r = __pyx_t_1;
      __pyx_t_1 = 0;
      goto __pyx_L0;

      /* function exit code */
      __pyx_L1_error:;
      __Pyx_XDECREF(__pyx_t_1);
      __Pyx_AddTraceback("amqp10_codec_faster.message_faster.Message.unmarshal_c", __pyx_clineno, __pyx_lineno, __pyx_filename);
      __pyx_r = NULL;
      __pyx_L0:;
      __Pyx_XGIVEREF(__pyx_r);
      __Pyx_RefNannyFinishContext();
      return __pyx_r;
    }
    /* … */
      __pyx_tuple__25 = PyTuple_Pack(2, __pyx_n_s_self, __pyx_n_s_buffer); if (unlikely(!__pyx_tuple__25)) __PYX_ERR(0, 35, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_tuple__25);
      __Pyx_GIVEREF(__pyx_tuple__25);
    /* … */
      __pyx_t_7 = __Pyx_CyFunction_New(&__pyx_mdef_19amqp10_codec_faster_14message_faster_7Message_3unmarshal_c, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_Message_unmarshal_c, NULL, __pyx_n_s_amqp10_codec_faster_message_fast_2, __pyx_d, ((PyObject *)__pyx_codeobj__26)); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 35, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_7);
      if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_19amqp10_codec_faster_14message_faster_Message, __pyx_n_s_unmarshal_c, __pyx_t_7) < 0) __PYX_ERR(0, 35, __pyx_L1_error)
      __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
      PyType_Modified(__pyx_ptype_19amqp10_codec_faster_14message_faster_Message);
      __pyx_codeobj__26 = (PyObject*)__Pyx_PyCode_New(2, 0, 0, 2, 0, CO_OPTIMIZED|CO_NEWLOCALS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__25, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_amqp10_codec_faster_message_fast, __pyx_n_s_unmarshal_c, 35, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__26)) __PYX_ERR(0, 35, __pyx_L1_error)

     036:         #                                                            Bare Message

     037:         #                                                               |

     038:         #                                         .---------------------+--------------------.

     039:         #                                         |                                           |

     040:         #    +--------+-------------+-------------+------------+--------------+--------------+--------

     041:         #    | header | delivery-   | message-    | properties | application- | application- | footer |

     042:         #    |        | annotations | annotations |             | properties  | data         |        |

     043:         #    +--------+-------------+-------------+------------+--------------+--------------+--------+

     044:         #    Altogether a message consists of the following sections:

     045:         #    • Zero or one header.

     046:         #    • Zero or one delivery-annotations.

     047:         #    • Zero or one message-annotations.

     048:         #    • Zero or one properties.

     049:         #    • Zero or one application-properties.

     050:         #    • The body consists of either: one or more data sections, one or more amqp-sequence sections,

     051:         #    or a single amqp-value section.

     052:         #    • Zero or one footer.

    +053:         cdef Message msg = Message()

      __pyx_t_1 = __Pyx_PyObject_CallNoArg(((PyObject *)__pyx_ptype_19amqp10_codec_faster_14message_faster_Message)); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 53, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_1);
      __pyx_v_msg = ((struct __pyx_obj_19amqp10_codec_faster_14message_faster_Message *)__pyx_t_1);
      __pyx_t_1 = 0;

    +054:         cdef Py_ssize_t offset = 0

      __pyx_v_offset = 0;

    +055:         cdef Py_ssize_t buffer_length = buffer.shape[0]

      __pyx_v_buffer_length = (__pyx_v_buffer.shape[0]);

     056:         cdef uint8_t described_format_code

     057:

    +058:         cdef unsigned char *buffer_p = &buffer[0]

      __pyx_t_2 = 0;
      __pyx_v_buffer_p = (&(*((unsigned char *) ( /* dim=0 */ (__pyx_v_buffer.data + __pyx_t_2 * __pyx_v_buffer.strides[0]) ))));

     059:

    +060:         while offset != buffer_length:

      while (1) {
        __pyx_t_3 = (__pyx_v_offset != __pyx_v_buffer_length);
        if (!__pyx_t_3) break;

    +061:             described_format_code = <uint8_t> buffer_p[offset + 2] # don't need 0 and 1

        __pyx_v_described_format_code = ((uint8_t)(__pyx_v_buffer_p[(__pyx_v_offset + 2)]));

     062:

    +063:             if described_format_code == 0x75:

        switch (__pyx_v_described_format_code) {
          case 0x75:
    /* … */
          break;
          case 0x70:

    +064:                 offset += DESCRIBED_FORMAT_CODE_SIZE

          __pyx_v_offset = (__pyx_v_offset + 3);

    +065:                 msg.body = read_application_data(buffer_p, &offset)

          __pyx_t_1 = __pyx_f_19amqp10_codec_faster_14message_faster_read_application_data(__pyx_v_buffer_p, (&__pyx_v_offset)); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 65, __pyx_L1_error)
          __Pyx_GOTREF(__pyx_t_1);
          __Pyx_GIVEREF(__pyx_t_1);
          __Pyx_GOTREF(__pyx_v_msg->body);
          __Pyx_DECREF(__pyx_v_msg->body);
          __pyx_v_msg->body = __pyx_t_1;
          __pyx_t_1 = 0;

    +066:             elif described_format_code == 0x70:

          break;
          case 0x74:

    +067:                 msg.header = Header().parse(buffer_p, &offset)

          __pyx_t_1 = __Pyx_PyObject_CallNoArg(((PyObject *)__pyx_ptype_19amqp10_codec_faster_14message_faster_Header)); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 67, __pyx_L1_error)
          __Pyx_GOTREF(__pyx_t_1);
          #pragma GCC diagnostic ignored "-Wincompatible-pointer-types"
          __pyx_t_4 = ((PyObject *)__pyx_f_19amqp10_codec_faster_14message_faster_6Header_parse(((struct __pyx_obj_19amqp10_codec_faster_14message_faster_Header *)__pyx_t_1), __pyx_v_buffer_p, (&__pyx_v_offset))); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 67, __pyx_L1_error)
          #pragma GCC diagnostic pop
          __Pyx_GOTREF(__pyx_t_4);
          __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
          __Pyx_GIVEREF(__pyx_t_4);
          __Pyx_GOTREF(__pyx_v_msg->header);
          __Pyx_DECREF(__pyx_v_msg->header);
          __pyx_v_msg->header = __pyx_t_4;
          __pyx_t_4 = 0;

    +068:             elif described_format_code == 0x74:

          break;
          case 0x72:

    +069:                 offset += DESCRIBED_FORMAT_CODE_SIZE

          __pyx_v_offset = (__pyx_v_offset + 3);

    +070:                 msg.application_properties = read_map(buffer_p, &offset)

          __pyx_t_4 = __pyx_f_19amqp10_codec_faster_14message_faster_read_map(__pyx_v_buffer_p, (&__pyx_v_offset)); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 70, __pyx_L1_error)
          __Pyx_GOTREF(__pyx_t_4);
          __Pyx_GIVEREF(__pyx_t_4);
          __Pyx_GOTREF(__pyx_v_msg->application_properties);
          __Pyx_DECREF(__pyx_v_msg->application_properties);
          __pyx_v_msg->application_properties = __pyx_t_4;
          __pyx_t_4 = 0;

    +071:             elif described_format_code == 0x72:

          break;
          case 0x73:

    +072:                 offset += DESCRIBED_FORMAT_CODE_SIZE

          __pyx_v_offset = (__pyx_v_offset + 3);

    +073:                 msg.annotations = read_map(buffer_p, &offset)

          __pyx_t_4 = __pyx_f_19amqp10_codec_faster_14message_faster_read_map(__pyx_v_buffer_p, (&__pyx_v_offset)); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 73, __pyx_L1_error)
          __Pyx_GOTREF(__pyx_t_4);
          __Pyx_GIVEREF(__pyx_t_4);
          __Pyx_GOTREF(__pyx_v_msg->annotations);
          __Pyx_DECREF(__pyx_v_msg->annotations);
          __pyx_v_msg->annotations = __pyx_t_4;
          __pyx_t_4 = 0;

    +074:             elif described_format_code == 0x73:

          break;
          case 0x77:

    +075:                 msg.properties = Properties().parse(buffer_p, &offset)

          __pyx_t_4 = __Pyx_PyObject_CallNoArg(((PyObject *)__pyx_ptype_19amqp10_codec_faster_14message_faster_Properties)); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 75, __pyx_L1_error)
          __Pyx_GOTREF(__pyx_t_4);
          #pragma GCC diagnostic ignored "-Wincompatible-pointer-types"
          __pyx_t_1 = ((PyObject *)__pyx_f_19amqp10_codec_faster_14message_faster_10Properties_parse(((struct __pyx_obj_19amqp10_codec_faster_14message_faster_Properties *)__pyx_t_4), __pyx_v_buffer_p, (&__pyx_v_offset))); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 75, __pyx_L1_error)
          #pragma GCC diagnostic pop
          __Pyx_GOTREF(__pyx_t_1);
          __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
          __Pyx_GIVEREF(__pyx_t_1);
          __Pyx_GOTREF(__pyx_v_msg->properties);
          __Pyx_DECREF(__pyx_v_msg->properties);
          __pyx_v_msg->properties = __pyx_t_1;
          __pyx_t_1 = 0;

    +076:             elif described_format_code == 0x77:

          break;
          default: break;
        }
      }

    +077:                 offset += DESCRIBED_FORMAT_CODE_SIZE

          __pyx_v_offset = (__pyx_v_offset + 3);

    +078:                 msg.amqp_value = read_any(buffer_p, &offset)

          __pyx_t_1 = __pyx_f_19amqp10_codec_faster_14message_faster_read_any(__pyx_v_buffer_p, (&__pyx_v_offset)); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 78, __pyx_L1_error)
          __Pyx_GOTREF(__pyx_t_1);
          __Pyx_GIVEREF(__pyx_t_1);
          __Pyx_GOTREF(__pyx_v_msg->amqp_value);
          __Pyx_DECREF(__pyx_v_msg->amqp_value);
          __pyx_v_msg->amqp_value = __pyx_t_1;
          __pyx_t_1 = 0;

    +079:         return msg

      __Pyx_XDECREF((PyObject *)__pyx_r);
      __Pyx_INCREF((PyObject *)__pyx_v_msg);
      __pyx_r = __pyx_v_msg;
      goto __pyx_L0;

     080:

    +081:     cpdef unsigned char[:] marshal_c(self):

    static PyObject *__pyx_pw_19amqp10_codec_faster_14message_faster_7Message_5marshal_c(PyObject *__pyx_v_self,
    #if CYTHON_METH_FASTCALL
    PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
    #else
    PyObject *__pyx_args, PyObject *__pyx_kwds
    #endif
    ); /*proto*/
    static __Pyx_memviewslice __pyx_f_19amqp10_codec_faster_14message_faster_7Message_marshal_c(struct __pyx_obj_19amqp10_codec_faster_14message_faster_Message *__pyx_v_self, CYTHON_UNUSED int __pyx_skip_dispatch) {
      __Pyx_memviewslice __pyx_v_body = { 0, 0, { 0 }, { 0 }, { 0 } };
      unsigned char *__pyx_v_mv_body;
      __Pyx_memviewslice __pyx_r = { 0, 0, { 0 }, { 0 }, { 0 } };
    /* … */
      /* function exit code */
      __pyx_L1_error:;
      __Pyx_XDECREF(__pyx_t_1);
      __PYX_XCLEAR_MEMVIEW(&__pyx_t_2, 1);
      __pyx_r.data = NULL;
      __pyx_r.memview = NULL;
      __Pyx_AddTraceback("amqp10_codec_faster.message_faster.Message.marshal_c", __pyx_clineno, __pyx_lineno, __pyx_filename);
      goto __pyx_L2;
      __pyx_L0:;
      if (unlikely(!__pyx_r.memview)) {
        PyErr_SetString(PyExc_TypeError, "Memoryview return value is not initialized");
      }
      __pyx_L2:;
      __PYX_XCLEAR_MEMVIEW(&__pyx_v_body, 1);
      __Pyx_RefNannyFinishContext();
      return __pyx_r;
    }

    /* Python wrapper */
    static PyObject *__pyx_pw_19amqp10_codec_faster_14message_faster_7Message_5marshal_c(PyObject *__pyx_v_self,
    #if CYTHON_METH_FASTCALL
    PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
    #else
    PyObject *__pyx_args, PyObject *__pyx_kwds
    #endif
    ); /*proto*/
    PyDoc_STRVAR(__pyx_doc_19amqp10_codec_faster_14message_faster_7Message_4marshal_c, "marshal_c(self) -> unsigned_char[:]");
    static PyMethodDef __pyx_mdef_19amqp10_codec_faster_14message_faster_7Message_5marshal_c = {"marshal_c", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_19amqp10_codec_faster_14message_faster_7Message_5marshal_c, __Pyx_METH_FASTCALL|METH_KEYWORDS, __pyx_doc_19amqp10_codec_faster_14message_faster_7Message_4marshal_c};
    static PyObject *__pyx_pw_19amqp10_codec_faster_14message_faster_7Message_5marshal_c(PyObject *__pyx_v_self,
    #if CYTHON_METH_FASTCALL
    PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
    #else
    PyObject *__pyx_args, PyObject *__pyx_kwds
    #endif
    ) {
      #if !CYTHON_METH_FASTCALL
      CYTHON_UNUSED Py_ssize_t __pyx_nargs;
      #endif
      CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
      PyObject *__pyx_r = 0;
      __Pyx_RefNannyDeclarations
      __Pyx_RefNannySetupContext("marshal_c (wrapper)", 0);
      #if !CYTHON_METH_FASTCALL
      #if CYTHON_ASSUME_SAFE_MACROS
      __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
      #else
      __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
      #endif
      #endif
      __pyx_kwvalues = __Pyx_KwValues_FASTCALL(__pyx_args, __pyx_nargs);
      if (unlikely(__pyx_nargs > 0)) {
        __Pyx_RaiseArgtupleInvalid("marshal_c", 1, 0, 0, __pyx_nargs); return NULL;}
      if (unlikely(__pyx_kwds) && __Pyx_NumKwargs_FASTCALL(__pyx_kwds) && unlikely(!__Pyx_CheckKeywordStrings(__pyx_kwds, "marshal_c", 0))) return NULL;
      __pyx_r = __pyx_pf_19amqp10_codec_faster_14message_faster_7Message_4marshal_c(((struct __pyx_obj_19amqp10_codec_faster_14message_faster_Message *)__pyx_v_self));

      /* function exit code */
      __Pyx_RefNannyFinishContext();
      return __pyx_r;
    }

    static PyObject *__pyx_pf_19amqp10_codec_faster_14message_faster_7Message_4marshal_c(struct __pyx_obj_19amqp10_codec_faster_14message_faster_Message *__pyx_v_self) {
      PyObject *__pyx_r = NULL;
      __Pyx_XDECREF(__pyx_r);
      __pyx_t_1 = __pyx_f_19amqp10_codec_faster_14message_faster_7Message_marshal_c(__pyx_v_self, 1); if (unlikely(!__pyx_t_1.memview)) __PYX_ERR(0, 81, __pyx_L1_error)
      __pyx_t_2 = __pyx_memoryview_fromslice(__pyx_t_1, 1, (PyObject *(*)(char *)) __pyx_memview_get_unsigned_char, (int (*)(char *, PyObject *)) __pyx_memview_set_unsigned_char, 0);; if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 81, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_2);
      __PYX_XCLEAR_MEMVIEW(&__pyx_t_1, 1);
      __pyx_t_1.memview = NULL; __pyx_t_1.data = NULL;
      __pyx_r = __pyx_t_2;
      __pyx_t_2 = 0;
      goto __pyx_L0;

      /* function exit code */
      __pyx_L1_error:;
      __PYX_XCLEAR_MEMVIEW(&__pyx_t_1, 1);
      __Pyx_XDECREF(__pyx_t_2);
      __Pyx_AddTraceback("amqp10_codec_faster.message_faster.Message.marshal_c", __pyx_clineno, __pyx_lineno, __pyx_filename);
      __pyx_r = NULL;
      __pyx_L0:;
      __Pyx_XGIVEREF(__pyx_r);
      __Pyx_RefNannyFinishContext();
      return __pyx_r;
    }
    /* … */
      __pyx_tuple__27 = PyTuple_Pack(1, __pyx_n_s_self); if (unlikely(!__pyx_tuple__27)) __PYX_ERR(0, 81, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_tuple__27);
      __Pyx_GIVEREF(__pyx_tuple__27);
    /* … */
      __pyx_t_7 = __Pyx_CyFunction_New(&__pyx_mdef_19amqp10_codec_faster_14message_faster_7Message_5marshal_c, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_Message_marshal_c, NULL, __pyx_n_s_amqp10_codec_faster_message_fast_2, __pyx_d, ((PyObject *)__pyx_codeobj__28)); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 81, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_7);
      if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_19amqp10_codec_faster_14message_faster_Message, __pyx_n_s_marshal_c, __pyx_t_7) < 0) __PYX_ERR(0, 81, __pyx_L1_error)
      __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
      PyType_Modified(__pyx_ptype_19amqp10_codec_faster_14message_faster_Message);
      __pyx_codeobj__28 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 1, 0, CO_OPTIMIZED|CO_NEWLOCALS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__27, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_amqp10_codec_faster_message_fast, __pyx_n_s_marshal_c, 81, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__28)) __PYX_ERR(0, 81, __pyx_L1_error)

    +082:         cdef unsigned char[:] body = bytearray(self.body)

      __pyx_t_1 = __Pyx_PyObject_CallOneArg(((PyObject *)(&PyByteArray_Type)), __pyx_v_self->body); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 82, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_1);
      __pyx_t_2 = __Pyx_PyObject_to_MemoryviewSlice_ds_unsigned_char(__pyx_t_1, PyBUF_WRITABLE); if (unlikely(!__pyx_t_2.memview)) __PYX_ERR(0, 82, __pyx_L1_error)
      __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
      __pyx_v_body = __pyx_t_2;
      __pyx_t_2.memview = NULL;
      __pyx_t_2.data = NULL;

    +083:         cdef unsigned char *mv_body = &body[0]

      __pyx_t_3 = 0;
      __pyx_v_mv_body = (&(*((unsigned char *) ( /* dim=0 */ (__pyx_v_body.data + __pyx_t_3 * __pyx_v_body.strides[0]) ))));

     084:         #pass buffer from here

    +085:         return write_data(mv_body, body.shape[0])

      __pyx_t_2 = __pyx_f_19amqp10_codec_faster_14message_faster_write_data(__pyx_v_mv_body, (__pyx_v_body.shape[0])); if (unlikely(!__pyx_t_2.memview)) __PYX_ERR(0, 85, __pyx_L1_error)
      __pyx_r = __pyx_t_2;
      __pyx_t_2.memview = NULL;
      __pyx_t_2.data = NULL;
      goto __pyx_L0;

     086:

     087:

     088: @cython.no_gc_clear

     089: @cython.final

     090: @cython.freelist(1000)

    +091: cdef class Header:

    struct __pyx_obj_19amqp10_codec_faster_14message_faster_Header {
      PyObject_HEAD
      struct __pyx_vtabstruct_19amqp10_codec_faster_14message_faster_Header *__pyx_vtab;
      int durable;
      uint8_t priority;
      uint32_t ttl;
      int first_acquirer;
      uint32_t delivery_count;
    };
    /* … */
    struct __pyx_vtabstruct_19amqp10_codec_faster_14message_faster_Header {
      struct __pyx_obj_19amqp10_codec_faster_14message_faster_Header *(*parse)(struct __pyx_obj_19amqp10_codec_faster_14message_faster_Header *, unsigned char *, Py_ssize_t *);
    };
    static struct __pyx_vtabstruct_19amqp10_codec_faster_14message_faster_Header *__pyx_vtabptr_19amqp10_codec_faster_14message_faster_Header;
    static struct __pyx_obj_19amqp10_codec_faster_14message_faster_Header *__pyx_f_19amqp10_codec_faster_14message_faster_6Header_parse(struct __pyx_obj_19amqp10_codec_faster_14message_faster_Header *, unsigned char *, Py_ssize_t *);

     092:     cdef:

    +093:         public bint durable

    /* Python wrapper */
    static PyObject *__pyx_pw_19amqp10_codec_faster_14message_faster_6Header_7durable_1__get__(PyObject *__pyx_v_self); /*proto*/
    static PyObject *__pyx_pw_19amqp10_codec_faster_14message_faster_6Header_7durable_1__get__(PyObject *__pyx_v_self) {
      CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
      PyObject *__pyx_r = 0;
      __Pyx_RefNannyDeclarations
      __Pyx_RefNannySetupContext("__get__ (wrapper)", 0);
      __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
      __pyx_r = __pyx_pf_19amqp10_codec_faster_14message_faster_6Header_7durable___get__(((struct __pyx_obj_19amqp10_codec_faster_14message_faster_Header *)__pyx_v_self));

      /* function exit code */
      __Pyx_RefNannyFinishContext();
      return __pyx_r;
    }

    static PyObject *__pyx_pf_19amqp10_codec_faster_14message_faster_6Header_7durable___get__(struct __pyx_obj_19amqp10_codec_faster_14message_faster_Header *__pyx_v_self) {
      PyObject *__pyx_r = NULL;
      __Pyx_XDECREF(__pyx_r);
      __pyx_t_1 = __Pyx_PyBool_FromLong(__pyx_v_self->durable); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 93, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_1);
      __pyx_r = __pyx_t_1;
      __pyx_t_1 = 0;
      goto __pyx_L0;

      /* function exit code */
      __pyx_L1_error:;
      __Pyx_XDECREF(__pyx_t_1);
      __Pyx_AddTraceback("amqp10_codec_faster.message_faster.Header.durable.__get__", __pyx_clineno, __pyx_lineno, __pyx_filename);
      __pyx_r = NULL;
      __pyx_L0:;
      __Pyx_XGIVEREF(__pyx_r);
      __Pyx_RefNannyFinishContext();
      return __pyx_r;
    }

    /* Python wrapper */
    static int __pyx_pw_19amqp10_codec_faster_14message_faster_6Header_7durable_3__set__(PyObject *__pyx_v_self, PyObject *__pyx_v_value); /*proto*/
    static int __pyx_pw_19amqp10_codec_faster_14message_faster_6Header_7durable_3__set__(PyObject *__pyx_v_self, PyObject *__pyx_v_value) {
      CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
      int __pyx_r;
      __Pyx_RefNannyDeclarations
      __Pyx_RefNannySetupContext("__set__ (wrapper)", 0);
      __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
      __pyx_r = __pyx_pf_19amqp10_codec_faster_14message_faster_6Header_7durable_2__set__(((struct __pyx_obj_19amqp10_codec_faster_14message_faster_Header *)__pyx_v_self), ((PyObject *)__pyx_v_value));

      /* function exit code */
      __Pyx_RefNannyFinishContext();
      return __pyx_r;
    }

    static int __pyx_pf_19amqp10_codec_faster_14message_faster_6Header_7durable_2__set__(struct __pyx_obj_19amqp10_codec_faster_14message_faster_Header *__pyx_v_self, PyObject *__pyx_v_value) {
      int __pyx_r;
      __pyx_t_1 = __Pyx_PyObject_IsTrue(__pyx_v_value); if (unlikely((__pyx_t_1 == (int)-1) && PyErr_Occurred())) __PYX_ERR(0, 93, __pyx_L1_error)
      __pyx_v_self->durable = __pyx_t_1;

      /* function exit code */
      __pyx_r = 0;
      goto __pyx_L0;
      __pyx_L1_error:;
      __Pyx_AddTraceback("amqp10_codec_faster.message_faster.Header.durable.__set__", __pyx_clineno, __pyx_lineno, __pyx_filename);
      __pyx_r = -1;
      __pyx_L0:;
      return __pyx_r;
    }

    +094:         public uint8_t priority

    /* Python wrapper */
    static PyObject *__pyx_pw_19amqp10_codec_faster_14message_faster_6Header_8priority_1__get__(PyObject *__pyx_v_self); /*proto*/
    static PyObject *__pyx_pw_19amqp10_codec_faster_14message_faster_6Header_8priority_1__get__(PyObject *__pyx_v_self) {
      CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
      PyObject *__pyx_r = 0;
      __Pyx_RefNannyDeclarations
      __Pyx_RefNannySetupContext("__get__ (wrapper)", 0);
      __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
      __pyx_r = __pyx_pf_19amqp10_codec_faster_14message_faster_6Header_8priority___get__(((struct __pyx_obj_19amqp10_codec_faster_14message_faster_Header *)__pyx_v_self));

      /* function exit code */
      __Pyx_RefNannyFinishContext();
      return __pyx_r;
    }

    static PyObject *__pyx_pf_19amqp10_codec_faster_14message_faster_6Header_8priority___get__(struct __pyx_obj_19amqp10_codec_faster_14message_faster_Header *__pyx_v_self) {
      PyObject *__pyx_r = NULL;
      __Pyx_XDECREF(__pyx_r);
      __pyx_t_1 = __Pyx_PyInt_From_uint8_t(__pyx_v_self->priority); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 94, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_1);
      __pyx_r = __pyx_t_1;
      __pyx_t_1 = 0;
      goto __pyx_L0;

      /* function exit code */
      __pyx_L1_error:;
      __Pyx_XDECREF(__pyx_t_1);
      __Pyx_AddTraceback("amqp10_codec_faster.message_faster.Header.priority.__get__", __pyx_clineno, __pyx_lineno, __pyx_filename);
      __pyx_r = NULL;
      __pyx_L0:;
      __Pyx_XGIVEREF(__pyx_r);
      __Pyx_RefNannyFinishContext();
      return __pyx_r;
    }

    /* Python wrapper */
    static int __pyx_pw_19amqp10_codec_faster_14message_faster_6Header_8priority_3__set__(PyObject *__pyx_v_self, PyObject *__pyx_v_value); /*proto*/
    static int __pyx_pw_19amqp10_codec_faster_14message_faster_6Header_8priority_3__set__(PyObject *__pyx_v_self, PyObject *__pyx_v_value) {
      CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
      int __pyx_r;
      __Pyx_RefNannyDeclarations
      __Pyx_RefNannySetupContext("__set__ (wrapper)", 0);
      __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
      __pyx_r = __pyx_pf_19amqp10_codec_faster_14message_faster_6Header_8priority_2__set__(((struct __pyx_obj_19amqp10_codec_faster_14message_faster_Header *)__pyx_v_self), ((PyObject *)__pyx_v_value));

      /* function exit code */
      __Pyx_RefNannyFinishContext();
      return __pyx_r;
    }

    static int __pyx_pf_19amqp10_codec_faster_14message_faster_6Header_8priority_2__set__(struct __pyx_obj_19amqp10_codec_faster_14message_faster_Header *__pyx_v_self, PyObject *__pyx_v_value) {
      int __pyx_r;
      __pyx_t_1 = __Pyx_PyInt_As_uint8_t(__pyx_v_value); if (unlikely((__pyx_t_1 == ((uint8_t)-1)) && PyErr_Occurred())) __PYX_ERR(0, 94, __pyx_L1_error)
      __pyx_v_self->priority = __pyx_t_1;

      /* function exit code */
      __pyx_r = 0;
      goto __pyx_L0;
      __pyx_L1_error:;
      __Pyx_AddTraceback("amqp10_codec_faster.message_faster.Header.priority.__set__", __pyx_clineno, __pyx_lineno, __pyx_filename);
      __pyx_r = -1;
      __pyx_L0:;
      return __pyx_r;
    }

    +095:         public uint32_t ttl

    /* Python wrapper */
    static PyObject *__pyx_pw_19amqp10_codec_faster_14message_faster_6Header_3ttl_1__get__(PyObject *__pyx_v_self); /*proto*/
    static PyObject *__pyx_pw_19amqp10_codec_faster_14message_faster_6Header_3ttl_1__get__(PyObject *__pyx_v_self) {
      CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
      PyObject *__pyx_r = 0;
      __Pyx_RefNannyDeclarations
      __Pyx_RefNannySetupContext("__get__ (wrapper)", 0);
      __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
      __pyx_r = __pyx_pf_19amqp10_codec_faster_14message_faster_6Header_3ttl___get__(((struct __pyx_obj_19amqp10_codec_faster_14message_faster_Header *)__pyx_v_self));

      /* function exit code */
      __Pyx_RefNannyFinishContext();
      return __pyx_r;
    }

    static PyObject *__pyx_pf_19amqp10_codec_faster_14message_faster_6Header_3ttl___get__(struct __pyx_obj_19amqp10_codec_faster_14message_faster_Header *__pyx_v_self) {
      PyObject *__pyx_r = NULL;
      __Pyx_XDECREF(__pyx_r);
      __pyx_t_1 = __Pyx_PyInt_From_uint32_t(__pyx_v_self->ttl); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 95, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_1);
      __pyx_r = __pyx_t_1;
      __pyx_t_1 = 0;
      goto __pyx_L0;

      /* function exit code */
      __pyx_L1_error:;
      __Pyx_XDECREF(__pyx_t_1);
      __Pyx_AddTraceback("amqp10_codec_faster.message_faster.Header.ttl.__get__", __pyx_clineno, __pyx_lineno, __pyx_filename);
      __pyx_r = NULL;
      __pyx_L0:;
      __Pyx_XGIVEREF(__pyx_r);
      __Pyx_RefNannyFinishContext();
      return __pyx_r;
    }

    /* Python wrapper */
    static int __pyx_pw_19amqp10_codec_faster_14message_faster_6Header_3ttl_3__set__(PyObject *__pyx_v_self, PyObject *__pyx_v_value); /*proto*/
    static int __pyx_pw_19amqp10_codec_faster_14message_faster_6Header_3ttl_3__set__(PyObject *__pyx_v_self, PyObject *__pyx_v_value) {
      CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
      int __pyx_r;
      __Pyx_RefNannyDeclarations
      __Pyx_RefNannySetupContext("__set__ (wrapper)", 0);
      __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
      __pyx_r = __pyx_pf_19amqp10_codec_faster_14message_faster_6Header_3ttl_2__set__(((struct __pyx_obj_19amqp10_codec_faster_14message_faster_Header *)__pyx_v_self), ((PyObject *)__pyx_v_value));

      /* function exit code */
      __Pyx_RefNannyFinishContext();
      return __pyx_r;
    }

    static int __pyx_pf_19amqp10_codec_faster_14message_faster_6Header_3ttl_2__set__(struct __pyx_obj_19amqp10_codec_faster_14message_faster_Header *__pyx_v_self, PyObject *__pyx_v_value) {
      int __pyx_r;
      __pyx_t_1 = __Pyx_PyInt_As_uint32_t(__pyx_v_value); if (unlikely((__pyx_t_1 == ((uint32_t)-1)) && PyErr_Occurred())) __PYX_ERR(0, 95, __pyx_L1_error)
      __pyx_v_self->ttl = __pyx_t_1;

      /* function exit code */
      __pyx_r = 0;
      goto __pyx_L0;
      __pyx_L1_error:;
      __Pyx_AddTraceback("amqp10_codec_faster.message_faster.Header.ttl.__set__", __pyx_clineno, __pyx_lineno, __pyx_filename);
      __pyx_r = -1;
      __pyx_L0:;
      return __pyx_r;
    }

    +096:         public bint first_acquirer

    /* Python wrapper */
    static PyObject *__pyx_pw_19amqp10_codec_faster_14message_faster_6Header_14first_acquirer_1__get__(PyObject *__pyx_v_self); /*proto*/
    static PyObject *__pyx_pw_19amqp10_codec_faster_14message_faster_6Header_14first_acquirer_1__get__(PyObject *__pyx_v_self) {
      CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
      PyObject *__pyx_r = 0;
      __Pyx_RefNannyDeclarations
      __Pyx_RefNannySetupContext("__get__ (wrapper)", 0);
      __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
      __pyx_r = __pyx_pf_19amqp10_codec_faster_14message_faster_6Header_14first_acquirer___get__(((struct __pyx_obj_19amqp10_codec_faster_14message_faster_Header *)__pyx_v_self));

      /* function exit code */
      __Pyx_RefNannyFinishContext();
      return __pyx_r;
    }

    static PyObject *__pyx_pf_19amqp10_codec_faster_14message_faster_6Header_14first_acquirer___get__(struct __pyx_obj_19amqp10_codec_faster_14message_faster_Header *__pyx_v_self) {
      PyObject *__pyx_r = NULL;
      __Pyx_XDECREF(__pyx_r);
      __pyx_t_1 = __Pyx_PyBool_FromLong(__pyx_v_self->first_acquirer); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 96, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_1);
      __pyx_r = __pyx_t_1;
      __pyx_t_1 = 0;
      goto __pyx_L0;

      /* function exit code */
      __pyx_L1_error:;
      __Pyx_XDECREF(__pyx_t_1);
      __Pyx_AddTraceback("amqp10_codec_faster.message_faster.Header.first_acquirer.__get__", __pyx_clineno, __pyx_lineno, __pyx_filename);
      __pyx_r = NULL;
      __pyx_L0:;
      __Pyx_XGIVEREF(__pyx_r);
      __Pyx_RefNannyFinishContext();
      return __pyx_r;
    }

    /* Python wrapper */
    static int __pyx_pw_19amqp10_codec_faster_14message_faster_6Header_14first_acquirer_3__set__(PyObject *__pyx_v_self, PyObject *__pyx_v_value); /*proto*/
    static int __pyx_pw_19amqp10_codec_faster_14message_faster_6Header_14first_acquirer_3__set__(PyObject *__pyx_v_self, PyObject *__pyx_v_value) {
      CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
      int __pyx_r;
      __Pyx_RefNannyDeclarations
      __Pyx_RefNannySetupContext("__set__ (wrapper)", 0);
      __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
      __pyx_r = __pyx_pf_19amqp10_codec_faster_14message_faster_6Header_14first_acquirer_2__set__(((struct __pyx_obj_19amqp10_codec_faster_14message_faster_Header *)__pyx_v_self), ((PyObject *)__pyx_v_value));

      /* function exit code */
      __Pyx_RefNannyFinishContext();
      return __pyx_r;
    }

    static int __pyx_pf_19amqp10_codec_faster_14message_faster_6Header_14first_acquirer_2__set__(struct __pyx_obj_19amqp10_codec_faster_14message_faster_Header *__pyx_v_self, PyObject *__pyx_v_value) {
      int __pyx_r;
      __pyx_t_1 = __Pyx_PyObject_IsTrue(__pyx_v_value); if (unlikely((__pyx_t_1 == (int)-1) && PyErr_Occurred())) __PYX_ERR(0, 96, __pyx_L1_error)
      __pyx_v_self->first_acquirer = __pyx_t_1;

      /* function exit code */
      __pyx_r = 0;
      goto __pyx_L0;
      __pyx_L1_error:;
      __Pyx_AddTraceback("amqp10_codec_faster.message_faster.Header.first_acquirer.__set__", __pyx_clineno, __pyx_lineno, __pyx_filename);
      __pyx_r = -1;
      __pyx_L0:;
      return __pyx_r;
    }

    +097:         public uint32_t delivery_count

    /* Python wrapper */
    static PyObject *__pyx_pw_19amqp10_codec_faster_14message_faster_6Header_14delivery_count_1__get__(PyObject *__pyx_v_self); /*proto*/
    static PyObject *__pyx_pw_19amqp10_codec_faster_14message_faster_6Header_14delivery_count_1__get__(PyObject *__pyx_v_self) {
      CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
      PyObject *__pyx_r = 0;
      __Pyx_RefNannyDeclarations
      __Pyx_RefNannySetupContext("__get__ (wrapper)", 0);
      __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
      __pyx_r = __pyx_pf_19amqp10_codec_faster_14message_faster_6Header_14delivery_count___get__(((struct __pyx_obj_19amqp10_codec_faster_14message_faster_Header *)__pyx_v_self));

      /* function exit code */
      __Pyx_RefNannyFinishContext();
      return __pyx_r;
    }

    static PyObject *__pyx_pf_19amqp10_codec_faster_14message_faster_6Header_14delivery_count___get__(struct __pyx_obj_19amqp10_codec_faster_14message_faster_Header *__pyx_v_self) {
      PyObject *__pyx_r = NULL;
      __Pyx_XDECREF(__pyx_r);
      __pyx_t_1 = __Pyx_PyInt_From_uint32_t(__pyx_v_self->delivery_count); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 97, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_1);
      __pyx_r = __pyx_t_1;
      __pyx_t_1 = 0;
      goto __pyx_L0;

      /* function exit code */
      __pyx_L1_error:;
      __Pyx_XDECREF(__pyx_t_1);
      __Pyx_AddTraceback("amqp10_codec_faster.message_faster.Header.delivery_count.__get__", __pyx_clineno, __pyx_lineno, __pyx_filename);
      __pyx_r = NULL;
      __pyx_L0:;
      __Pyx_XGIVEREF(__pyx_r);
      __Pyx_RefNannyFinishContext();
      return __pyx_r;
    }

    /* Python wrapper */
    static int __pyx_pw_19amqp10_codec_faster_14message_faster_6Header_14delivery_count_3__set__(PyObject *__pyx_v_self, PyObject *__pyx_v_value); /*proto*/
    static int __pyx_pw_19amqp10_codec_faster_14message_faster_6Header_14delivery_count_3__set__(PyObject *__pyx_v_self, PyObject *__pyx_v_value) {
      CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
      int __pyx_r;
      __Pyx_RefNannyDeclarations
      __Pyx_RefNannySetupContext("__set__ (wrapper)", 0);
      __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
      __pyx_r = __pyx_pf_19amqp10_codec_faster_14message_faster_6Header_14delivery_count_2__set__(((struct __pyx_obj_19amqp10_codec_faster_14message_faster_Header *)__pyx_v_self), ((PyObject *)__pyx_v_value));

      /* function exit code */
      __Pyx_RefNannyFinishContext();
      return __pyx_r;
    }

    static int __pyx_pf_19amqp10_codec_faster_14message_faster_6Header_14delivery_count_2__set__(struct __pyx_obj_19amqp10_codec_faster_14message_faster_Header *__pyx_v_self, PyObject *__pyx_v_value) {
      int __pyx_r;
      __pyx_t_1 = __Pyx_PyInt_As_uint32_t(__pyx_v_value); if (unlikely((__pyx_t_1 == ((uint32_t)-1)) && PyErr_Occurred())) __PYX_ERR(0, 97, __pyx_L1_error)
      __pyx_v_self->delivery_count = __pyx_t_1;

      /* function exit code */
      __pyx_r = 0;
      goto __pyx_L0;
      __pyx_L1_error:;
      __Pyx_AddTraceback("amqp10_codec_faster.message_faster.Header.delivery_count.__set__", __pyx_clineno, __pyx_lineno, __pyx_filename);
      __pyx_r = -1;
      __pyx_L0:;
      return __pyx_r;
    }

     098:

    +099:     def __init__(

    /* Python wrapper */
    static int __pyx_pw_19amqp10_codec_faster_14message_faster_6Header_1__init__(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
    static int __pyx_pw_19amqp10_codec_faster_14message_faster_6Header_1__init__(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
      CYTHON_UNUSED Py_ssize_t __pyx_nargs;
      CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
      int __pyx_r;
      __Pyx_RefNannyDeclarations
      __Pyx_RefNannySetupContext("__init__ (wrapper)", 0);
      #if CYTHON_ASSUME_SAFE_MACROS
      __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
      #else
      __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return -1;
      #endif
      __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
      if (unlikely(__pyx_nargs > 0)) {
        __Pyx_RaiseArgtupleInvalid("__init__", 1, 0, 0, __pyx_nargs); return -1;}
      if (unlikely(__pyx_kwds) && __Pyx_NumKwargs_VARARGS(__pyx_kwds) && unlikely(!__Pyx_CheckKeywordStrings(__pyx_kwds, "__init__", 0))) return -1;
      __pyx_r = __pyx_pf_19amqp10_codec_faster_14message_faster_6Header___init__(((struct __pyx_obj_19amqp10_codec_faster_14message_faster_Header *)__pyx_v_self));

      /* function exit code */
      __Pyx_RefNannyFinishContext();
      return __pyx_r;
    }

    static int __pyx_pf_19amqp10_codec_faster_14message_faster_6Header___init__(struct __pyx_obj_19amqp10_codec_faster_14message_faster_Header *__pyx_v_self) {
      int __pyx_r;
    /* … */
      /* function exit code */
      __pyx_r = 0;
      return __pyx_r;
    }

     100:         self,

     101:     ):

    +102:         self.durable = False

      __pyx_v_self->durable = 0;

    +103:         self.priority = 0

      __pyx_v_self->priority = 0;

    +104:         self.ttl = 0

      __pyx_v_self->ttl = 0;

    +105:         self.first_acquirer = False

      __pyx_v_self->first_acquirer = 0;

    +106:         self.delivery_count = 0

      __pyx_v_self->delivery_count = 0;

     107:

    +108:     cdef Header parse(self, unsigned char *buffer, Py_ssize_t *offset):

    static struct __pyx_obj_19amqp10_codec_faster_14message_faster_Header *__pyx_f_19amqp10_codec_faster_14message_faster_6Header_parse(CYTHON_UNUSED struct __pyx_obj_19amqp10_codec_faster_14message_faster_Header *__pyx_v_self, unsigned char *__pyx_v_buffer, Py_ssize_t *__pyx_v_offset) {
      uint32_t __pyx_v_fields;
      struct __pyx_obj_19amqp10_codec_faster_14message_faster_Header *__pyx_v_h = 0;
      uint8_t __pyx_v_index;
      unsigned char __pyx_v_value;
      struct __pyx_obj_19amqp10_codec_faster_14message_faster_Header *__pyx_r = NULL;
    /* … */
      /* function exit code */
      __pyx_L1_error:;
      __Pyx_XDECREF(__pyx_t_2);
      __Pyx_AddTraceback("amqp10_codec_faster.message_faster.Header.parse", __pyx_clineno, __pyx_lineno, __pyx_filename);
      __pyx_r = 0;
      __pyx_L0:;
      __Pyx_XDECREF((PyObject *)__pyx_v_h);
      __Pyx_XGIVEREF((PyObject *)__pyx_r);
      __Pyx_RefNannyFinishContext();
      return __pyx_r;
    }

     109:

    +110:         cdef uint32_t fields = read_composite_header(buffer, offset)

      __pyx_t_1 = __pyx_f_19amqp10_codec_faster_14message_faster_read_composite_header(__pyx_v_buffer, __pyx_v_offset); if (unlikely(__pyx_t_1 == ((uint32_t)-1) && PyErr_Occurred())) __PYX_ERR(0, 110, __pyx_L1_error)
      __pyx_v_fields = __pyx_t_1;

    +111:         cdef Header h = Header()

      __pyx_t_2 = __Pyx_PyObject_CallNoArg(((PyObject *)__pyx_ptype_19amqp10_codec_faster_14message_faster_Header)); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 111, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_2);
      __pyx_v_h = ((struct __pyx_obj_19amqp10_codec_faster_14message_faster_Header *)__pyx_t_2);
      __pyx_t_2 = 0;

     112:         cdef uint8_t index

     113:         cdef unsigned char value

     114:

    +115:         for index in range(0, fields, 1):

      __pyx_t_1 = __pyx_v_fields;
      __pyx_t_3 = __pyx_t_1;
      for (__pyx_t_4 = 0; __pyx_t_4 < __pyx_t_3; __pyx_t_4+=1) {
        __pyx_v_index = __pyx_t_4;

     116:

    +117:             value = buffer[offset[0]]

        __pyx_v_value = (__pyx_v_buffer[(__pyx_v_offset[0])]);

    +118:             if value == 0x40:  # Null

        __pyx_t_5 = (__pyx_v_value == 0x40);
        if (__pyx_t_5) {
    /* … */
          goto __pyx_L5;
        }

    +119:                 offset[0] += 1

          __pyx_t_6 = 0;
          (__pyx_v_offset[__pyx_t_6]) = ((__pyx_v_offset[__pyx_t_6]) + 1);

     120:

     121:             else:

    +122:                 if index == 0:

        /*else*/ {
    /* … */
          switch (__pyx_v_index) {
            case 0:
    /* … */
            break;
            case 1:

    +123:                     h.durable = read_any(buffer, offset)

            __pyx_t_2 = __pyx_f_19amqp10_codec_faster_14message_faster_read_any(__pyx_v_buffer, __pyx_v_offset); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 123, __pyx_L1_error)
            __Pyx_GOTREF(__pyx_t_2);
            __pyx_t_5 = __Pyx_PyObject_IsTrue(__pyx_t_2); if (unlikely((__pyx_t_5 == (int)-1) && PyErr_Occurred())) __PYX_ERR(0, 123, __pyx_L1_error)
            __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
            __pyx_v_h->durable = __pyx_t_5;

    +124:                 elif index == 1:

            break;
            case 2:

    +125:                     h.priority = read_any(buffer, offset)

            __pyx_t_2 = __pyx_f_19amqp10_codec_faster_14message_faster_read_any(__pyx_v_buffer, __pyx_v_offset); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 125, __pyx_L1_error)
            __Pyx_GOTREF(__pyx_t_2);
            __pyx_t_7 = __Pyx_PyInt_As_uint8_t(__pyx_t_2); if (unlikely((__pyx_t_7 == ((uint8_t)-1)) && PyErr_Occurred())) __PYX_ERR(0, 125, __pyx_L1_error)
            __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
            __pyx_v_h->priority = __pyx_t_7;

    +126:                 elif index == 2:

            break;
            case 3:

    +127:                     h.ttl = read_any(buffer, offset)

            __pyx_t_2 = __pyx_f_19amqp10_codec_faster_14message_faster_read_any(__pyx_v_buffer, __pyx_v_offset); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 127, __pyx_L1_error)
            __Pyx_GOTREF(__pyx_t_2);
            __pyx_t_8 = __Pyx_PyInt_As_uint32_t(__pyx_t_2); if (unlikely((__pyx_t_8 == ((uint32_t)-1)) && PyErr_Occurred())) __PYX_ERR(0, 127, __pyx_L1_error)
            __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
            __pyx_v_h->ttl = __pyx_t_8;

    +128:                 elif index == 3:

            break;
            case 4:

    +129:                     h.first_acquirer = read_any(buffer, offset)

            __pyx_t_2 = __pyx_f_19amqp10_codec_faster_14message_faster_read_any(__pyx_v_buffer, __pyx_v_offset); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 129, __pyx_L1_error)
            __Pyx_GOTREF(__pyx_t_2);
            __pyx_t_5 = __Pyx_PyObject_IsTrue(__pyx_t_2); if (unlikely((__pyx_t_5 == (int)-1) && PyErr_Occurred())) __PYX_ERR(0, 129, __pyx_L1_error)
            __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
            __pyx_v_h->first_acquirer = __pyx_t_5;

    +130:                 elif index == 4:

            break;
            default:

    +131:                     h.delivery_count = read_any(buffer, offset)

            __pyx_t_2 = __pyx_f_19amqp10_codec_faster_14message_faster_read_any(__pyx_v_buffer, __pyx_v_offset); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 131, __pyx_L1_error)
            __Pyx_GOTREF(__pyx_t_2);
            __pyx_t_8 = __Pyx_PyInt_As_uint32_t(__pyx_t_2); if (unlikely((__pyx_t_8 == ((uint32_t)-1)) && PyErr_Occurred())) __PYX_ERR(0, 131, __pyx_L1_error)
            __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
            __pyx_v_h->delivery_count = __pyx_t_8;

     132:                 else:

    +133:                     raise ValueError("Properties Parse invalid index {index}")

            __pyx_t_2 = __Pyx_PyObject_Call(__pyx_builtin_ValueError, __pyx_tuple__9, NULL); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 133, __pyx_L1_error)
            __Pyx_GOTREF(__pyx_t_2);
            __Pyx_Raise(__pyx_t_2, 0, 0, 0);
            __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
            __PYX_ERR(0, 133, __pyx_L1_error)
            break;
          }
        }
        __pyx_L5:;
      }
    /* … */
      __pyx_tuple__9 = PyTuple_Pack(1, __pyx_kp_u_Properties_Parse_invalid_index_i); if (unlikely(!__pyx_tuple__9)) __PYX_ERR(0, 133, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_tuple__9);
      __Pyx_GIVEREF(__pyx_tuple__9);

    +134:         return h

      __Pyx_XDECREF((PyObject *)__pyx_r);
      __Pyx_INCREF((PyObject *)__pyx_v_h);
      __pyx_r = __pyx_v_h;
      goto __pyx_L0;

     135:

     136:

     137:

     138: @cython.no_gc_clear

     139: @cython.final

     140: @cython.freelist(1000)

    +141: cdef class Properties:

    struct __pyx_obj_19amqp10_codec_faster_14message_faster_Properties {
      PyObject_HEAD
      struct __pyx_vtabstruct_19amqp10_codec_faster_14message_faster_Properties *__pyx_vtab;
      PyObject *message_id;
      PyObject *user_id;
      PyObject *to;
      PyObject *subject;
      PyObject *reply_to;
      PyObject *correlation_id;
      PyObject *content_type;
      PyObject *content_encoding;
      PyObject *absolute_expiry_time;
      PyObject *creation_time;
      PyObject *group_id;
      PyObject *group_sequence;
      PyObject *reply_to_group_id;
    };
    /* … */
    struct __pyx_vtabstruct_19amqp10_codec_faster_14message_faster_Properties {
      struct __pyx_obj_19amqp10_codec_faster_14message_faster_Properties *(*parse)(struct __pyx_obj_19amqp10_codec_faster_14message_faster_Properties *, unsigned char *, Py_ssize_t *);
    };
    static struct __pyx_vtabstruct_19amqp10_codec_faster_14message_faster_Properties *__pyx_vtabptr_19amqp10_codec_faster_14message_faster_Properties;
    static struct __pyx_obj_19amqp10_codec_faster_14message_faster_Properties *__pyx_f_19amqp10_codec_faster_14message_faster_10Properties_parse(struct __pyx_obj_19amqp10_codec_faster_14message_faster_Properties *, unsigned char *, Py_ssize_t *);

     142:     cdef:

    +143:         public object message_id

    /* Python wrapper */
    static PyObject *__pyx_pw_19amqp10_codec_faster_14message_faster_10Properties_10message_id_1__get__(PyObject *__pyx_v_self); /*proto*/
    static PyObject *__pyx_pw_19amqp10_codec_faster_14message_faster_10Properties_10message_id_1__get__(PyObject *__pyx_v_self) {
      CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
      PyObject *__pyx_r = 0;
      __Pyx_RefNannyDeclarations
      __Pyx_RefNannySetupContext("__get__ (wrapper)", 0);
      __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
      __pyx_r = __pyx_pf_19amqp10_codec_faster_14message_faster_10Properties_10message_id___get__(((struct __pyx_obj_19amqp10_codec_faster_14message_faster_Properties *)__pyx_v_self));

      /* function exit code */
      __Pyx_RefNannyFinishContext();
      return __pyx_r;
    }

    static PyObject *__pyx_pf_19amqp10_codec_faster_14message_faster_10Properties_10message_id___get__(struct __pyx_obj_19amqp10_codec_faster_14message_faster_Properties *__pyx_v_self) {
      PyObject *__pyx_r = NULL;
      __Pyx_XDECREF(__pyx_r);
      __Pyx_INCREF(__pyx_v_self->message_id);
      __pyx_r = __pyx_v_self->message_id;
      goto __pyx_L0;

      /* function exit code */
      __pyx_L0:;
      __Pyx_XGIVEREF(__pyx_r);
      __Pyx_RefNannyFinishContext();
      return __pyx_r;
    }

    /* Python wrapper */
    static int __pyx_pw_19amqp10_codec_faster_14message_faster_10Properties_10message_id_3__set__(PyObject *__pyx_v_self, PyObject *__pyx_v_value); /*proto*/
    static int __pyx_pw_19amqp10_codec_faster_14message_faster_10Properties_10message_id_3__set__(PyObject *__pyx_v_self, PyObject *__pyx_v_value) {
      CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
      int __pyx_r;
      __Pyx_RefNannyDeclarations
      __Pyx_RefNannySetupContext("__set__ (wrapper)", 0);
      __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
      __pyx_r = __pyx_pf_19amqp10_codec_faster_14message_faster_10Properties_10message_id_2__set__(((struct __pyx_obj_19amqp10_codec_faster_14message_faster_Properties *)__pyx_v_self), ((PyObject *)__pyx_v_value));

      /* function exit code */
      __Pyx_RefNannyFinishContext();
      return __pyx_r;
    }

    static int __pyx_pf_19amqp10_codec_faster_14message_faster_10Properties_10message_id_2__set__(struct __pyx_obj_19amqp10_codec_faster_14message_faster_Properties *__pyx_v_self, PyObject *__pyx_v_value) {
      int __pyx_r;
      __Pyx_INCREF(__pyx_v_value);
      __Pyx_GIVEREF(__pyx_v_value);
      __Pyx_GOTREF(__pyx_v_self->message_id);
      __Pyx_DECREF(__pyx_v_self->message_id);
      __pyx_v_self->message_id = __pyx_v_value;

      /* function exit code */
      __pyx_r = 0;
      __Pyx_RefNannyFinishContext();
      return __pyx_r;
    }

    /* Python wrapper */
    static int __pyx_pw_19amqp10_codec_faster_14message_faster_10Properties_10message_id_5__del__(PyObject *__pyx_v_self); /*proto*/
    static int __pyx_pw_19amqp10_codec_faster_14message_faster_10Properties_10message_id_5__del__(PyObject *__pyx_v_self) {
      CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
      int __pyx_r;
      __Pyx_RefNannyDeclarations
      __Pyx_RefNannySetupContext("__del__ (wrapper)", 0);
      __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
      __pyx_r = __pyx_pf_19amqp10_codec_faster_14message_faster_10Properties_10message_id_4__del__(((struct __pyx_obj_19amqp10_codec_faster_14message_faster_Properties *)__pyx_v_self));

      /* function exit code */
      __Pyx_RefNannyFinishContext();
      return __pyx_r;
    }

    static int __pyx_pf_19amqp10_codec_faster_14message_faster_10Properties_10message_id_4__del__(struct __pyx_obj_19amqp10_codec_faster_14message_faster_Properties *__pyx_v_self) {
      int __pyx_r;
      __Pyx_INCREF(Py_None);
      __Pyx_GIVEREF(Py_None);
      __Pyx_GOTREF(__pyx_v_self->message_id);
      __Pyx_DECREF(__pyx_v_self->message_id);
      __pyx_v_self->message_id = Py_None;

      /* function exit code */
      __pyx_r = 0;
      __Pyx_RefNannyFinishContext();
      return __pyx_r;
    }

    +144:         public object user_id

    /* Python wrapper */
    static PyObject *__pyx_pw_19amqp10_codec_faster_14message_faster_10Properties_7user_id_1__get__(PyObject *__pyx_v_self); /*proto*/
    static PyObject *__pyx_pw_19amqp10_codec_faster_14message_faster_10Properties_7user_id_1__get__(PyObject *__pyx_v_self) {
      CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
      PyObject *__pyx_r = 0;
      __Pyx_RefNannyDeclarations
      __Pyx_RefNannySetupContext("__get__ (wrapper)", 0);
      __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
      __pyx_r = __pyx_pf_19amqp10_codec_faster_14message_faster_10Properties_7user_id___get__(((struct __pyx_obj_19amqp10_codec_faster_14message_faster_Properties *)__pyx_v_self));

      /* function exit code */
      __Pyx_RefNannyFinishContext();
      return __pyx_r;
    }

    static PyObject *__pyx_pf_19amqp10_codec_faster_14message_faster_10Properties_7user_id___get__(struct __pyx_obj_19amqp10_codec_faster_14message_faster_Properties *__pyx_v_self) {
      PyObject *__pyx_r = NULL;
      __Pyx_XDECREF(__pyx_r);
      __Pyx_INCREF(__pyx_v_self->user_id);
      __pyx_r = __pyx_v_self->user_id;
      goto __pyx_L0;

      /* function exit code */
      __pyx_L0:;
      __Pyx_XGIVEREF(__pyx_r);
      __Pyx_RefNannyFinishContext();
      return __pyx_r;
    }

    /* Python wrapper */
    static int __pyx_pw_19amqp10_codec_faster_14message_faster_10Properties_7user_id_3__set__(PyObject *__pyx_v_self, PyObject *__pyx_v_value); /*proto*/
    static int __pyx_pw_19amqp10_codec_faster_14message_faster_10Properties_7user_id_3__set__(PyObject *__pyx_v_self, PyObject *__pyx_v_value) {
      CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
      int __pyx_r;
      __Pyx_RefNannyDeclarations
      __Pyx_RefNannySetupContext("__set__ (wrapper)", 0);
      __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
      __pyx_r = __pyx_pf_19amqp10_codec_faster_14message_faster_10Properties_7user_id_2__set__(((struct __pyx_obj_19amqp10_codec_faster_14message_faster_Properties *)__pyx_v_self), ((PyObject *)__pyx_v_value));

      /* function exit code */
      __Pyx_RefNannyFinishContext();
      return __pyx_r;
    }

    static int __pyx_pf_19amqp10_codec_faster_14message_faster_10Properties_7user_id_2__set__(struct __pyx_obj_19amqp10_codec_faster_14message_faster_Properties *__pyx_v_self, PyObject *__pyx_v_value) {
      int __pyx_r;
      __Pyx_INCREF(__pyx_v_value);
      __Pyx_GIVEREF(__pyx_v_value);
      __Pyx_GOTREF(__pyx_v_self->user_id);
      __Pyx_DECREF(__pyx_v_self->user_id);
      __pyx_v_self->user_id = __pyx_v_value;

      /* function exit code */
      __pyx_r = 0;
      __Pyx_RefNannyFinishContext();
      return __pyx_r;
    }

    /* Python wrapper */
    static int __pyx_pw_19amqp10_codec_faster_14message_faster_10Properties_7user_id_5__del__(PyObject *__pyx_v_self); /*proto*/
    static int __pyx_pw_19amqp10_codec_faster_14message_faster_10Properties_7user_id_5__del__(PyObject *__pyx_v_self) {
      CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
      int __pyx_r;
      __Pyx_RefNannyDeclarations
      __Pyx_RefNannySetupContext("__del__ (wrapper)", 0);
      __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
      __pyx_r = __pyx_pf_19amqp10_codec_faster_14message_faster_10Properties_7user_id_4__del__(((struct __pyx_obj_19amqp10_codec_faster_14message_faster_Properties *)__pyx_v_self));

      /* function exit code */
      __Pyx_RefNannyFinishContext();
      return __pyx_r;
    }

    static int __pyx_pf_19amqp10_codec_faster_14message_faster_10Properties_7user_id_4__del__(struct __pyx_obj_19amqp10_codec_faster_14message_faster_Properties *__pyx_v_self) {
      int __pyx_r;
      __Pyx_INCREF(Py_None);
      __Pyx_GIVEREF(Py_None);
      __Pyx_GOTREF(__pyx_v_self->user_id);
      __Pyx_DECREF(__pyx_v_self->user_id);
      __pyx_v_self->user_id = Py_None;

      /* function exit code */
      __pyx_r = 0;
      __Pyx_RefNannyFinishContext();
      return __pyx_r;
    }

    +145:         public object to

    /* Python wrapper */
    static PyObject *__pyx_pw_19amqp10_codec_faster_14message_faster_10Properties_2to_1__get__(PyObject *__pyx_v_self); /*proto*/
    static PyObject *__pyx_pw_19amqp10_codec_faster_14message_faster_10Properties_2to_1__get__(PyObject *__pyx_v_self) {
      CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
      PyObject *__pyx_r = 0;
      __Pyx_RefNannyDeclarations
      __Pyx_RefNannySetupContext("__get__ (wrapper)", 0);
      __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
      __pyx_r = __pyx_pf_19amqp10_codec_faster_14message_faster_10Properties_2to___get__(((struct __pyx_obj_19amqp10_codec_faster_14message_faster_Properties *)__pyx_v_self));

      /* function exit code */
      __Pyx_RefNannyFinishContext();
      return __pyx_r;
    }

    static PyObject *__pyx_pf_19amqp10_codec_faster_14message_faster_10Properties_2to___get__(struct __pyx_obj_19amqp10_codec_faster_14message_faster_Properties *__pyx_v_self) {
      PyObject *__pyx_r = NULL;
      __Pyx_XDECREF(__pyx_r);
      __Pyx_INCREF(__pyx_v_self->to);
      __pyx_r = __pyx_v_self->to;
      goto __pyx_L0;

      /* function exit code */
      __pyx_L0:;
      __Pyx_XGIVEREF(__pyx_r);
      __Pyx_RefNannyFinishContext();
      return __pyx_r;
    }

    /* Python wrapper */
    static int __pyx_pw_19amqp10_codec_faster_14message_faster_10Properties_2to_3__set__(PyObject *__pyx_v_self, PyObject *__pyx_v_value); /*proto*/
    static int __pyx_pw_19amqp10_codec_faster_14message_faster_10Properties_2to_3__set__(PyObject *__pyx_v_self, PyObject *__pyx_v_value) {
      CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
      int __pyx_r;
      __Pyx_RefNannyDeclarations
      __Pyx_RefNannySetupContext("__set__ (wrapper)", 0);
      __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
      __pyx_r = __pyx_pf_19amqp10_codec_faster_14message_faster_10Properties_2to_2__set__(((struct __pyx_obj_19amqp10_codec_faster_14message_faster_Properties *)__pyx_v_self), ((PyObject *)__pyx_v_value));

      /* function exit code */
      __Pyx_RefNannyFinishContext();
      return __pyx_r;
    }

    static int __pyx_pf_19amqp10_codec_faster_14message_faster_10Properties_2to_2__set__(struct __pyx_obj_19amqp10_codec_faster_14message_faster_Properties *__pyx_v_self, PyObject *__pyx_v_value) {
      int __pyx_r;
      __Pyx_INCREF(__pyx_v_value);
      __Pyx_GIVEREF(__pyx_v_value);
      __Pyx_GOTREF(__pyx_v_self->to);
      __Pyx_DECREF(__pyx_v_self->to);
      __pyx_v_self->to = __pyx_v_value;

      /* function exit code */
      __pyx_r = 0;
      __Pyx_RefNannyFinishContext();
      return __pyx_r;
    }

    /* Python wrapper */
    static int __pyx_pw_19amqp10_codec_faster_14message_faster_10Properties_2to_5__del__(PyObject *__pyx_v_self); /*proto*/
    static int __pyx_pw_19amqp10_codec_faster_14message_faster_10Properties_2to_5__del__(PyObject *__pyx_v_self) {
      CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
      int __pyx_r;
      __Pyx_RefNannyDeclarations
      __Pyx_RefNannySetupContext("__del__ (wrapper)", 0);
      __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
      __pyx_r = __pyx_pf_19amqp10_codec_faster_14message_faster_10Properties_2to_4__del__(((struct __pyx_obj_19amqp10_codec_faster_14message_faster_Properties *)__pyx_v_self));

      /* function exit code */
      __Pyx_RefNannyFinishContext();
      return __pyx_r;
    }

    static int __pyx_pf_19amqp10_codec_faster_14message_faster_10Properties_2to_4__del__(struct __pyx_obj_19amqp10_codec_faster_14message_faster_Properties *__pyx_v_self) {
      int __pyx_r;
      __Pyx_INCREF(Py_None);
      __Pyx_GIVEREF(Py_None);
      __Pyx_GOTREF(__pyx_v_self->to);
      __Pyx_DECREF(__pyx_v_self->to);
      __pyx_v_self->to = Py_None;

      /* function exit code */
      __pyx_r = 0;
      __Pyx_RefNannyFinishContext();
      return __pyx_r;
    }

    +146:         public object subject

    /* Python wrapper */
    static PyObject *__pyx_pw_19amqp10_codec_faster_14message_faster_10Properties_7subject_1__get__(PyObject *__pyx_v_self); /*proto*/
    static PyObject *__pyx_pw_19amqp10_codec_faster_14message_faster_10Properties_7subject_1__get__(PyObject *__pyx_v_self) {
      CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
      PyObject *__pyx_r = 0;
      __Pyx_RefNannyDeclarations
      __Pyx_RefNannySetupContext("__get__ (wrapper)", 0);
      __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
      __pyx_r = __pyx_pf_19amqp10_codec_faster_14message_faster_10Properties_7subject___get__(((struct __pyx_obj_19amqp10_codec_faster_14message_faster_Properties *)__pyx_v_self));

      /* function exit code */
      __Pyx_RefNannyFinishContext();
      return __pyx_r;
    }

    static PyObject *__pyx_pf_19amqp10_codec_faster_14message_faster_10Properties_7subject___get__(struct __pyx_obj_19amqp10_codec_faster_14message_faster_Properties *__pyx_v_self) {
      PyObject *__pyx_r = NULL;
      __Pyx_XDECREF(__pyx_r);
      __Pyx_INCREF(__pyx_v_self->subject);
      __pyx_r = __pyx_v_self->subject;
      goto __pyx_L0;

      /* function exit code */
      __pyx_L0:;
      __Pyx_XGIVEREF(__pyx_r);
      __Pyx_RefNannyFinishContext();
      return __pyx_r;
    }

    /* Python wrapper */
    static int __pyx_pw_19amqp10_codec_faster_14message_faster_10Properties_7subject_3__set__(PyObject *__pyx_v_self, PyObject *__pyx_v_value); /*proto*/
    static int __pyx_pw_19amqp10_codec_faster_14message_faster_10Properties_7subject_3__set__(PyObject *__pyx_v_self, PyObject *__pyx_v_value) {
      CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
      int __pyx_r;
      __Pyx_RefNannyDeclarations
      __Pyx_RefNannySetupContext("__set__ (wrapper)", 0);
      __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
      __pyx_r = __pyx_pf_19amqp10_codec_faster_14message_faster_10Properties_7subject_2__set__(((struct __pyx_obj_19amqp10_codec_faster_14message_faster_Properties *)__pyx_v_self), ((PyObject *)__pyx_v_value));

      /* function exit code */
      __Pyx_RefNannyFinishContext();
      return __pyx_r;
    }

    static int __pyx_pf_19amqp10_codec_faster_14message_faster_10Properties_7subject_2__set__(struct __pyx_obj_19amqp10_codec_faster_14message_faster_Properties *__pyx_v_self, PyObject *__pyx_v_value) {
      int __pyx_r;
      __Pyx_INCREF(__pyx_v_value);
      __Pyx_GIVEREF(__pyx_v_value);
      __Pyx_GOTREF(__pyx_v_self->subject);
      __Pyx_DECREF(__pyx_v_self->subject);
      __pyx_v_self->subject = __pyx_v_value;

      /* function exit code */
      __pyx_r = 0;
      __Pyx_RefNannyFinishContext();
      return __pyx_r;
    }

    /* Python wrapper */
    static int __pyx_pw_19amqp10_codec_faster_14message_faster_10Properties_7subject_5__del__(PyObject *__pyx_v_self); /*proto*/
    static int __pyx_pw_19amqp10_codec_faster_14message_faster_10Properties_7subject_5__del__(PyObject *__pyx_v_self) {
      CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
      int __pyx_r;
      __Pyx_RefNannyDeclarations
      __Pyx_RefNannySetupContext("__del__ (wrapper)", 0);
      __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
      __pyx_r = __pyx_pf_19amqp10_codec_faster_14message_faster_10Properties_7subject_4__del__(((struct __pyx_obj_19amqp10_codec_faster_14message_faster_Properties *)__pyx_v_self));

      /* function exit code */
      __Pyx_RefNannyFinishContext();
      return __pyx_r;
    }

    static int __pyx_pf_19amqp10_codec_faster_14message_faster_10Properties_7subject_4__del__(struct __pyx_obj_19amqp10_codec_faster_14message_faster_Properties *__pyx_v_self) {
      int __pyx_r;
      __Pyx_INCREF(Py_None);
      __Pyx_GIVEREF(Py_None);
      __Pyx_GOTREF(__pyx_v_self->subject);
      __Pyx_DECREF(__pyx_v_self->subject);
      __pyx_v_self->subject = Py_None;

      /* function exit code */
      __pyx_r = 0;
      __Pyx_RefNannyFinishContext();
      return __pyx_r;
    }

    +147:         public object reply_to

    /* Python wrapper */
    static PyObject *__pyx_pw_19amqp10_codec_faster_14message_faster_10Properties_8reply_to_1__get__(PyObject *__pyx_v_self); /*proto*/
    static PyObject *__pyx_pw_19amqp10_codec_faster_14message_faster_10Properties_8reply_to_1__get__(PyObject *__pyx_v_self) {
      CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
      PyObject *__pyx_r = 0;
      __Pyx_RefNannyDeclarations
      __Pyx_RefNannySetupContext("__get__ (wrapper)", 0);
      __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
      __pyx_r = __pyx_pf_19amqp10_codec_faster_14message_faster_10Properties_8reply_to___get__(((struct __pyx_obj_19amqp10_codec_faster_14message_faster_Properties *)__pyx_v_self));

      /* function exit code */
      __Pyx_RefNannyFinishContext();
      return __pyx_r;
    }

    static PyObject *__pyx_pf_19amqp10_codec_faster_14message_faster_10Properties_8reply_to___get__(struct __pyx_obj_19amqp10_codec_faster_14message_faster_Properties *__pyx_v_self) {
      PyObject *__pyx_r = NULL;
      __Pyx_XDECREF(__pyx_r);
      __Pyx_INCREF(__pyx_v_self->reply_to);
      __pyx_r = __pyx_v_self->reply_to;
      goto __pyx_L0;

      /* function exit code */
      __pyx_L0:;
      __Pyx_XGIVEREF(__pyx_r);
      __Pyx_RefNannyFinishContext();
      return __pyx_r;
    }

    /* Python wrapper */
    static int __pyx_pw_19amqp10_codec_faster_14message_faster_10Properties_8reply_to_3__set__(PyObject *__pyx_v_self, PyObject *__pyx_v_value); /*proto*/
    static int __pyx_pw_19amqp10_codec_faster_14message_faster_10Properties_8reply_to_3__set__(PyObject *__pyx_v_self, PyObject *__pyx_v_value) {
      CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
      int __pyx_r;
      __Pyx_RefNannyDeclarations
      __Pyx_RefNannySetupContext("__set__ (wrapper)", 0);
      __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
      __pyx_r = __pyx_pf_19amqp10_codec_faster_14message_faster_10Properties_8reply_to_2__set__(((struct __pyx_obj_19amqp10_codec_faster_14message_faster_Properties *)__pyx_v_self), ((PyObject *)__pyx_v_value));

      /* function exit code */
      __Pyx_RefNannyFinishContext();
      return __pyx_r;
    }

    static int __pyx_pf_19amqp10_codec_faster_14message_faster_10Properties_8reply_to_2__set__(struct __pyx_obj_19amqp10_codec_faster_14message_faster_Properties *__pyx_v_self, PyObject *__pyx_v_value) {
      int __pyx_r;
      __Pyx_INCREF(__pyx_v_value);
      __Pyx_GIVEREF(__pyx_v_value);
      __Pyx_GOTREF(__pyx_v_self->reply_to);
      __Pyx_DECREF(__pyx_v_self->reply_to);
      __pyx_v_self->reply_to = __pyx_v_value;

      /* function exit code */
      __pyx_r = 0;
      __Pyx_RefNannyFinishContext();
      return __pyx_r;
    }

    /* Python wrapper */
    static int __pyx_pw_19amqp10_codec_faster_14message_faster_10Properties_8reply_to_5__del__(PyObject *__pyx_v_self); /*proto*/
    static int __pyx_pw_19amqp10_codec_faster_14message_faster_10Properties_8reply_to_5__del__(PyObject *__pyx_v_self) {
      CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
      int __pyx_r;
      __Pyx_RefNannyDeclarations
      __Pyx_RefNannySetupContext("__del__ (wrapper)", 0);
      __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
      __pyx_r = __pyx_pf_19amqp10_codec_faster_14message_faster_10Properties_8reply_to_4__del__(((struct __pyx_obj_19amqp10_codec_faster_14message_faster_Properties *)__pyx_v_self));

      /* function exit code */
      __Pyx_RefNannyFinishContext();
      return __pyx_r;
    }

    static int __pyx_pf_19amqp10_codec_faster_14message_faster_10Properties_8reply_to_4__del__(struct __pyx_obj_19amqp10_codec_faster_14message_faster_Properties *__pyx_v_self) {
      int __pyx_r;
      __Pyx_INCREF(Py_None);
      __Pyx_GIVEREF(Py_None);
      __Pyx_GOTREF(__pyx_v_self->reply_to);
      __Pyx_DECREF(__pyx_v_self->reply_to);
      __pyx_v_self->reply_to = Py_None;

      /* function exit code */
      __pyx_r = 0;
      __Pyx_RefNannyFinishContext();
      return __pyx_r;
    }

    +148:         public object correlation_id

    /* Python wrapper */
    static PyObject *__pyx_pw_19amqp10_codec_faster_14message_faster_10Properties_14correlation_id_1__get__(PyObject *__pyx_v_self); /*proto*/
    static PyObject *__pyx_pw_19amqp10_codec_faster_14message_faster_10Properties_14correlation_id_1__get__(PyObject *__pyx_v_self) {
      CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
      PyObject *__pyx_r = 0;
      __Pyx_RefNannyDeclarations
      __Pyx_RefNannySetupContext("__get__ (wrapper)", 0);
      __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
      __pyx_r = __pyx_pf_19amqp10_codec_faster_14message_faster_10Properties_14correlation_id___get__(((struct __pyx_obj_19amqp10_codec_faster_14message_faster_Properties *)__pyx_v_self));

      /* function exit code */
      __Pyx_RefNannyFinishContext();
      return __pyx_r;
    }

    static PyObject *__pyx_pf_19amqp10_codec_faster_14message_faster_10Properties_14correlation_id___get__(struct __pyx_obj_19amqp10_codec_faster_14message_faster_Properties *__pyx_v_self) {
      PyObject *__pyx_r = NULL;
      __Pyx_XDECREF(__pyx_r);
      __Pyx_INCREF(__pyx_v_self->correlation_id);
      __pyx_r = __pyx_v_self->correlation_id;
      goto __pyx_L0;

      /* function exit code */
      __pyx_L0:;
      __Pyx_XGIVEREF(__pyx_r);
      __Pyx_RefNannyFinishContext();
      return __pyx_r;
    }

    /* Python wrapper */
    static int __pyx_pw_19amqp10_codec_faster_14message_faster_10Properties_14correlation_id_3__set__(PyObject *__pyx_v_self, PyObject *__pyx_v_value); /*proto*/
    static int __pyx_pw_19amqp10_codec_faster_14message_faster_10Properties_14correlation_id_3__set__(PyObject *__pyx_v_self, PyObject *__pyx_v_value) {
      CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
      int __pyx_r;
      __Pyx_RefNannyDeclarations
      __Pyx_RefNannySetupContext("__set__ (wrapper)", 0);
      __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
      __pyx_r = __pyx_pf_19amqp10_codec_faster_14message_faster_10Properties_14correlation_id_2__set__(((struct __pyx_obj_19amqp10_codec_faster_14message_faster_Properties *)__pyx_v_self), ((PyObject *)__pyx_v_value));

      /* function exit code */
      __Pyx_RefNannyFinishContext();
      return __pyx_r;
    }

    static int __pyx_pf_19amqp10_codec_faster_14message_faster_10Properties_14correlation_id_2__set__(struct __pyx_obj_19amqp10_codec_faster_14message_faster_Properties *__pyx_v_self, PyObject *__pyx_v_value) {
      int __pyx_r;
      __Pyx_INCREF(__pyx_v_value);
      __Pyx_GIVEREF(__pyx_v_value);
      __Pyx_GOTREF(__pyx_v_self->correlation_id);
      __Pyx_DECREF(__pyx_v_self->correlation_id);
      __pyx_v_self->correlation_id = __pyx_v_value;

      /* function exit code */
      __pyx_r = 0;
      __Pyx_RefNannyFinishContext();
      return __pyx_r;
    }

    /* Python wrapper */
    static int __pyx_pw_19amqp10_codec_faster_14message_faster_10Properties_14correlation_id_5__del__(PyObject *__pyx_v_self); /*proto*/
    static int __pyx_pw_19amqp10_codec_faster_14message_faster_10Properties_14correlation_id_5__del__(PyObject *__pyx_v_self) {
      CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
      int __pyx_r;
      __Pyx_RefNannyDeclarations
      __Pyx_RefNannySetupContext("__del__ (wrapper)", 0);
      __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
      __pyx_r = __pyx_pf_19amqp10_codec_faster_14message_faster_10Properties_14correlation_id_4__del__(((struct __pyx_obj_19amqp10_codec_faster_14message_faster_Properties *)__pyx_v_self));

      /* function exit code */
      __Pyx_RefNannyFinishContext();
      return __pyx_r;
    }

    static int __pyx_pf_19amqp10_codec_faster_14message_faster_10Properties_14correlation_id_4__del__(struct __pyx_obj_19amqp10_codec_faster_14message_faster_Properties *__pyx_v_self) {
      int __pyx_r;
      __Pyx_INCREF(Py_None);
      __Pyx_GIVEREF(Py_None);
      __Pyx_GOTREF(__pyx_v_self->correlation_id);
      __Pyx_DECREF(__pyx_v_self->correlation_id);
      __pyx_v_self->correlation_id = Py_None;

      /* function exit code */
      __pyx_r = 0;
      __Pyx_RefNannyFinishContext();
      return __pyx_r;
    }

    +149:         public object content_type

    /* Python wrapper */
    static PyObject *__pyx_pw_19amqp10_codec_faster_14message_faster_10Properties_12content_type_1__get__(PyObject *__pyx_v_self); /*proto*/
    static PyObject *__pyx_pw_19amqp10_codec_faster_14message_faster_10Properties_12content_type_1__get__(PyObject *__pyx_v_self) {
      CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
      PyObject *__pyx_r = 0;
      __Pyx_RefNannyDeclarations
      __Pyx_RefNannySetupContext("__get__ (wrapper)", 0);
      __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
      __pyx_r = __pyx_pf_19amqp10_codec_faster_14message_faster_10Properties_12content_type___get__(((struct __pyx_obj_19amqp10_codec_faster_14message_faster_Properties *)__pyx_v_self));

      /* function exit code */
      __Pyx_RefNannyFinishContext();
      return __pyx_r;
    }

    static PyObject *__pyx_pf_19amqp10_codec_faster_14message_faster_10Properties_12content_type___get__(struct __pyx_obj_19amqp10_codec_faster_14message_faster_Properties *__pyx_v_self) {
      PyObject *__pyx_r = NULL;
      __Pyx_XDECREF(__pyx_r);
      __Pyx_INCREF(__pyx_v_self->content_type);
      __pyx_r = __pyx_v_self->content_type;
      goto __pyx_L0;

      /* function exit code */
      __pyx_L0:;
      __Pyx_XGIVEREF(__pyx_r);
      __Pyx_RefNannyFinishContext();
      return __pyx_r;
    }

    /* Python wrapper */
    static int __pyx_pw_19amqp10_codec_faster_14message_faster_10Properties_12content_type_3__set__(PyObject *__pyx_v_self, PyObject *__pyx_v_value); /*proto*/
    static int __pyx_pw_19amqp10_codec_faster_14message_faster_10Properties_12content_type_3__set__(PyObject *__pyx_v_self, PyObject *__pyx_v_value) {
      CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
      int __pyx_r;
      __Pyx_RefNannyDeclarations
      __Pyx_RefNannySetupContext("__set__ (wrapper)", 0);
      __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
      __pyx_r = __pyx_pf_19amqp10_codec_faster_14message_faster_10Properties_12content_type_2__set__(((struct __pyx_obj_19amqp10_codec_faster_14message_faster_Properties *)__pyx_v_self), ((PyObject *)__pyx_v_value));

      /* function exit code */
      __Pyx_RefNannyFinishContext();
      return __pyx_r;
    }

    static int __pyx_pf_19amqp10_codec_faster_14message_faster_10Properties_12content_type_2__set__(struct __pyx_obj_19amqp10_codec_faster_14message_faster_Properties *__pyx_v_self, PyObject *__pyx_v_value) {
      int __pyx_r;
      __Pyx_INCREF(__pyx_v_value);
      __Pyx_GIVEREF(__pyx_v_value);
      __Pyx_GOTREF(__pyx_v_self->content_type);
      __Pyx_DECREF(__pyx_v_self->content_type);
      __pyx_v_self->content_type = __pyx_v_value;

      /* function exit code */
      __pyx_r = 0;
      __Pyx_RefNannyFinishContext();
      return __pyx_r;
    }

    /* Python wrapper */
    static int __pyx_pw_19amqp10_codec_faster_14message_faster_10Properties_12content_type_5__del__(PyObject *__pyx_v_self); /*proto*/
    static int __pyx_pw_19amqp10_codec_faster_14message_faster_10Properties_12content_type_5__del__(PyObject *__pyx_v_self) {
      CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
      int __pyx_r;
      __Pyx_RefNannyDeclarations
      __Pyx_RefNannySetupContext("__del__ (wrapper)", 0);
      __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
      __pyx_r = __pyx_pf_19amqp10_codec_faster_14message_faster_10Properties_12content_type_4__del__(((struct __pyx_obj_19amqp10_codec_faster_14message_faster_Properties *)__pyx_v_self));

      /* function exit code */
      __Pyx_RefNannyFinishContext();
      return __pyx_r;
    }

    static int __pyx_pf_19amqp10_codec_faster_14message_faster_10Properties_12content_type_4__del__(struct __pyx_obj_19amqp10_codec_faster_14message_faster_Properties *__pyx_v_self) {
      int __pyx_r;
      __Pyx_INCREF(Py_None);
      __Pyx_GIVEREF(Py_None);
      __Pyx_GOTREF(__pyx_v_self->content_type);
      __Pyx_DECREF(__pyx_v_self->content_type);
      __pyx_v_self->content_type = Py_None;

      /* function exit code */
      __pyx_r = 0;
      __Pyx_RefNannyFinishContext();
      return __pyx_r;
    }

    +150:         public object content_encoding

    /* Python wrapper */
    static PyObject *__pyx_pw_19amqp10_codec_faster_14message_faster_10Properties_16content_encoding_1__get__(PyObject *__pyx_v_self); /*proto*/
    static PyObject *__pyx_pw_19amqp10_codec_faster_14message_faster_10Properties_16content_encoding_1__get__(PyObject *__pyx_v_self) {
      CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
      PyObject *__pyx_r = 0;
      __Pyx_RefNannyDeclarations
      __Pyx_RefNannySetupContext("__get__ (wrapper)", 0);
      __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
      __pyx_r = __pyx_pf_19amqp10_codec_faster_14message_faster_10Properties_16content_encoding___get__(((struct __pyx_obj_19amqp10_codec_faster_14message_faster_Properties *)__pyx_v_self));

      /* function exit code */
      __Pyx_RefNannyFinishContext();
      return __pyx_r;
    }

    static PyObject *__pyx_pf_19amqp10_codec_faster_14message_faster_10Properties_16content_encoding___get__(struct __pyx_obj_19amqp10_codec_faster_14message_faster_Properties *__pyx_v_self) {
      PyObject *__pyx_r = NULL;
      __Pyx_XDECREF(__pyx_r);
      __Pyx_INCREF(__pyx_v_self->content_encoding);
      __pyx_r = __pyx_v_self->content_encoding;
      goto __pyx_L0;

      /* function exit code */
      __pyx_L0:;
      __Pyx_XGIVEREF(__pyx_r);
      __Pyx_RefNannyFinishContext();
      return __pyx_r;
    }

    /* Python wrapper */
    static int __pyx_pw_19amqp10_codec_faster_14message_faster_10Properties_16content_encoding_3__set__(PyObject *__pyx_v_self, PyObject *__pyx_v_value); /*proto*/
    static int __pyx_pw_19amqp10_codec_faster_14message_faster_10Properties_16content_encoding_3__set__(PyObject *__pyx_v_self, PyObject *__pyx_v_value) {
      CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
      int __pyx_r;
      __Pyx_RefNannyDeclarations
      __Pyx_RefNannySetupContext("__set__ (wrapper)", 0);
      __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
      __pyx_r = __pyx_pf_19amqp10_codec_faster_14message_faster_10Properties_16content_encoding_2__set__(((struct __pyx_obj_19amqp10_codec_faster_14message_faster_Properties *)__pyx_v_self), ((PyObject *)__pyx_v_value));

      /* function exit code */
      __Pyx_RefNannyFinishContext();
      return __pyx_r;
    }

    static int __pyx_pf_19amqp10_codec_faster_14message_faster_10Properties_16content_encoding_2__set__(struct __pyx_obj_19amqp10_codec_faster_14message_faster_Properties *__pyx_v_self, PyObject *__pyx_v_value) {
      int __pyx_r;
      __Pyx_INCREF(__pyx_v_value);
      __Pyx_GIVEREF(__pyx_v_value);
      __Pyx_GOTREF(__pyx_v_self->content_encoding);
      __Pyx_DECREF(__pyx_v_self->content_encoding);
      __pyx_v_self->content_encoding = __pyx_v_value;

      /* function exit code */
      __pyx_r = 0;
      __Pyx_RefNannyFinishContext();
      return __pyx_r;
    }

    /* Python wrapper */
    static int __pyx_pw_19amqp10_codec_faster_14message_faster_10Properties_16content_encoding_5__del__(PyObject *__pyx_v_self); /*proto*/
    static int __pyx_pw_19amqp10_codec_faster_14message_faster_10Properties_16content_encoding_5__del__(PyObject *__pyx_v_self) {
      CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
      int __pyx_r;
      __Pyx_RefNannyDeclarations
      __Pyx_RefNannySetupContext("__del__ (wrapper)", 0);
      __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
      __pyx_r = __pyx_pf_19amqp10_codec_faster_14message_faster_10Properties_16content_encoding_4__del__(((struct __pyx_obj_19amqp10_codec_faster_14message_faster_Properties *)__pyx_v_self));

      /* function exit code */
      __Pyx_RefNannyFinishContext();
      return __pyx_r;
    }

    static int __pyx_pf_19amqp10_codec_faster_14message_faster_10Properties_16content_encoding_4__del__(struct __pyx_obj_19amqp10_codec_faster_14message_faster_Properties *__pyx_v_self) {
      int __pyx_r;
      __Pyx_INCREF(Py_None);
      __Pyx_GIVEREF(Py_None);
      __Pyx_GOTREF(__pyx_v_self->content_encoding);
      __Pyx_DECREF(__pyx_v_self->content_encoding);
      __pyx_v_self->content_encoding = Py_None;

      /* function exit code */
      __pyx_r = 0;
      __Pyx_RefNannyFinishContext();
      return __pyx_r;
    }

    +151:         public object absolute_expiry_time

    /* Python wrapper */
    static PyObject *__pyx_pw_19amqp10_codec_faster_14message_faster_10Properties_20absolute_expiry_time_1__get__(PyObject *__pyx_v_self); /*proto*/
    static PyObject *__pyx_pw_19amqp10_codec_faster_14message_faster_10Properties_20absolute_expiry_time_1__get__(PyObject *__pyx_v_self) {
      CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
      PyObject *__pyx_r = 0;
      __Pyx_RefNannyDeclarations
      __Pyx_RefNannySetupContext("__get__ (wrapper)", 0);
      __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
      __pyx_r = __pyx_pf_19amqp10_codec_faster_14message_faster_10Properties_20absolute_expiry_time___get__(((struct __pyx_obj_19amqp10_codec_faster_14message_faster_Properties *)__pyx_v_self));

      /* function exit code */
      __Pyx_RefNannyFinishContext();
      return __pyx_r;
    }

    static PyObject *__pyx_pf_19amqp10_codec_faster_14message_faster_10Properties_20absolute_expiry_time___get__(struct __pyx_obj_19amqp10_codec_faster_14message_faster_Properties *__pyx_v_self) {
      PyObject *__pyx_r = NULL;
      __Pyx_XDECREF(__pyx_r);
      __Pyx_INCREF(__pyx_v_self->absolute_expiry_time);
      __pyx_r = __pyx_v_self->absolute_expiry_time;
      goto __pyx_L0;

      /* function exit code */
      __pyx_L0:;
      __Pyx_XGIVEREF(__pyx_r);
      __Pyx_RefNannyFinishContext();
      return __pyx_r;
    }

    /* Python wrapper */
    static int __pyx_pw_19amqp10_codec_faster_14message_faster_10Properties_20absolute_expiry_time_3__set__(PyObject *__pyx_v_self, PyObject *__pyx_v_value); /*proto*/
    static int __pyx_pw_19amqp10_codec_faster_14message_faster_10Properties_20absolute_expiry_time_3__set__(PyObject *__pyx_v_self, PyObject *__pyx_v_value) {
      CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
      int __pyx_r;
      __Pyx_RefNannyDeclarations
      __Pyx_RefNannySetupContext("__set__ (wrapper)", 0);
      __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
      __pyx_r = __pyx_pf_19amqp10_codec_faster_14message_faster_10Properties_20absolute_expiry_time_2__set__(((struct __pyx_obj_19amqp10_codec_faster_14message_faster_Properties *)__pyx_v_self), ((PyObject *)__pyx_v_value));

      /* function exit code */
      __Pyx_RefNannyFinishContext();
      return __pyx_r;
    }

    static int __pyx_pf_19amqp10_codec_faster_14message_faster_10Properties_20absolute_expiry_time_2__set__(struct __pyx_obj_19amqp10_codec_faster_14message_faster_Properties *__pyx_v_self, PyObject *__pyx_v_value) {
      int __pyx_r;
      __Pyx_INCREF(__pyx_v_value);
      __Pyx_GIVEREF(__pyx_v_value);
      __Pyx_GOTREF(__pyx_v_self->absolute_expiry_time);
      __Pyx_DECREF(__pyx_v_self->absolute_expiry_time);
      __pyx_v_self->absolute_expiry_time = __pyx_v_value;

      /* function exit code */
      __pyx_r = 0;
      __Pyx_RefNannyFinishContext();
      return __pyx_r;
    }

    /* Python wrapper */
    static int __pyx_pw_19amqp10_codec_faster_14message_faster_10Properties_20absolute_expiry_time_5__del__(PyObject *__pyx_v_self); /*proto*/
    static int __pyx_pw_19amqp10_codec_faster_14message_faster_10Properties_20absolute_expiry_time_5__del__(PyObject *__pyx_v_self) {
      CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
      int __pyx_r;
      __Pyx_RefNannyDeclarations
      __Pyx_RefNannySetupContext("__del__ (wrapper)", 0);
      __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
      __pyx_r = __pyx_pf_19amqp10_codec_faster_14message_faster_10Properties_20absolute_expiry_time_4__del__(((struct __pyx_obj_19amqp10_codec_faster_14message_faster_Properties *)__pyx_v_self));

      /* function exit code */
      __Pyx_RefNannyFinishContext();
      return __pyx_r;
    }

    static int __pyx_pf_19amqp10_codec_faster_14message_faster_10Properties_20absolute_expiry_time_4__del__(struct __pyx_obj_19amqp10_codec_faster_14message_faster_Properties *__pyx_v_self) {
      int __pyx_r;
      __Pyx_INCREF(Py_None);
      __Pyx_GIVEREF(Py_None);
      __Pyx_GOTREF(__pyx_v_self->absolute_expiry_time);
      __Pyx_DECREF(__pyx_v_self->absolute_expiry_time);
      __pyx_v_self->absolute_expiry_time = Py_None;

      /* function exit code */
      __pyx_r = 0;
      __Pyx_RefNannyFinishContext();
      return __pyx_r;
    }

    +152:         public object creation_time

    /* Python wrapper */
    static PyObject *__pyx_pw_19amqp10_codec_faster_14message_faster_10Properties_13creation_time_1__get__(PyObject *__pyx_v_self); /*proto*/
    static PyObject *__pyx_pw_19amqp10_codec_faster_14message_faster_10Properties_13creation_time_1__get__(PyObject *__pyx_v_self) {
      CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
      PyObject *__pyx_r = 0;
      __Pyx_RefNannyDeclarations
      __Pyx_RefNannySetupContext("__get__ (wrapper)", 0);
      __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
      __pyx_r = __pyx_pf_19amqp10_codec_faster_14message_faster_10Properties_13creation_time___get__(((struct __pyx_obj_19amqp10_codec_faster_14message_faster_Properties *)__pyx_v_self));

      /* function exit code */
      __Pyx_RefNannyFinishContext();
      return __pyx_r;
    }

    static PyObject *__pyx_pf_19amqp10_codec_faster_14message_faster_10Properties_13creation_time___get__(struct __pyx_obj_19amqp10_codec_faster_14message_faster_Properties *__pyx_v_self) {
      PyObject *__pyx_r = NULL;
      __Pyx_XDECREF(__pyx_r);
      __Pyx_INCREF(__pyx_v_self->creation_time);
      __pyx_r = __pyx_v_self->creation_time;
      goto __pyx_L0;

      /* function exit code */
      __pyx_L0:;
      __Pyx_XGIVEREF(__pyx_r);
      __Pyx_RefNannyFinishContext();
      return __pyx_r;
    }

    /* Python wrapper */
    static int __pyx_pw_19amqp10_codec_faster_14message_faster_10Properties_13creation_time_3__set__(PyObject *__pyx_v_self, PyObject *__pyx_v_value); /*proto*/
    static int __pyx_pw_19amqp10_codec_faster_14message_faster_10Properties_13creation_time_3__set__(PyObject *__pyx_v_self, PyObject *__pyx_v_value) {
      CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
      int __pyx_r;
      __Pyx_RefNannyDeclarations
      __Pyx_RefNannySetupContext("__set__ (wrapper)", 0);
      __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
      __pyx_r = __pyx_pf_19amqp10_codec_faster_14message_faster_10Properties_13creation_time_2__set__(((struct __pyx_obj_19amqp10_codec_faster_14message_faster_Properties *)__pyx_v_self), ((PyObject *)__pyx_v_value));

      /* function exit code */
      __Pyx_RefNannyFinishContext();
      return __pyx_r;
    }

    static int __pyx_pf_19amqp10_codec_faster_14message_faster_10Properties_13creation_time_2__set__(struct __pyx_obj_19amqp10_codec_faster_14message_faster_Properties *__pyx_v_self, PyObject *__pyx_v_value) {
      int __pyx_r;
      __Pyx_INCREF(__pyx_v_value);
      __Pyx_GIVEREF(__pyx_v_value);
      __Pyx_GOTREF(__pyx_v_self->creation_time);
      __Pyx_DECREF(__pyx_v_self->creation_time);
      __pyx_v_self->creation_time = __pyx_v_value;

      /* function exit code */
      __pyx_r = 0;
      __Pyx_RefNannyFinishContext();
      return __pyx_r;
    }

    /* Python wrapper */
    static int __pyx_pw_19amqp10_codec_faster_14message_faster_10Properties_13creation_time_5__del__(PyObject *__pyx_v_self); /*proto*/
    static int __pyx_pw_19amqp10_codec_faster_14message_faster_10Properties_13creation_time_5__del__(PyObject *__pyx_v_self) {
      CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
      int __pyx_r;
      __Pyx_RefNannyDeclarations
      __Pyx_RefNannySetupContext("__del__ (wrapper)", 0);
      __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
      __pyx_r = __pyx_pf_19amqp10_codec_faster_14message_faster_10Properties_13creation_time_4__del__(((struct __pyx_obj_19amqp10_codec_faster_14message_faster_Properties *)__pyx_v_self));

      /* function exit code */
      __Pyx_RefNannyFinishContext();
      return __pyx_r;
    }

    static int __pyx_pf_19amqp10_codec_faster_14message_faster_10Properties_13creation_time_4__del__(struct __pyx_obj_19amqp10_codec_faster_14message_faster_Properties *__pyx_v_self) {
      int __pyx_r;
      __Pyx_INCREF(Py_None);
      __Pyx_GIVEREF(Py_None);
      __Pyx_GOTREF(__pyx_v_self->creation_time);
      __Pyx_DECREF(__pyx_v_self->creation_time);
      __pyx_v_self->creation_time = Py_None;

      /* function exit code */
      __pyx_r = 0;
      __Pyx_RefNannyFinishContext();
      return __pyx_r;
    }

    +153:         public object group_id

    /* Python wrapper */
    static PyObject *__pyx_pw_19amqp10_codec_faster_14message_faster_10Properties_8group_id_1__get__(PyObject *__pyx_v_self); /*proto*/
    static PyObject *__pyx_pw_19amqp10_codec_faster_14message_faster_10Properties_8group_id_1__get__(PyObject *__pyx_v_self) {
      CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
      PyObject *__pyx_r = 0;
      __Pyx_RefNannyDeclarations
      __Pyx_RefNannySetupContext("__get__ (wrapper)", 0);
      __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
      __pyx_r = __pyx_pf_19amqp10_codec_faster_14message_faster_10Properties_8group_id___get__(((struct __pyx_obj_19amqp10_codec_faster_14message_faster_Properties *)__pyx_v_self));

      /* function exit code */
      __Pyx_RefNannyFinishContext();
      return __pyx_r;
    }

    static PyObject *__pyx_pf_19amqp10_codec_faster_14message_faster_10Properties_8group_id___get__(struct __pyx_obj_19amqp10_codec_faster_14message_faster_Properties *__pyx_v_self) {
      PyObject *__pyx_r = NULL;
      __Pyx_XDECREF(__pyx_r);
      __Pyx_INCREF(__pyx_v_self->group_id);
      __pyx_r = __pyx_v_self->group_id;
      goto __pyx_L0;

      /* function exit code */
      __pyx_L0:;
      __Pyx_XGIVEREF(__pyx_r);
      __Pyx_RefNannyFinishContext();
      return __pyx_r;
    }

    /* Python wrapper */
    static int __pyx_pw_19amqp10_codec_faster_14message_faster_10Properties_8group_id_3__set__(PyObject *__pyx_v_self, PyObject *__pyx_v_value); /*proto*/
    static int __pyx_pw_19amqp10_codec_faster_14message_faster_10Properties_8group_id_3__set__(PyObject *__pyx_v_self, PyObject *__pyx_v_value) {
      CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
      int __pyx_r;
      __Pyx_RefNannyDeclarations
      __Pyx_RefNannySetupContext("__set__ (wrapper)", 0);
      __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
      __pyx_r = __pyx_pf_19amqp10_codec_faster_14message_faster_10Properties_8group_id_2__set__(((struct __pyx_obj_19amqp10_codec_faster_14message_faster_Properties *)__pyx_v_self), ((PyObject *)__pyx_v_value));

      /* function exit code */
      __Pyx_RefNannyFinishContext();
      return __pyx_r;
    }

    static int __pyx_pf_19amqp10_codec_faster_14message_faster_10Properties_8group_id_2__set__(struct __pyx_obj_19amqp10_codec_faster_14message_faster_Properties *__pyx_v_self, PyObject *__pyx_v_value) {
      int __pyx_r;
      __Pyx_INCREF(__pyx_v_value);
      __Pyx_GIVEREF(__pyx_v_value);
      __Pyx_GOTREF(__pyx_v_self->group_id);
      __Pyx_DECREF(__pyx_v_self->group_id);
      __pyx_v_self->group_id = __pyx_v_value;

      /* function exit code */
      __pyx_r = 0;
      __Pyx_RefNannyFinishContext();
      return __pyx_r;
    }

    /* Python wrapper */
    static int __pyx_pw_19amqp10_codec_faster_14message_faster_10Properties_8group_id_5__del__(PyObject *__pyx_v_self); /*proto*/
    static int __pyx_pw_19amqp10_codec_faster_14message_faster_10Properties_8group_id_5__del__(PyObject *__pyx_v_self) {
      CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
      int __pyx_r;
      __Pyx_RefNannyDeclarations
      __Pyx_RefNannySetupContext("__del__ (wrapper)", 0);
      __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
      __pyx_r = __pyx_pf_19amqp10_codec_faster_14message_faster_10Properties_8group_id_4__del__(((struct __pyx_obj_19amqp10_codec_faster_14message_faster_Properties *)__pyx_v_self));

      /* function exit code */
      __Pyx_RefNannyFinishContext();
      return __pyx_r;
    }

    static int __pyx_pf_19amqp10_codec_faster_14message_faster_10Properties_8group_id_4__del__(struct __pyx_obj_19amqp10_codec_faster_14message_faster_Properties *__pyx_v_self) {
      int __pyx_r;
      __Pyx_INCREF(Py_None);
      __Pyx_GIVEREF(Py_None);
      __Pyx_GOTREF(__pyx_v_self->group_id);
      __Pyx_DECREF(__pyx_v_self->group_id);
      __pyx_v_self->group_id = Py_None;

      /* function exit code */
      __pyx_r = 0;
      __Pyx_RefNannyFinishContext();
      return __pyx_r;
    }

    +154:         public object group_sequence

    /* Python wrapper */
    static PyObject *__pyx_pw_19amqp10_codec_faster_14message_faster_10Properties_14group_sequence_1__get__(PyObject *__pyx_v_self); /*proto*/
    static PyObject *__pyx_pw_19amqp10_codec_faster_14message_faster_10Properties_14group_sequence_1__get__(PyObject *__pyx_v_self) {
      CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
      PyObject *__pyx_r = 0;
      __Pyx_RefNannyDeclarations
      __Pyx_RefNannySetupContext("__get__ (wrapper)", 0);
      __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
      __pyx_r = __pyx_pf_19amqp10_codec_faster_14message_faster_10Properties_14group_sequence___get__(((struct __pyx_obj_19amqp10_codec_faster_14message_faster_Properties *)__pyx_v_self));

      /* function exit code */
      __Pyx_RefNannyFinishContext();
      return __pyx_r;
    }

    static PyObject *__pyx_pf_19amqp10_codec_faster_14message_faster_10Properties_14group_sequence___get__(struct __pyx_obj_19amqp10_codec_faster_14message_faster_Properties *__pyx_v_self) {
      PyObject *__pyx_r = NULL;
      __Pyx_XDECREF(__pyx_r);
      __Pyx_INCREF(__pyx_v_self->group_sequence);
      __pyx_r = __pyx_v_self->group_sequence;
      goto __pyx_L0;

      /* function exit code */
      __pyx_L0:;
      __Pyx_XGIVEREF(__pyx_r);
      __Pyx_RefNannyFinishContext();
      return __pyx_r;
    }

    /* Python wrapper */
    static int __pyx_pw_19amqp10_codec_faster_14message_faster_10Properties_14group_sequence_3__set__(PyObject *__pyx_v_self, PyObject *__pyx_v_value); /*proto*/
    static int __pyx_pw_19amqp10_codec_faster_14message_faster_10Properties_14group_sequence_3__set__(PyObject *__pyx_v_self, PyObject *__pyx_v_value) {
      CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
      int __pyx_r;
      __Pyx_RefNannyDeclarations
      __Pyx_RefNannySetupContext("__set__ (wrapper)", 0);
      __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
      __pyx_r = __pyx_pf_19amqp10_codec_faster_14message_faster_10Properties_14group_sequence_2__set__(((struct __pyx_obj_19amqp10_codec_faster_14message_faster_Properties *)__pyx_v_self), ((PyObject *)__pyx_v_value));

      /* function exit code */
      __Pyx_RefNannyFinishContext();
      return __pyx_r;
    }

    static int __pyx_pf_19amqp10_codec_faster_14message_faster_10Properties_14group_sequence_2__set__(struct __pyx_obj_19amqp10_codec_faster_14message_faster_Properties *__pyx_v_self, PyObject *__pyx_v_value) {
      int __pyx_r;
      __Pyx_INCREF(__pyx_v_value);
      __Pyx_GIVEREF(__pyx_v_value);
      __Pyx_GOTREF(__pyx_v_self->group_sequence);
      __Pyx_DECREF(__pyx_v_self->group_sequence);
      __pyx_v_self->group_sequence = __pyx_v_value;

      /* function exit code */
      __pyx_r = 0;
      __Pyx_RefNannyFinishContext();
      return __pyx_r;
    }

    /* Python wrapper */
    static int __pyx_pw_19amqp10_codec_faster_14message_faster_10Properties_14group_sequence_5__del__(PyObject *__pyx_v_self); /*proto*/
    static int __pyx_pw_19amqp10_codec_faster_14message_faster_10Properties_14group_sequence_5__del__(PyObject *__pyx_v_self) {
      CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
      int __pyx_r;
      __Pyx_RefNannyDeclarations
      __Pyx_RefNannySetupContext("__del__ (wrapper)", 0);
      __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
      __pyx_r = __pyx_pf_19amqp10_codec_faster_14message_faster_10Properties_14group_sequence_4__del__(((struct __pyx_obj_19amqp10_codec_faster_14message_faster_Properties *)__pyx_v_self));

      /* function exit code */
      __Pyx_RefNannyFinishContext();
      return __pyx_r;
    }

    static int __pyx_pf_19amqp10_codec_faster_14message_faster_10Properties_14group_sequence_4__del__(struct __pyx_obj_19amqp10_codec_faster_14message_faster_Properties *__pyx_v_self) {
      int __pyx_r;
      __Pyx_INCREF(Py_None);
      __Pyx_GIVEREF(Py_None);
      __Pyx_GOTREF(__pyx_v_self->group_sequence);
      __Pyx_DECREF(__pyx_v_self->group_sequence);
      __pyx_v_self->group_sequence = Py_None;

      /* function exit code */
      __pyx_r = 0;
      __Pyx_RefNannyFinishContext();
      return __pyx_r;
    }

    +155:         public object reply_to_group_id

    /* Python wrapper */
    static PyObject *__pyx_pw_19amqp10_codec_faster_14message_faster_10Properties_17reply_to_group_id_1__get__(PyObject *__pyx_v_self); /*proto*/
    static PyObject *__pyx_pw_19amqp10_codec_faster_14message_faster_10Properties_17reply_to_group_id_1__get__(PyObject *__pyx_v_self) {
      CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
      PyObject *__pyx_r = 0;
      __Pyx_RefNannyDeclarations
      __Pyx_RefNannySetupContext("__get__ (wrapper)", 0);
      __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
      __pyx_r = __pyx_pf_19amqp10_codec_faster_14message_faster_10Properties_17reply_to_group_id___get__(((struct __pyx_obj_19amqp10_codec_faster_14message_faster_Properties *)__pyx_v_self));

      /* function exit code */
      __Pyx_RefNannyFinishContext();
      return __pyx_r;
    }

    static PyObject *__pyx_pf_19amqp10_codec_faster_14message_faster_10Properties_17reply_to_group_id___get__(struct __pyx_obj_19amqp10_codec_faster_14message_faster_Properties *__pyx_v_self) {
      PyObject *__pyx_r = NULL;
      __Pyx_XDECREF(__pyx_r);
      __Pyx_INCREF(__pyx_v_self->reply_to_group_id);
      __pyx_r = __pyx_v_self->reply_to_group_id;
      goto __pyx_L0;

      /* function exit code */
      __pyx_L0:;
      __Pyx_XGIVEREF(__pyx_r);
      __Pyx_RefNannyFinishContext();
      return __pyx_r;
    }

    /* Python wrapper */
    static int __pyx_pw_19amqp10_codec_faster_14message_faster_10Properties_17reply_to_group_id_3__set__(PyObject *__pyx_v_self, PyObject *__pyx_v_value); /*proto*/
    static int __pyx_pw_19amqp10_codec_faster_14message_faster_10Properties_17reply_to_group_id_3__set__(PyObject *__pyx_v_self, PyObject *__pyx_v_value) {
      CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
      int __pyx_r;
      __Pyx_RefNannyDeclarations
      __Pyx_RefNannySetupContext("__set__ (wrapper)", 0);
      __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
      __pyx_r = __pyx_pf_19amqp10_codec_faster_14message_faster_10Properties_17reply_to_group_id_2__set__(((struct __pyx_obj_19amqp10_codec_faster_14message_faster_Properties *)__pyx_v_self), ((PyObject *)__pyx_v_value));

      /* function exit code */
      __Pyx_RefNannyFinishContext();
      return __pyx_r;
    }

    static int __pyx_pf_19amqp10_codec_faster_14message_faster_10Properties_17reply_to_group_id_2__set__(struct __pyx_obj_19amqp10_codec_faster_14message_faster_Properties *__pyx_v_self, PyObject *__pyx_v_value) {
      int __pyx_r;
      __Pyx_INCREF(__pyx_v_value);
      __Pyx_GIVEREF(__pyx_v_value);
      __Pyx_GOTREF(__pyx_v_self->reply_to_group_id);
      __Pyx_DECREF(__pyx_v_self->reply_to_group_id);
      __pyx_v_self->reply_to_group_id = __pyx_v_value;

      /* function exit code */
      __pyx_r = 0;
      __Pyx_RefNannyFinishContext();
      return __pyx_r;
    }

    /* Python wrapper */
    static int __pyx_pw_19amqp10_codec_faster_14message_faster_10Properties_17reply_to_group_id_5__del__(PyObject *__pyx_v_self); /*proto*/
    static int __pyx_pw_19amqp10_codec_faster_14message_faster_10Properties_17reply_to_group_id_5__del__(PyObject *__pyx_v_self) {
      CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
      int __pyx_r;
      __Pyx_RefNannyDeclarations
      __Pyx_RefNannySetupContext("__del__ (wrapper)", 0);
      __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
      __pyx_r = __pyx_pf_19amqp10_codec_faster_14message_faster_10Properties_17reply_to_group_id_4__del__(((struct __pyx_obj_19amqp10_codec_faster_14message_faster_Properties *)__pyx_v_self));

      /* function exit code */
      __Pyx_RefNannyFinishContext();
      return __pyx_r;
    }

    static int __pyx_pf_19amqp10_codec_faster_14message_faster_10Properties_17reply_to_group_id_4__del__(struct __pyx_obj_19amqp10_codec_faster_14message_faster_Properties *__pyx_v_self) {
      int __pyx_r;
      __Pyx_INCREF(Py_None);
      __Pyx_GIVEREF(Py_None);
      __Pyx_GOTREF(__pyx_v_self->reply_to_group_id);
      __Pyx_DECREF(__pyx_v_self->reply_to_group_id);
      __pyx_v_self->reply_to_group_id = Py_None;

      /* function exit code */
      __pyx_r = 0;
      __Pyx_RefNannyFinishContext();
      return __pyx_r;
    }

     156:

    +157:     def __init__(

    /* Python wrapper */
    static int __pyx_pw_19amqp10_codec_faster_14message_faster_10Properties_1__init__(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
    static int __pyx_pw_19amqp10_codec_faster_14message_faster_10Properties_1__init__(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
      CYTHON_UNUSED Py_ssize_t __pyx_nargs;
      CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
      int __pyx_r;
      __Pyx_RefNannyDeclarations
      __Pyx_RefNannySetupContext("__init__ (wrapper)", 0);
      #if CYTHON_ASSUME_SAFE_MACROS
      __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
      #else
      __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return -1;
      #endif
      __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
      if (unlikely(__pyx_nargs > 0)) {
        __Pyx_RaiseArgtupleInvalid("__init__", 1, 0, 0, __pyx_nargs); return -1;}
      if (unlikely(__pyx_kwds) && __Pyx_NumKwargs_VARARGS(__pyx_kwds) && unlikely(!__Pyx_CheckKeywordStrings(__pyx_kwds, "__init__", 0))) return -1;
      __pyx_r = __pyx_pf_19amqp10_codec_faster_14message_faster_10Properties___init__(((struct __pyx_obj_19amqp10_codec_faster_14message_faster_Properties *)__pyx_v_self));

      /* function exit code */
      __Pyx_RefNannyFinishContext();
      return __pyx_r;
    }

    static int __pyx_pf_19amqp10_codec_faster_14message_faster_10Properties___init__(struct __pyx_obj_19amqp10_codec_faster_14message_faster_Properties *__pyx_v_self) {
      int __pyx_r;
    /* … */
      /* function exit code */
      __pyx_r = 0;
      __Pyx_RefNannyFinishContext();
      return __pyx_r;
    }

     158:         self,

     159:     ):

    +160:         self.message_id = None

      __Pyx_INCREF(Py_None);
      __Pyx_GIVEREF(Py_None);
      __Pyx_GOTREF(__pyx_v_self->message_id);
      __Pyx_DECREF(__pyx_v_self->message_id);
      __pyx_v_self->message_id = Py_None;

    +161:         self.user_id = None

      __Pyx_INCREF(Py_None);
      __Pyx_GIVEREF(Py_None);
      __Pyx_GOTREF(__pyx_v_self->user_id);
      __Pyx_DECREF(__pyx_v_self->user_id);
      __pyx_v_self->user_id = Py_None;

    +162:         self.to = None

      __Pyx_INCREF(Py_None);
      __Pyx_GIVEREF(Py_None);
      __Pyx_GOTREF(__pyx_v_self->to);
      __Pyx_DECREF(__pyx_v_self->to);
      __pyx_v_self->to = Py_None;

    +163:         self.subject = None

      __Pyx_INCREF(Py_None);
      __Pyx_GIVEREF(Py_None);
      __Pyx_GOTREF(__pyx_v_self->subject);
      __Pyx_DECREF(__pyx_v_self->subject);
      __pyx_v_self->subject = Py_None;

    +164:         self.reply_to = None

      __Pyx_INCREF(Py_None);
      __Pyx_GIVEREF(Py_None);
      __Pyx_GOTREF(__pyx_v_self->reply_to);
      __Pyx_DECREF(__pyx_v_self->reply_to);
      __pyx_v_self->reply_to = Py_None;

    +165:         self.correlation_id = None

      __Pyx_INCREF(Py_None);
      __Pyx_GIVEREF(Py_None);
      __Pyx_GOTREF(__pyx_v_self->correlation_id);
      __Pyx_DECREF(__pyx_v_self->correlation_id);
      __pyx_v_self->correlation_id = Py_None;

    +166:         self.content_type = None

      __Pyx_INCREF(Py_None);
      __Pyx_GIVEREF(Py_None);
      __Pyx_GOTREF(__pyx_v_self->content_type);
      __Pyx_DECREF(__pyx_v_self->content_type);
      __pyx_v_self->content_type = Py_None;

    +167:         self.content_encoding = None

      __Pyx_INCREF(Py_None);
      __Pyx_GIVEREF(Py_None);
      __Pyx_GOTREF(__pyx_v_self->content_encoding);
      __Pyx_DECREF(__pyx_v_self->content_encoding);
      __pyx_v_self->content_encoding = Py_None;

    +168:         self.absolute_expiry_time = None

      __Pyx_INCREF(Py_None);
      __Pyx_GIVEREF(Py_None);
      __Pyx_GOTREF(__pyx_v_self->absolute_expiry_time);
      __Pyx_DECREF(__pyx_v_self->absolute_expiry_time);
      __pyx_v_self->absolute_expiry_time = Py_None;

    +169:         self.creation_time = None

      __Pyx_INCREF(Py_None);
      __Pyx_GIVEREF(Py_None);
      __Pyx_GOTREF(__pyx_v_self->creation_time);
      __Pyx_DECREF(__pyx_v_self->creation_time);
      __pyx_v_self->creation_time = Py_None;

    +170:         self.group_id = None

      __Pyx_INCREF(Py_None);
      __Pyx_GIVEREF(Py_None);
      __Pyx_GOTREF(__pyx_v_self->group_id);
      __Pyx_DECREF(__pyx_v_self->group_id);
      __pyx_v_self->group_id = Py_None;

    +171:         self.group_sequence = None

      __Pyx_INCREF(Py_None);
      __Pyx_GIVEREF(Py_None);
      __Pyx_GOTREF(__pyx_v_self->group_sequence);
      __Pyx_DECREF(__pyx_v_self->group_sequence);
      __pyx_v_self->group_sequence = Py_None;

    +172:         self.reply_to_group_id = None

      __Pyx_INCREF(Py_None);
      __Pyx_GIVEREF(Py_None);
      __Pyx_GOTREF(__pyx_v_self->reply_to_group_id);
      __Pyx_DECREF(__pyx_v_self->reply_to_group_id);
      __pyx_v_self->reply_to_group_id = Py_None;

     173:

     174:

    +175:     cdef Properties parse(self, unsigned char *buffer, Py_ssize_t *offset):

    static struct __pyx_obj_19amqp10_codec_faster_14message_faster_Properties *__pyx_f_19amqp10_codec_faster_14message_faster_10Properties_parse(CYTHON_UNUSED struct __pyx_obj_19amqp10_codec_faster_14message_faster_Properties *__pyx_v_self, unsigned char *__pyx_v_buffer, Py_ssize_t *__pyx_v_offset) {
      uint32_t __pyx_v_fields;
      unsigned char __pyx_v_value;
      struct __pyx_obj_19amqp10_codec_faster_14message_faster_Properties *__pyx_v_p = NULL;
      long __pyx_v_index;
      struct __pyx_obj_19amqp10_codec_faster_14message_faster_Properties *__pyx_r = NULL;
    /* … */
      /* function exit code */
      __pyx_L1_error:;
      __Pyx_XDECREF(__pyx_t_2);
      __Pyx_AddTraceback("amqp10_codec_faster.message_faster.Properties.parse", __pyx_clineno, __pyx_lineno, __pyx_filename);
      __pyx_r = 0;
      __pyx_L0:;
      __Pyx_XDECREF((PyObject *)__pyx_v_p);
      __Pyx_XGIVEREF((PyObject *)__pyx_r);
      __Pyx_RefNannyFinishContext();
      return __pyx_r;
    }

    +176:         cdef uint32_t fields = read_composite_header(buffer, offset)

      __pyx_t_1 = __pyx_f_19amqp10_codec_faster_14message_faster_read_composite_header(__pyx_v_buffer, __pyx_v_offset); if (unlikely(__pyx_t_1 == ((uint32_t)-1) && PyErr_Occurred())) __PYX_ERR(0, 176, __pyx_L1_error)
      __pyx_v_fields = __pyx_t_1;

     177:         cdef unsigned char value

    +178:         p = Properties()

      __pyx_t_2 = __Pyx_PyObject_CallNoArg(((PyObject *)__pyx_ptype_19amqp10_codec_faster_14message_faster_Properties)); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 178, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_2);
      __pyx_v_p = ((struct __pyx_obj_19amqp10_codec_faster_14message_faster_Properties *)__pyx_t_2);
      __pyx_t_2 = 0;

    +179:         for index in range(0, fields, 1):

      __pyx_t_1 = __pyx_v_fields;
      __pyx_t_3 = __pyx_t_1;
      for (__pyx_t_4 = 0; __pyx_t_4 < __pyx_t_3; __pyx_t_4+=1) {
        __pyx_v_index = __pyx_t_4;

    +180:             value = buffer[offset[0]]

        __pyx_v_value = (__pyx_v_buffer[(__pyx_v_offset[0])]);

     181:

    +182:             if value == 0x40: # Null

        __pyx_t_5 = (__pyx_v_value == 0x40);
        if (__pyx_t_5) {
    /* … */
          goto __pyx_L5;
        }

    +183:                 offset[0] += 1

          __pyx_t_6 = 0;
          (__pyx_v_offset[__pyx_t_6]) = ((__pyx_v_offset[__pyx_t_6]) + 1);

     184:             else:

    +185:                 if index == 0:

        /*else*/ {
    /* … */
          switch (__pyx_v_index) {
            case 0:
    /* … */
            break;
            case 1:

    +186:                     p.message_id = read_any(buffer, offset)

            __pyx_t_2 = __pyx_f_19amqp10_codec_faster_14message_faster_read_any(__pyx_v_buffer, __pyx_v_offset); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 186, __pyx_L1_error)
            __Pyx_GOTREF(__pyx_t_2);
            __Pyx_GIVEREF(__pyx_t_2);
            __Pyx_GOTREF(__pyx_v_p->message_id);
            __Pyx_DECREF(__pyx_v_p->message_id);
            __pyx_v_p->message_id = __pyx_t_2;
            __pyx_t_2 = 0;

    +187:                 elif index == 1:

            break;
            case 2:

    +188:                     p.user_id = read_application_data(buffer, offset)

            __pyx_t_2 = __pyx_f_19amqp10_codec_faster_14message_faster_read_application_data(__pyx_v_buffer, __pyx_v_offset); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 188, __pyx_L1_error)
            __Pyx_GOTREF(__pyx_t_2);
            __Pyx_GIVEREF(__pyx_t_2);
            __Pyx_GOTREF(__pyx_v_p->user_id);
            __Pyx_DECREF(__pyx_v_p->user_id);
            __pyx_v_p->user_id = __pyx_t_2;
            __pyx_t_2 = 0;

    +189:                 elif index == 2:

            break;
            case 3:

    +190:                     p.to = read_any(buffer, offset)

            __pyx_t_2 = __pyx_f_19amqp10_codec_faster_14message_faster_read_any(__pyx_v_buffer, __pyx_v_offset); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 190, __pyx_L1_error)
            __Pyx_GOTREF(__pyx_t_2);
            __Pyx_GIVEREF(__pyx_t_2);
            __Pyx_GOTREF(__pyx_v_p->to);
            __Pyx_DECREF(__pyx_v_p->to);
            __pyx_v_p->to = __pyx_t_2;
            __pyx_t_2 = 0;

    +191:                 elif index == 3:

            break;
            case 4:

    +192:                     p.subject = read_any(buffer, offset)

            __pyx_t_2 = __pyx_f_19amqp10_codec_faster_14message_faster_read_any(__pyx_v_buffer, __pyx_v_offset); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 192, __pyx_L1_error)
            __Pyx_GOTREF(__pyx_t_2);
            __Pyx_GIVEREF(__pyx_t_2);
            __Pyx_GOTREF(__pyx_v_p->subject);
            __Pyx_DECREF(__pyx_v_p->subject);
            __pyx_v_p->subject = __pyx_t_2;
            __pyx_t_2 = 0;

    +193:                 elif index == 4:

            break;
            case 5:

    +194:                     p.reply_to = read_any(buffer, offset)

            __pyx_t_2 = __pyx_f_19amqp10_codec_faster_14message_faster_read_any(__pyx_v_buffer, __pyx_v_offset); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 194, __pyx_L1_error)
            __Pyx_GOTREF(__pyx_t_2);
            __Pyx_GIVEREF(__pyx_t_2);
            __Pyx_GOTREF(__pyx_v_p->reply_to);
            __Pyx_DECREF(__pyx_v_p->reply_to);
            __pyx_v_p->reply_to = __pyx_t_2;
            __pyx_t_2 = 0;

    +195:                 elif index == 5:

            break;
            case 6:

    +196:                     p.correlation_id = read_any(buffer, offset)

            __pyx_t_2 = __pyx_f_19amqp10_codec_faster_14message_faster_read_any(__pyx_v_buffer, __pyx_v_offset); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 196, __pyx_L1_error)
            __Pyx_GOTREF(__pyx_t_2);
            __Pyx_GIVEREF(__pyx_t_2);
            __Pyx_GOTREF(__pyx_v_p->correlation_id);
            __Pyx_DECREF(__pyx_v_p->correlation_id);
            __pyx_v_p->correlation_id = __pyx_t_2;
            __pyx_t_2 = 0;

    +197:                 elif index == 6:

            break;
            case 7:

    +198:                     p.content_type = read_any(buffer, offset)

            __pyx_t_2 = __pyx_f_19amqp10_codec_faster_14message_faster_read_any(__pyx_v_buffer, __pyx_v_offset); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 198, __pyx_L1_error)
            __Pyx_GOTREF(__pyx_t_2);
            __Pyx_GIVEREF(__pyx_t_2);
            __Pyx_GOTREF(__pyx_v_p->content_type);
            __Pyx_DECREF(__pyx_v_p->content_type);
            __pyx_v_p->content_type = __pyx_t_2;
            __pyx_t_2 = 0;

    +199:                 elif index == 7:

            break;
            case 8:

    +200:                     p.content_encoding = read_any(buffer, offset)

            __pyx_t_2 = __pyx_f_19amqp10_codec_faster_14message_faster_read_any(__pyx_v_buffer, __pyx_v_offset); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 200, __pyx_L1_error)
            __Pyx_GOTREF(__pyx_t_2);
            __Pyx_GIVEREF(__pyx_t_2);
            __Pyx_GOTREF(__pyx_v_p->content_encoding);
            __Pyx_DECREF(__pyx_v_p->content_encoding);
            __pyx_v_p->content_encoding = __pyx_t_2;
            __pyx_t_2 = 0;

    +201:                 elif index == 8:

            break;
            case 9:

    +202:                     p.absolute_expiry_time = read_any(buffer, offset)

            __pyx_t_2 = __pyx_f_19amqp10_codec_faster_14message_faster_read_any(__pyx_v_buffer, __pyx_v_offset); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 202, __pyx_L1_error)
            __Pyx_GOTREF(__pyx_t_2);
            __Pyx_GIVEREF(__pyx_t_2);
            __Pyx_GOTREF(__pyx_v_p->absolute_expiry_time);
            __Pyx_DECREF(__pyx_v_p->absolute_expiry_time);
            __pyx_v_p->absolute_expiry_time = __pyx_t_2;
            __pyx_t_2 = 0;

    +203:                 elif index == 9:

            break;
            case 10:

    +204:                     p.creation_time = read_any(buffer, offset)

            __pyx_t_2 = __pyx_f_19amqp10_codec_faster_14message_faster_read_any(__pyx_v_buffer, __pyx_v_offset); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 204, __pyx_L1_error)
            __Pyx_GOTREF(__pyx_t_2);
            __Pyx_GIVEREF(__pyx_t_2);
            __Pyx_GOTREF(__pyx_v_p->creation_time);
            __Pyx_DECREF(__pyx_v_p->creation_time);
            __pyx_v_p->creation_time = __pyx_t_2;
            __pyx_t_2 = 0;

    +205:                 elif index == 10:

            break;
            case 11:

    +206:                     p.group_id = read_any(buffer, offset)

            __pyx_t_2 = __pyx_f_19amqp10_codec_faster_14message_faster_read_any(__pyx_v_buffer, __pyx_v_offset); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 206, __pyx_L1_error)
            __Pyx_GOTREF(__pyx_t_2);
            __Pyx_GIVEREF(__pyx_t_2);
            __Pyx_GOTREF(__pyx_v_p->group_id);
            __Pyx_DECREF(__pyx_v_p->group_id);
            __pyx_v_p->group_id = __pyx_t_2;
            __pyx_t_2 = 0;

    +207:                 elif index == 11:

            break;
            case 12:

    +208:                     p.group_sequence = read_any(buffer, offset)

            __pyx_t_2 = __pyx_f_19amqp10_codec_faster_14message_faster_read_any(__pyx_v_buffer, __pyx_v_offset); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 208, __pyx_L1_error)
            __Pyx_GOTREF(__pyx_t_2);
            __Pyx_GIVEREF(__pyx_t_2);
            __Pyx_GOTREF(__pyx_v_p->group_sequence);
            __Pyx_DECREF(__pyx_v_p->group_sequence);
            __pyx_v_p->group_sequence = __pyx_t_2;
            __pyx_t_2 = 0;

    +209:                 elif index == 12:

            break;
            default:

    +210:                     p.reply_to_group_id = read_any(buffer, offset)

            __pyx_t_2 = __pyx_f_19amqp10_codec_faster_14message_faster_read_any(__pyx_v_buffer, __pyx_v_offset); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 210, __pyx_L1_error)
            __Pyx_GOTREF(__pyx_t_2);
            __Pyx_GIVEREF(__pyx_t_2);
            __Pyx_GOTREF(__pyx_v_p->reply_to_group_id);
            __Pyx_DECREF(__pyx_v_p->reply_to_group_id);
            __pyx_v_p->reply_to_group_id = __pyx_t_2;
            __pyx_t_2 = 0;

     211:                 else:

    +212:                     raise ValueError("Properties Parse invalid index {index}")

            __pyx_t_2 = __Pyx_PyObject_Call(__pyx_builtin_ValueError, __pyx_tuple__9, NULL); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 212, __pyx_L1_error)
            __Pyx_GOTREF(__pyx_t_2);
            __Pyx_Raise(__pyx_t_2, 0, 0, 0);
            __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
            __PYX_ERR(0, 212, __pyx_L1_error)
            break;
          }
        }
        __pyx_L5:;
      }

     213:

    +214:         return p

      __Pyx_XDECREF((PyObject *)__pyx_r);
      __Pyx_INCREF((PyObject *)__pyx_v_p);
      __pyx_r = __pyx_v_p;
      goto __pyx_L0;

     215:

     216:

     217:

    +218: cdef bytes read_application_data(unsigned char *buffer, Py_ssize_t *offset):

    static PyObject *__pyx_f_19amqp10_codec_faster_14message_faster_read_application_data(unsigned char *__pyx_v_buffer, Py_ssize_t *__pyx_v_offset) {
      unsigned char __pyx_v_data_type;
      uint8_t __pyx_v_length_8;
      uint32_t __pyx_v_length_32;
      PyObject *__pyx_v_body = 0;
      PyObject *__pyx_r = NULL;
    /* … */
      /* function exit code */
      __pyx_L1_error:;
      __Pyx_XDECREF(__pyx_t_3);
      __Pyx_XDECREF(__pyx_t_5);
      __Pyx_XDECREF(__pyx_t_6);
      __Pyx_XDECREF(__pyx_t_7);
      __Pyx_AddTraceback("amqp10_codec_faster.message_faster.read_application_data", __pyx_clineno, __pyx_lineno, __pyx_filename);
      __pyx_r = 0;
      __pyx_L0:;
      __Pyx_XDECREF(__pyx_v_body);
      __Pyx_XGIVEREF(__pyx_r);
      __Pyx_RefNannyFinishContext();
      return __pyx_r;
    }

     219:

    +220:     cdef unsigned char data_type = buffer[offset[0]]

      __pyx_v_data_type = (__pyx_v_buffer[(__pyx_v_offset[0])]);

     221:     cdef uint8_t length_8

     222:     cdef uint32_t length_32

     223:     cdef bytes body

     224:

    +225:     if data_type == 0xA0: # Vbin8

      switch (__pyx_v_data_type) {
        case 0xA0:
    /* … */
        break;
        case 0xB0:

    +226:         offset[0] += sizeof(data_type)

        __pyx_t_1 = 0;
        (__pyx_v_offset[__pyx_t_1]) = ((__pyx_v_offset[__pyx_t_1]) + (sizeof(__pyx_v_data_type)));

    +227:         length_8 = read_uint8(buffer, offset)

        __pyx_t_2 = __pyx_f_19amqp10_codec_faster_14message_faster_read_uint8(__pyx_v_buffer, __pyx_v_offset); if (unlikely(__pyx_t_2 == ((uint8_t)-1) && PyErr_Occurred())) __PYX_ERR(0, 227, __pyx_L1_error)
        __pyx_v_length_8 = __pyx_t_2;

    +228:         body = buffer[offset[0]: offset[0] + length_8]

        __pyx_t_3 = __Pyx_PyBytes_FromStringAndSize(((const char*)__pyx_v_buffer) + (__pyx_v_offset[0]), ((__pyx_v_offset[0]) + __pyx_v_length_8) - (__pyx_v_offset[0])); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 228, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_3);
        __pyx_v_body = ((PyObject*)__pyx_t_3);
        __pyx_t_3 = 0;

    +229:         offset[0] += length_8

        __pyx_t_1 = 0;
        (__pyx_v_offset[__pyx_t_1]) = ((__pyx_v_offset[__pyx_t_1]) + __pyx_v_length_8);

     230:

    +231:     elif data_type == 0xB0: # Vbin32

        break;
        default:

    +232:         offset[0] += sizeof(data_type)

        __pyx_t_1 = 0;
        (__pyx_v_offset[__pyx_t_1]) = ((__pyx_v_offset[__pyx_t_1]) + (sizeof(__pyx_v_data_type)));

    +233:         length_32 = read_uint32(buffer, offset)

        __pyx_t_4 = __pyx_f_19amqp10_codec_faster_14message_faster_read_uint32(__pyx_v_buffer, __pyx_v_offset); if (unlikely(__pyx_t_4 == ((uint32_t)-1) && PyErr_Occurred())) __PYX_ERR(0, 233, __pyx_L1_error)
        __pyx_v_length_32 = __pyx_t_4;

    +234:         body = buffer[offset[0]: offset[0] + length_32]

        __pyx_t_3 = __Pyx_PyBytes_FromStringAndSize(((const char*)__pyx_v_buffer) + (__pyx_v_offset[0]), ((__pyx_v_offset[0]) + __pyx_v_length_32) - (__pyx_v_offset[0])); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 234, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_3);
        __pyx_v_body = ((PyObject*)__pyx_t_3);
        __pyx_t_3 = 0;

    +235:         offset[0] += length_32

        __pyx_t_1 = 0;
        (__pyx_v_offset[__pyx_t_1]) = ((__pyx_v_offset[__pyx_t_1]) + __pyx_v_length_32);

     236:     else:

    +237:         raise ValueError("Error in read_data {} not found".format(hex(data_type)))

        __pyx_t_5 = __Pyx_PyObject_GetAttrStr(__pyx_kp_u_Error_in_read_data_not_found, __pyx_n_s_format); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 237, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_5);
        __pyx_t_6 = __Pyx_PyInt_From_unsigned_char(__pyx_v_data_type); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 237, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_6);
        __pyx_t_7 = __Pyx_PyObject_CallOneArg(__pyx_builtin_hex, __pyx_t_6); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 237, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_7);
        __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
        __pyx_t_6 = NULL;
        __pyx_t_8 = 0;
        #if CYTHON_UNPACK_METHODS
        if (likely(PyMethod_Check(__pyx_t_5))) {
          __pyx_t_6 = PyMethod_GET_SELF(__pyx_t_5);
          if (likely(__pyx_t_6)) {
            PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_5);
            __Pyx_INCREF(__pyx_t_6);
            __Pyx_INCREF(function);
            __Pyx_DECREF_SET(__pyx_t_5, function);
            __pyx_t_8 = 1;
          }
        }
        #endif
        {
          PyObject *__pyx_callargs[2] = {__pyx_t_6, __pyx_t_7};
          __pyx_t_3 = __Pyx_PyObject_FastCall(__pyx_t_5, __pyx_callargs+1-__pyx_t_8, 1+__pyx_t_8);
          __Pyx_XDECREF(__pyx_t_6); __pyx_t_6 = 0;
          __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
          if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 237, __pyx_L1_error)
          __Pyx_GOTREF(__pyx_t_3);
          __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
        }
        __pyx_t_5 = __Pyx_PyObject_CallOneArg(__pyx_builtin_ValueError, __pyx_t_3); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 237, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_5);
        __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
        __Pyx_Raise(__pyx_t_5, 0, 0, 0);
        __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
        __PYX_ERR(0, 237, __pyx_L1_error)
        break;
      }

     238:

    +239:     return body

      __Pyx_XDECREF(__pyx_r);
      __Pyx_INCREF(__pyx_v_body);
      __pyx_r = __pyx_v_body;
      goto __pyx_L0;

     240:

     241:

    +242: cdef dict read_map(unsigned char *buffer, Py_ssize_t *offset):

    static PyObject *__pyx_f_19amqp10_codec_faster_14message_faster_read_map(unsigned char *__pyx_v_buffer, Py_ssize_t *__pyx_v_offset) {
      uint32_t __pyx_v_items_count;
      PyObject *__pyx_v_amqpMap = 0;
      CYTHON_UNUSED long __pyx_v__;
      PyObject *__pyx_v_key = NULL;
      PyObject *__pyx_v_value = NULL;
      PyObject *__pyx_r = NULL;
    /* … */
      /* function exit code */
      __pyx_L1_error:;
      __Pyx_XDECREF(__pyx_t_2);
      __Pyx_AddTraceback("amqp10_codec_faster.message_faster.read_map", __pyx_clineno, __pyx_lineno, __pyx_filename);
      __pyx_r = 0;
      __pyx_L0:;
      __Pyx_XDECREF(__pyx_v_amqpMap);
      __Pyx_XDECREF(__pyx_v_key);
      __Pyx_XDECREF(__pyx_v_value);
      __Pyx_XGIVEREF(__pyx_r);
      __Pyx_RefNannyFinishContext();
      return __pyx_r;
    }

    +243:     cdef uint32_t items_count = read_map_header(&buffer[0], offset)

      __pyx_t_1 = __pyx_f_19amqp10_codec_faster_14message_faster_read_map_header((&(__pyx_v_buffer[0])), __pyx_v_offset); if (unlikely(__pyx_t_1 == ((uint32_t)-1) && PyErr_Occurred())) __PYX_ERR(0, 243, __pyx_L1_error)
      __pyx_v_items_count = __pyx_t_1;

     244:

    +245:     cdef dict amqpMap = {}

      __pyx_t_2 = __Pyx_PyDict_NewPresized(0); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 245, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_2);
      __pyx_v_amqpMap = ((PyObject*)__pyx_t_2);
      __pyx_t_2 = 0;

    +246:     for _ in range(0, items_count, 1):

      __pyx_t_1 = __pyx_v_items_count;
      __pyx_t_3 = __pyx_t_1;
      for (__pyx_t_4 = 0; __pyx_t_4 < __pyx_t_3; __pyx_t_4+=1) {
        __pyx_v__ = __pyx_t_4;

    +247:         key = read_any(&buffer[0], offset)

        __pyx_t_2 = __pyx_f_19amqp10_codec_faster_14message_faster_read_any((&(__pyx_v_buffer[0])), __pyx_v_offset); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 247, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_2);
        __Pyx_XDECREF_SET(__pyx_v_key, __pyx_t_2);
        __pyx_t_2 = 0;

    +248:         value = read_any(&buffer[0], offset)

        __pyx_t_2 = __pyx_f_19amqp10_codec_faster_14message_faster_read_any((&(__pyx_v_buffer[0])), __pyx_v_offset); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 248, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_2);
        __Pyx_XDECREF_SET(__pyx_v_value, __pyx_t_2);
        __pyx_t_2 = 0;

    +249:         amqpMap[key] = value

        if (unlikely((PyDict_SetItem(__pyx_v_amqpMap, __pyx_v_key, __pyx_v_value) < 0))) __PYX_ERR(0, 249, __pyx_L1_error)
      }

     250:

    +251:     return amqpMap

      __Pyx_XDECREF(__pyx_r);
      __Pyx_INCREF(__pyx_v_amqpMap);
      __pyx_r = __pyx_v_amqpMap;
      goto __pyx_L0;

     252:

    +253: cdef uint32_t read_composite_header(unsigned char *buffer, Py_ssize_t *offset):

    static uint32_t __pyx_f_19amqp10_codec_faster_14message_faster_read_composite_header(unsigned char *__pyx_v_buffer, Py_ssize_t *__pyx_v_offset) {
      uint8_t __pyx_v_data_type;
      uint32_t __pyx_v_fields;
      uint32_t __pyx_r;
    /* … */
      /* function exit code */
      __pyx_L1_error:;
      __Pyx_XDECREF(__pyx_t_2);
      __Pyx_XDECREF(__pyx_t_3);
      __Pyx_AddTraceback("amqp10_codec_faster.message_faster.read_composite_header", __pyx_clineno, __pyx_lineno, __pyx_filename);
      __pyx_r = -1;
      __pyx_L0:;
      __Pyx_RefNannyFinishContext();
      return __pyx_r;
    }

    +254:     cdef uint8_t data_type = buffer[offset[0]]

      __pyx_v_data_type = (__pyx_v_buffer[(__pyx_v_offset[0])]);

     255:     cdef uint32_t fields

     256:

    +257:     if data_type != 0:

      __pyx_t_1 = (__pyx_v_data_type != 0);
      if (unlikely(__pyx_t_1)) {
    /* … */
      }

    +258:         raise ValueError(f"Invalid composite header {data_type}")

        __pyx_t_2 = __Pyx_PyInt_From_uint8_t(__pyx_v_data_type); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 258, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_2);
        __pyx_t_3 = __Pyx_PyObject_FormatSimple(__pyx_t_2, __pyx_empty_unicode); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 258, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_3);
        __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
        __pyx_t_2 = __Pyx_PyUnicode_Concat(__pyx_kp_u_Invalid_composite_header, __pyx_t_3); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 258, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_2);
        __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
        __pyx_t_3 = __Pyx_PyObject_CallOneArg(__pyx_builtin_ValueError, __pyx_t_2); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 258, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_3);
        __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
        __Pyx_Raise(__pyx_t_3, 0, 0, 0);
        __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
        __PYX_ERR(0, 258, __pyx_L1_error)

    +259:     offset[0] += sizeof(data_type)

      __pyx_t_4 = 0;
      (__pyx_v_offset[__pyx_t_4]) = ((__pyx_v_offset[__pyx_t_4]) + (sizeof(__pyx_v_data_type)));

    +260:     read_any(buffer, offset)

      __pyx_t_3 = __pyx_f_19amqp10_codec_faster_14message_faster_read_any(__pyx_v_buffer, __pyx_v_offset); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 260, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_3);
      __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;

    +261:     fields = read_list_header(buffer, offset)

      __pyx_t_5 = __pyx_f_19amqp10_codec_faster_14message_faster_read_list_header(__pyx_v_buffer, __pyx_v_offset); if (unlikely(__pyx_t_5 == ((uint32_t)-1) && PyErr_Occurred())) __PYX_ERR(0, 261, __pyx_L1_error)
      __pyx_v_fields = __pyx_t_5;

    +262:     return fields

      __pyx_r = __pyx_v_fields;
      goto __pyx_L0;

     263:

    +264: cdef uint32_t read_list_header(unsigned char *buffer, Py_ssize_t *offset):

    static uint32_t __pyx_f_19amqp10_codec_faster_14message_faster_read_list_header(unsigned char *__pyx_v_buffer, Py_ssize_t *__pyx_v_offset) {
      unsigned char __pyx_v_data_type;
      uint32_t __pyx_v_length;
      uint32_t __pyx_r;
    /* … */
      /* function exit code */
      __pyx_L1_error:;
      __Pyx_XDECREF(__pyx_t_4);
      __Pyx_XDECREF(__pyx_t_5);
      __Pyx_XDECREF(__pyx_t_6);
      __Pyx_XDECREF(__pyx_t_7);
      __Pyx_AddTraceback("amqp10_codec_faster.message_faster.read_list_header", __pyx_clineno, __pyx_lineno, __pyx_filename);
      __pyx_r = -1;
      __pyx_L0:;
      __Pyx_RefNannyFinishContext();
      return __pyx_r;
    }

    +265:     cdef unsigned char data_type = buffer[offset[0]]

      __pyx_v_data_type = (__pyx_v_buffer[(__pyx_v_offset[0])]);

     266:     cdef uint32_t length

     267:

    +268:     if data_type == 0x45: #List0

      switch (__pyx_v_data_type) {
        case 0x45:
    /* … */
        break;
        case 0xC0:

    +269:         length = 0

        __pyx_v_length = 0;

    +270:         offset[0] += 1

        __pyx_t_1 = 0;
        (__pyx_v_offset[__pyx_t_1]) = ((__pyx_v_offset[__pyx_t_1]) + 1);

    +271:     elif data_type == 0xC0: #List8

        break;
        case 0xD0:

     272:         # move the offset by two to discard unused size value

    +273:         offset[0] += 2

        __pyx_t_1 = 0;
        (__pyx_v_offset[__pyx_t_1]) = ((__pyx_v_offset[__pyx_t_1]) + 2);

    +274:         length = read_uint8(buffer, offset)

        __pyx_t_2 = __pyx_f_19amqp10_codec_faster_14message_faster_read_uint8(__pyx_v_buffer, __pyx_v_offset); if (unlikely(__pyx_t_2 == ((uint8_t)-1) && PyErr_Occurred())) __PYX_ERR(0, 274, __pyx_L1_error)
        __pyx_v_length = __pyx_t_2;

    +275:     elif data_type == 0xD0: # List32

        break;
        default:

     276:         # move the offset by five to discard unused size value

    +277:         offset[0] += 5

        __pyx_t_1 = 0;
        (__pyx_v_offset[__pyx_t_1]) = ((__pyx_v_offset[__pyx_t_1]) + 5);

    +278:         length = read_uint32(buffer, offset)

        __pyx_t_3 = __pyx_f_19amqp10_codec_faster_14message_faster_read_uint32(__pyx_v_buffer, __pyx_v_offset); if (unlikely(__pyx_t_3 == ((uint32_t)-1) && PyErr_Occurred())) __PYX_ERR(0, 278, __pyx_L1_error)
        __pyx_v_length = __pyx_t_3;

     279:     else:

    +280:         raise ValueError("Invalid list header {}".format(hex(data_type)))

        __pyx_t_5 = __Pyx_PyObject_GetAttrStr(__pyx_kp_u_Invalid_list_header, __pyx_n_s_format); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 280, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_5);
        __pyx_t_6 = __Pyx_PyInt_From_unsigned_char(__pyx_v_data_type); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 280, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_6);
        __pyx_t_7 = __Pyx_PyObject_CallOneArg(__pyx_builtin_hex, __pyx_t_6); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 280, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_7);
        __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
        __pyx_t_6 = NULL;
        __pyx_t_8 = 0;
        #if CYTHON_UNPACK_METHODS
        if (likely(PyMethod_Check(__pyx_t_5))) {
          __pyx_t_6 = PyMethod_GET_SELF(__pyx_t_5);
          if (likely(__pyx_t_6)) {
            PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_5);
            __Pyx_INCREF(__pyx_t_6);
            __Pyx_INCREF(function);
            __Pyx_DECREF_SET(__pyx_t_5, function);
            __pyx_t_8 = 1;
          }
        }
        #endif
        {
          PyObject *__pyx_callargs[2] = {__pyx_t_6, __pyx_t_7};
          __pyx_t_4 = __Pyx_PyObject_FastCall(__pyx_t_5, __pyx_callargs+1-__pyx_t_8, 1+__pyx_t_8);
          __Pyx_XDECREF(__pyx_t_6); __pyx_t_6 = 0;
          __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
          if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 280, __pyx_L1_error)
          __Pyx_GOTREF(__pyx_t_4);
          __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
        }
        __pyx_t_5 = __Pyx_PyObject_CallOneArg(__pyx_builtin_ValueError, __pyx_t_4); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 280, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_5);
        __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
        __Pyx_Raise(__pyx_t_5, 0, 0, 0);
        __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
        __PYX_ERR(0, 280, __pyx_L1_error)
        break;
      }

     281:

    +282:     return length

      __pyx_r = __pyx_v_length;
      goto __pyx_L0;

     283:

     284:

    +285: cdef uint32_t read_map_header(unsigned char *buffer, Py_ssize_t *offset):

    static uint32_t __pyx_f_19amqp10_codec_faster_14message_faster_read_map_header(unsigned char *__pyx_v_buffer, Py_ssize_t *__pyx_v_offset) {
      unsigned char __pyx_v_data_type;
      uint8_t __pyx_v_map_8;
      uint32_t __pyx_v_map_32;
      PyObject *__pyx_v_items_count = NULL;
      uint32_t __pyx_r;
    /* … */
      /* function exit code */
      __pyx_L1_error:;
      __Pyx_XDECREF(__pyx_t_3);
      __Pyx_AddTraceback("amqp10_codec_faster.message_faster.read_map_header", __pyx_clineno, __pyx_lineno, __pyx_filename);
      __pyx_r = -1;
      __pyx_L0:;
      __Pyx_XDECREF(__pyx_v_items_count);
      __Pyx_RefNannyFinishContext();
      return __pyx_r;
    }

    +286:     cdef unsigned char data_type = buffer[offset[0]]

      __pyx_v_data_type = (__pyx_v_buffer[(__pyx_v_offset[0])]);

     287:     cdef uint8_t map_8

     288:     cdef uint32_t map_32

    +289:     offset[0] += sizeof(data_type)

      __pyx_t_1 = 0;
      (__pyx_v_offset[__pyx_t_1]) = ((__pyx_v_offset[__pyx_t_1]) + (sizeof(__pyx_v_data_type)));

     290:

    +291:     if data_type == 0xC1: # Map8

      switch (__pyx_v_data_type) {
        case 0xC1:
    /* … */
        break;
        case 0xD1:

     292:         # Ignore this byte

    +293:         offset[0] += 1

        __pyx_t_1 = 0;
        (__pyx_v_offset[__pyx_t_1]) = ((__pyx_v_offset[__pyx_t_1]) + 1);

    +294:         map_8 = read_uint8(buffer, offset)

        __pyx_t_2 = __pyx_f_19amqp10_codec_faster_14message_faster_read_uint8(__pyx_v_buffer, __pyx_v_offset); if (unlikely(__pyx_t_2 == ((uint8_t)-1) && PyErr_Occurred())) __PYX_ERR(0, 294, __pyx_L1_error)
        __pyx_v_map_8 = __pyx_t_2;

    +295:         items_count = map_8

        __pyx_t_3 = __Pyx_PyInt_From_uint8_t(__pyx_v_map_8); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 295, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_3);
        __pyx_v_items_count = __pyx_t_3;
        __pyx_t_3 = 0;

    +296:     elif data_type == 0xD1: # Map32

        break;
        default: break;
      }

     297:         # Ignore this 4 bytes

    +298:         offset[0] += 4

        __pyx_t_1 = 0;
        (__pyx_v_offset[__pyx_t_1]) = ((__pyx_v_offset[__pyx_t_1]) + 4);

    +299:         map_32 = read_uint32(buffer, offset)

        __pyx_t_4 = __pyx_f_19amqp10_codec_faster_14message_faster_read_uint32(__pyx_v_buffer, __pyx_v_offset); if (unlikely(__pyx_t_4 == ((uint32_t)-1) && PyErr_Occurred())) __PYX_ERR(0, 299, __pyx_L1_error)
        __pyx_v_map_32 = __pyx_t_4;

    +300:         items_count = map_32

        __pyx_t_3 = __Pyx_PyInt_From_uint32_t(__pyx_v_map_32); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 300, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_3);
        __pyx_v_items_count = __pyx_t_3;
        __pyx_t_3 = 0;

     301:

    +302:     return items_count // 2

      if (unlikely(!__pyx_v_items_count)) { __Pyx_RaiseUnboundLocalError("items_count"); __PYX_ERR(0, 302, __pyx_L1_error) }
      __pyx_t_3 = __Pyx_PyInt_FloorDivideObjC(__pyx_v_items_count, __pyx_int_2, 2, 0, 0); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 302, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_3);
      __pyx_t_4 = __Pyx_PyInt_As_uint32_t(__pyx_t_3); if (unlikely((__pyx_t_4 == ((uint32_t)-1)) && PyErr_Occurred())) __PYX_ERR(0, 302, __pyx_L1_error)
      __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
      __pyx_r = __pyx_t_4;
      goto __pyx_L0;

     303:

    +304: cdef read_any(unsigned char *buffer, Py_ssize_t *offset) except *:

    static PyObject *__pyx_f_19amqp10_codec_faster_14message_faster_read_any(unsigned char *__pyx_v_buffer, Py_ssize_t *__pyx_v_offset) {
      unsigned char __pyx_v_data_type;
      uint32_t __pyx_v_length;
      PyObject *__pyx_r = NULL;
    /* … */
      /* function exit code */
      __pyx_r = Py_None; __Pyx_INCREF(Py_None);
      goto __pyx_L0;
      __pyx_L1_error:;
      __Pyx_XDECREF(__pyx_t_3);
      __Pyx_AddTraceback("amqp10_codec_faster.message_faster.read_any", __pyx_clineno, __pyx_lineno, __pyx_filename);
      __pyx_r = 0;
      __pyx_L0:;
      __Pyx_XGIVEREF(__pyx_r);
      __Pyx_RefNannyFinishContext();
      return __pyx_r;
    }

    +305:     cdef unsigned char data_type = buffer[offset[0]]

      __pyx_v_data_type = (__pyx_v_buffer[(__pyx_v_offset[0])]);

    +306:     offset[0] += 1

      __pyx_t_1 = 0;
      (__pyx_v_offset[__pyx_t_1]) = ((__pyx_v_offset[__pyx_t_1]) + 1);

     307:     cdef uint32_t length

     308:

    +309:     if data_type == 0xA3: # Sym8

      switch (__pyx_v_data_type) {
        case 0xA3:
    /* … */
        break;
        case 0xA1:

    +310:         length = read_uint8(&buffer[0], offset)

        __pyx_t_2 = __pyx_f_19amqp10_codec_faster_14message_faster_read_uint8((&(__pyx_v_buffer[0])), __pyx_v_offset); if (unlikely(__pyx_t_2 == ((uint8_t)-1) && PyErr_Occurred())) __PYX_ERR(0, 310, __pyx_L1_error)
        __pyx_v_length = __pyx_t_2;

    +311:         return read_string(&buffer[0], offset, length)

        __Pyx_XDECREF(__pyx_r);
        __pyx_t_3 = __pyx_f_19amqp10_codec_faster_14message_faster_read_string((&(__pyx_v_buffer[0])), __pyx_v_offset, __pyx_v_length); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 311, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_3);
        __pyx_r = __pyx_t_3;
        __pyx_t_3 = 0;
        goto __pyx_L0;

     312:

    +313:     elif data_type == 0xA1: #Str8

        break;
        case 0xB3:

    +314:         length = read_uint8(&buffer[0], offset)

        __pyx_t_2 = __pyx_f_19amqp10_codec_faster_14message_faster_read_uint8((&(__pyx_v_buffer[0])), __pyx_v_offset); if (unlikely(__pyx_t_2 == ((uint8_t)-1) && PyErr_Occurred())) __PYX_ERR(0, 314, __pyx_L1_error)
        __pyx_v_length = __pyx_t_2;

    +315:         return read_string(&buffer[0], offset, length)

        __Pyx_XDECREF(__pyx_r);
        __pyx_t_3 = __pyx_f_19amqp10_codec_faster_14message_faster_read_string((&(__pyx_v_buffer[0])), __pyx_v_offset, __pyx_v_length); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 315, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_3);
        __pyx_r = __pyx_t_3;
        __pyx_t_3 = 0;
        goto __pyx_L0;

     316:

    +317:     elif data_type == 0xB3: # Sym32

        break;
        case 0xB1:

    +318:         length = read_uint32(&buffer[0], offset)

        __pyx_t_4 = __pyx_f_19amqp10_codec_faster_14message_faster_read_uint32((&(__pyx_v_buffer[0])), __pyx_v_offset); if (unlikely(__pyx_t_4 == ((uint32_t)-1) && PyErr_Occurred())) __PYX_ERR(0, 318, __pyx_L1_error)
        __pyx_v_length = __pyx_t_4;

    +319:         return read_string(&buffer[0], offset, length)

        __Pyx_XDECREF(__pyx_r);
        __pyx_t_3 = __pyx_f_19amqp10_codec_faster_14message_faster_read_string((&(__pyx_v_buffer[0])), __pyx_v_offset, __pyx_v_length); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 319, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_3);
        __pyx_r = __pyx_t_3;
        __pyx_t_3 = 0;
        goto __pyx_L0;

     320:

    +321:     elif data_type == 0xB1: # Str32

        break;
        case 0x44:

    +322:         length = read_uint32(&buffer[0], offset)

        __pyx_t_4 = __pyx_f_19amqp10_codec_faster_14message_faster_read_uint32((&(__pyx_v_buffer[0])), __pyx_v_offset); if (unlikely(__pyx_t_4 == ((uint32_t)-1) && PyErr_Occurred())) __PYX_ERR(0, 322, __pyx_L1_error)
        __pyx_v_length = __pyx_t_4;

    +323:         return read_string(&buffer[0], offset, length)

        __Pyx_XDECREF(__pyx_r);
        __pyx_t_3 = __pyx_f_19amqp10_codec_faster_14message_faster_read_string((&(__pyx_v_buffer[0])), __pyx_v_offset, __pyx_v_length); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 323, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_3);
        __pyx_r = __pyx_t_3;
        __pyx_t_3 = 0;
        goto __pyx_L0;

     324:

    +325:     elif data_type in (0x44,0x43) : #Ulong0, Uint0

        case 0x43:
    /* … */
        break;
        case 0x53:

    +326:         return 0

        __Pyx_XDECREF(__pyx_r);
        __Pyx_INCREF(__pyx_int_0);
        __pyx_r = __pyx_int_0;
        goto __pyx_L0;

     327:

    +328:     elif data_type in (0x53, 0x52, 0x50): #SmallUlong, SmallUint, Ubyte

        case 0x52:
        case 0x50:
    /* … */
        break;
        case 0x54:

    +329:         return read_uint8(&buffer[0], offset)

        __Pyx_XDECREF(__pyx_r);
        __pyx_t_2 = __pyx_f_19amqp10_codec_faster_14message_faster_read_uint8((&(__pyx_v_buffer[0])), __pyx_v_offset); if (unlikely(__pyx_t_2 == ((uint8_t)-1) && PyErr_Occurred())) __PYX_ERR(0, 329, __pyx_L1_error)
        __pyx_t_3 = __Pyx_PyInt_From_uint8_t(__pyx_t_2); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 329, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_3);
        __pyx_r = __pyx_t_3;
        __pyx_t_3 = 0;
        goto __pyx_L0;

     330:

    +331:     elif data_type in (0x54, 0x55, 0x51): #Smallint Smalllong Byte

        case 0x55:
        case 0x51:
    /* … */
        break;
        case 0x81:

    +332:         return read_int8(&buffer[0], offset)

        __Pyx_XDECREF(__pyx_r);
        __pyx_t_5 = __pyx_f_19amqp10_codec_faster_14message_faster_read_int8((&(__pyx_v_buffer[0])), __pyx_v_offset); if (unlikely(__pyx_t_5 == ((int8_t)-1) && PyErr_Occurred())) __PYX_ERR(0, 332, __pyx_L1_error)
        __pyx_t_3 = __Pyx_PyInt_From_int8_t(__pyx_t_5); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 332, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_3);
        __pyx_r = __pyx_t_3;
        __pyx_t_3 = 0;
        goto __pyx_L0;

     333:

    +334:     elif data_type ==  0x81: # Long

        break;
        case 0x80:

    +335:         return read_int64(&buffer[0], offset)

        __Pyx_XDECREF(__pyx_r);
        __pyx_t_6 = __pyx_f_19amqp10_codec_faster_14message_faster_read_int64((&(__pyx_v_buffer[0])), __pyx_v_offset); if (unlikely(__pyx_t_6 == ((int64_t)-1) && PyErr_Occurred())) __PYX_ERR(0, 335, __pyx_L1_error)
        __pyx_t_3 = __Pyx_PyInt_From_int64_t(__pyx_t_6); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 335, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_3);
        __pyx_r = __pyx_t_3;
        __pyx_t_3 = 0;
        goto __pyx_L0;

    +336:     elif data_type == 0x80: # Ulong:

        break;
        case 0x71:

    +337:         return read_uint64(&buffer[0], offset)

        __Pyx_XDECREF(__pyx_r);
        __pyx_t_7 = __pyx_f_19amqp10_codec_faster_14message_faster_read_uint64((&(__pyx_v_buffer[0])), __pyx_v_offset); if (unlikely(__pyx_t_7 == ((uint64_t)-1) && PyErr_Occurred())) __PYX_ERR(0, 337, __pyx_L1_error)
        __pyx_t_3 = __Pyx_PyInt_From_uint64_t(__pyx_t_7); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 337, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_3);
        __pyx_r = __pyx_t_3;
        __pyx_t_3 = 0;
        goto __pyx_L0;

     338:

    +339:     elif data_type == 0x71: # Int:

        break;
        case 0x70:

    +340:         return read_int32(&buffer[0], offset)

        __Pyx_XDECREF(__pyx_r);
        __pyx_t_8 = __pyx_f_19amqp10_codec_faster_14message_faster_read_int32((&(__pyx_v_buffer[0])), __pyx_v_offset); if (unlikely(__pyx_t_8 == ((int32_t)-1) && PyErr_Occurred())) __PYX_ERR(0, 340, __pyx_L1_error)
        __pyx_t_3 = __Pyx_PyInt_From_int32_t(__pyx_t_8); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 340, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_3);
        __pyx_r = __pyx_t_3;
        __pyx_t_3 = 0;
        goto __pyx_L0;

    +341:     elif data_type == 0x70:  # Uint

        break;
        case 0x61:

    +342:         return read_uint32(&buffer[0], offset)

        __Pyx_XDECREF(__pyx_r);
        __pyx_t_4 = __pyx_f_19amqp10_codec_faster_14message_faster_read_uint32((&(__pyx_v_buffer[0])), __pyx_v_offset); if (unlikely(__pyx_t_4 == ((uint32_t)-1) && PyErr_Occurred())) __PYX_ERR(0, 342, __pyx_L1_error)
        __pyx_t_3 = __Pyx_PyInt_From_uint32_t(__pyx_t_4); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 342, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_3);
        __pyx_r = __pyx_t_3;
        __pyx_t_3 = 0;
        goto __pyx_L0;

     343:

    +344:     elif data_type == 0x61:  # Short:

        break;
        case 0x60:

    +345:         return read_short(&buffer[0], offset)

        __Pyx_XDECREF(__pyx_r);
        __pyx_t_9 = __pyx_f_19amqp10_codec_faster_14message_faster_read_short((&(__pyx_v_buffer[0])), __pyx_v_offset); if (unlikely(__pyx_t_9 == ((int16_t)-1) && PyErr_Occurred())) __PYX_ERR(0, 345, __pyx_L1_error)
        __pyx_t_3 = __Pyx_PyInt_From_int16_t(__pyx_t_9); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 345, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_3);
        __pyx_r = __pyx_t_3;
        __pyx_t_3 = 0;
        goto __pyx_L0;

    +346:     elif data_type == 0x60: # Ushort

        break;
        case 0xA0:

    +347:         return read_ushort(&buffer[0], offset)

        __Pyx_XDECREF(__pyx_r);
        __pyx_t_10 = __pyx_f_19amqp10_codec_faster_14message_faster_read_ushort((&(__pyx_v_buffer[0])), __pyx_v_offset); if (unlikely(__pyx_t_10 == ((uint16_t)-1) && PyErr_Occurred())) __PYX_ERR(0, 347, __pyx_L1_error)
        __pyx_t_3 = __Pyx_PyInt_From_uint16_t(__pyx_t_10); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 347, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_3);
        __pyx_r = __pyx_t_3;
        __pyx_t_3 = 0;
        goto __pyx_L0;

     348:

    +349:     elif data_type == 0xA0: #Vbin8

        break;
        case 0xB0:

    +350:         return read_vbin8(&buffer[0], offset)

        __Pyx_XDECREF(__pyx_r);
        __pyx_t_3 = __pyx_f_19amqp10_codec_faster_14message_faster_read_vbin8((&(__pyx_v_buffer[0])), __pyx_v_offset); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 350, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_3);
        __pyx_r = __pyx_t_3;
        __pyx_t_3 = 0;
        goto __pyx_L0;

    +351:     elif data_type == 0xB0: #Vbin32

        break;
        case 0x56:

    +352:         return read_vbin32(&buffer[0], offset)

        __Pyx_XDECREF(__pyx_r);
        __pyx_t_3 = __pyx_f_19amqp10_codec_faster_14message_faster_read_vbin32((&(__pyx_v_buffer[0])), __pyx_v_offset); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 352, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_3);
        __pyx_r = __pyx_t_3;
        __pyx_t_3 = 0;
        goto __pyx_L0;

     353:

    +354:     elif data_type == 0x56: # Bool:

        break;
        case 0x41:

    +355:         return read_bool(&buffer[0], offset)

        __Pyx_XDECREF(__pyx_r);
        __pyx_t_11 = __pyx_f_19amqp10_codec_faster_14message_faster_read_bool((&(__pyx_v_buffer[0])), __pyx_v_offset); if (unlikely(__pyx_t_11 == ((int)-1) && PyErr_Occurred())) __PYX_ERR(0, 355, __pyx_L1_error)
        __pyx_t_3 = __Pyx_PyBool_FromLong(__pyx_t_11); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 355, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_3);
        __pyx_r = __pyx_t_3;
        __pyx_t_3 = 0;
        goto __pyx_L0;

    +356:     elif data_type == 0x41: # BoolTrue

        break;
        case 0x42:

    +357:         return True

        __Pyx_XDECREF(__pyx_r);
        __Pyx_INCREF(Py_True);
        __pyx_r = Py_True;
        goto __pyx_L0;

    +358:     elif data_type == 0x42: # BoolFalse

        break;
        case 0x83:

    +359:         return False

        __Pyx_XDECREF(__pyx_r);
        __Pyx_INCREF(Py_False);
        __pyx_r = Py_False;
        goto __pyx_L0;

     360:

    +361:     elif data_type == 0x83: # Timestamp:

        break;
        case 0x72:

    +362:         return read_timestamp(&buffer[0], offset)

        __Pyx_XDECREF(__pyx_r);
        __pyx_t_3 = __pyx_f_19amqp10_codec_faster_14message_faster_read_timestamp((&(__pyx_v_buffer[0])), __pyx_v_offset); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 362, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_3);
        __pyx_r = __pyx_t_3;
        __pyx_t_3 = 0;
        goto __pyx_L0;

     363:

    +364:     elif data_type == 0x72: #float

        break;
        case 0x82:

    +365:         return read_float(&buffer[0], offset)

        __Pyx_XDECREF(__pyx_r);
        __pyx_t_12 = __pyx_f_19amqp10_codec_faster_14message_faster_read_float((&(__pyx_v_buffer[0])), __pyx_v_offset); if (unlikely(__pyx_t_12 == ((float)-1) && PyErr_Occurred())) __PYX_ERR(0, 365, __pyx_L1_error)
        __pyx_t_3 = PyFloat_FromDouble(__pyx_t_12); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 365, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_3);
        __pyx_r = __pyx_t_3;
        __pyx_t_3 = 0;
        goto __pyx_L0;

    +366:     elif data_type == 0x82: #double

        break;
        case 0x40:

    +367:         return read_double(&buffer[0], offset)

        __Pyx_XDECREF(__pyx_r);
        __pyx_t_13 = __pyx_f_19amqp10_codec_faster_14message_faster_read_double((&(__pyx_v_buffer[0])), __pyx_v_offset); if (unlikely(__pyx_t_13 == ((double)-1) && PyErr_Occurred())) __PYX_ERR(0, 367, __pyx_L1_error)
        __pyx_t_3 = PyFloat_FromDouble(__pyx_t_13); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 367, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_3);
        __pyx_r = __pyx_t_3;
        __pyx_t_3 = 0;
        goto __pyx_L0;

     368:

    +369:     elif data_type == 0x40: # Null:

        break;
        default: break;
      }

    +370:         return None

        __Pyx_XDECREF(__pyx_r);
        __pyx_r = Py_None; __Pyx_INCREF(Py_None);
        goto __pyx_L0;

     371:

     372:

     373: #-------------- decode

    +374: cdef bytes read_vbin8(unsigned char *buffer, Py_ssize_t *offset):

    static PyObject *__pyx_f_19amqp10_codec_faster_14message_faster_read_vbin8(unsigned char *__pyx_v_buffer, Py_ssize_t *__pyx_v_offset) {
      PyObject *__pyx_v_binary_data = 0;
      uint8_t __pyx_v_length;
      PyObject *__pyx_r = NULL;
    /* … */
      /* function exit code */
      __pyx_L1_error:;
      __Pyx_XDECREF(__pyx_t_2);
      __Pyx_AddTraceback("amqp10_codec_faster.message_faster.read_vbin8", __pyx_clineno, __pyx_lineno, __pyx_filename);
      __pyx_r = 0;
      __pyx_L0:;
      __Pyx_XDECREF(__pyx_v_binary_data);
      __Pyx_XGIVEREF(__pyx_r);
      __Pyx_RefNannyFinishContext();
      return __pyx_r;
    }

     375:     cdef bytes binary_data

     376:     cdef uint8_t length

    +377:     length = read_uint8(buffer, offset)

      __pyx_t_1 = __pyx_f_19amqp10_codec_faster_14message_faster_read_uint8(__pyx_v_buffer, __pyx_v_offset); if (unlikely(__pyx_t_1 == ((uint8_t)-1) && PyErr_Occurred())) __PYX_ERR(0, 377, __pyx_L1_error)
      __pyx_v_length = __pyx_t_1;

    +378:     binary_data = buffer[offset[0]: offset[0] + length]

      __pyx_t_2 = __Pyx_PyBytes_FromStringAndSize(((const char*)__pyx_v_buffer) + (__pyx_v_offset[0]), ((__pyx_v_offset[0]) + __pyx_v_length) - (__pyx_v_offset[0])); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 378, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_2);
      __pyx_v_binary_data = ((PyObject*)__pyx_t_2);
      __pyx_t_2 = 0;

    +379:     offset[0] += length

      __pyx_t_3 = 0;
      (__pyx_v_offset[__pyx_t_3]) = ((__pyx_v_offset[__pyx_t_3]) + __pyx_v_length);

     380:

    +381:     return binary_data

      __Pyx_XDECREF(__pyx_r);
      __Pyx_INCREF(__pyx_v_binary_data);
      __pyx_r = __pyx_v_binary_data;
      goto __pyx_L0;

     382:

    +383: cdef bytes read_vbin32(unsigned char *buffer, Py_ssize_t *offset):

    static PyObject *__pyx_f_19amqp10_codec_faster_14message_faster_read_vbin32(unsigned char *__pyx_v_buffer, Py_ssize_t *__pyx_v_offset) {
      PyObject *__pyx_v_binary_data = 0;
      PyObject *__pyx_v_length = NULL;
      PyObject *__pyx_r = NULL;
    /* … */
      /* function exit code */
      __pyx_L1_error:;
      __Pyx_XDECREF(__pyx_t_2);
      __Pyx_XDECREF(__pyx_t_3);
      __Pyx_AddTraceback("amqp10_codec_faster.message_faster.read_vbin32", __pyx_clineno, __pyx_lineno, __pyx_filename);
      __pyx_r = 0;
      __pyx_L0:;
      __Pyx_XDECREF(__pyx_v_binary_data);
      __Pyx_XDECREF(__pyx_v_length);
      __Pyx_XGIVEREF(__pyx_r);
      __Pyx_RefNannyFinishContext();
      return __pyx_r;
    }

     384:     cdef bytes binary_data

    +385:     length = read_uint32(buffer, offset)

      __pyx_t_1 = __pyx_f_19amqp10_codec_faster_14message_faster_read_uint32(__pyx_v_buffer, __pyx_v_offset); if (unlikely(__pyx_t_1 == ((uint32_t)-1) && PyErr_Occurred())) __PYX_ERR(0, 385, __pyx_L1_error)
      __pyx_t_2 = __Pyx_PyInt_From_uint32_t(__pyx_t_1); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 385, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_2);
      __pyx_v_length = __pyx_t_2;
      __pyx_t_2 = 0;

    +386:     binary_data = buffer[offset[0]: offset[0] + length]

      __pyx_t_2 = PyInt_FromSsize_t((__pyx_v_offset[0])); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 386, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_2);
      __pyx_t_3 = PyNumber_Add(__pyx_t_2, __pyx_v_length); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 386, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_3);
      __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
      __pyx_t_5 = (__pyx_t_3 == Py_None);
      if (__pyx_t_5) {
        __pyx_t_4 = PY_SSIZE_T_MAX;
      } else {
        __pyx_t_6 = __Pyx_PyIndex_AsSsize_t(__pyx_t_3); if (unlikely((__pyx_t_6 == (Py_ssize_t)-1) && PyErr_Occurred())) __PYX_ERR(0, 386, __pyx_L1_error)
        __pyx_t_4 = __pyx_t_6;
      }
      __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
      __pyx_t_3 = __Pyx_PyBytes_FromStringAndSize(((const char*)__pyx_v_buffer) + (__pyx_v_offset[0]), __pyx_t_4 - (__pyx_v_offset[0])); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 386, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_3);
      __pyx_v_binary_data = ((PyObject*)__pyx_t_3);
      __pyx_t_3 = 0;

    +387:     offset[0] += length

      __pyx_t_7 = 0;
      __pyx_t_3 = PyInt_FromSsize_t((__pyx_v_offset[__pyx_t_7])); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 387, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_3);
      __pyx_t_2 = PyNumber_InPlaceAdd(__pyx_t_3, __pyx_v_length); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 387, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_2);
      __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
      __pyx_t_4 = __Pyx_PyIndex_AsSsize_t(__pyx_t_2); if (unlikely((__pyx_t_4 == (Py_ssize_t)-1) && PyErr_Occurred())) __PYX_ERR(0, 387, __pyx_L1_error)
      __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
      (__pyx_v_offset[__pyx_t_7]) = __pyx_t_4;

     388:

    +389:     return binary_data

      __Pyx_XDECREF(__pyx_r);
      __Pyx_INCREF(__pyx_v_binary_data);
      __pyx_r = __pyx_v_binary_data;
      goto __pyx_L0;

     390:

    +391: cdef uint8_t read_uint8(unsigned char *buffer,  Py_ssize_t *offset) except? -1:

    static uint8_t __pyx_f_19amqp10_codec_faster_14message_faster_read_uint8(unsigned char *__pyx_v_buffer, Py_ssize_t *__pyx_v_offset) {
      uint8_t __pyx_v_result;
      uint8_t __pyx_r;
    /* … */
      /* function exit code */
      __pyx_L0:;
      return __pyx_r;
    }

    +392:     cdef uint8_t result = buffer[offset[0]]

      __pyx_v_result = (__pyx_v_buffer[(__pyx_v_offset[0])]);

    +393:     offset[0] += sizeof(uint8_t)

      __pyx_t_1 = 0;
      (__pyx_v_offset[__pyx_t_1]) = ((__pyx_v_offset[__pyx_t_1]) + (sizeof(uint8_t)));

    +394:     return result

      __pyx_r = __pyx_v_result;
      goto __pyx_L0;

     395:

    +396: cdef uint16_t read_ushort(unsigned char *buffer,  Py_ssize_t *offset):

    static uint16_t __pyx_f_19amqp10_codec_faster_14message_faster_read_ushort(unsigned char *__pyx_v_buffer, Py_ssize_t *__pyx_v_offset) {
      uint16_t __pyx_v_result;
      uint8_t __pyx_v_i;
      uint16_t __pyx_r;
    /* … */
      /* function exit code */
      __pyx_L0:;
      return __pyx_r;
    }

    +397:     cdef uint16_t result = 0

      __pyx_v_result = 0;

     398:     cdef uint8_t i

    +399:     for i in range(0, 2, 1):

      for (__pyx_t_1 = 0; __pyx_t_1 < 2; __pyx_t_1+=1) {
        __pyx_v_i = __pyx_t_1;

    +400:         result = (result << 8) | buffer[offset[0] + i]

        __pyx_v_result = ((__pyx_v_result << 8) | (__pyx_v_buffer[((__pyx_v_offset[0]) + __pyx_v_i)]));
      }

    +401:     offset[0] += sizeof(uint16_t)

      __pyx_t_2 = 0;
      (__pyx_v_offset[__pyx_t_2]) = ((__pyx_v_offset[__pyx_t_2]) + (sizeof(uint16_t)));

    +402:     return result

      __pyx_r = __pyx_v_result;
      goto __pyx_L0;

     403:

    +404: cdef uint32_t read_uint32(unsigned char *buffer,  Py_ssize_t *offset):

    static uint32_t __pyx_f_19amqp10_codec_faster_14message_faster_read_uint32(unsigned char *__pyx_v_buffer, Py_ssize_t *__pyx_v_offset) {
      uint32_t __pyx_v_result;
      uint8_t __pyx_v_i;
      uint32_t __pyx_r;
    /* … */
      /* function exit code */
      __pyx_L0:;
      return __pyx_r;
    }

    +405:     cdef uint32_t result = 0

      __pyx_v_result = 0;

     406:     cdef uint8_t i

    +407:     for i in range(0, 4, 1):

      for (__pyx_t_1 = 0; __pyx_t_1 < 4; __pyx_t_1+=1) {
        __pyx_v_i = __pyx_t_1;

    +408:         result = (result << 8) | buffer[offset[0] + i]

        __pyx_v_result = ((__pyx_v_result << 8) | (__pyx_v_buffer[((__pyx_v_offset[0]) + __pyx_v_i)]));
      }

    +409:     offset[0] += sizeof(uint32_t)

      __pyx_t_2 = 0;
      (__pyx_v_offset[__pyx_t_2]) = ((__pyx_v_offset[__pyx_t_2]) + (sizeof(uint32_t)));

    +410:     return result

      __pyx_r = __pyx_v_result;
      goto __pyx_L0;

     411:

    +412: cdef uint64_t read_uint64(unsigned char* buffer, Py_ssize_t *offset):

    static uint64_t __pyx_f_19amqp10_codec_faster_14message_faster_read_uint64(unsigned char *__pyx_v_buffer, Py_ssize_t *__pyx_v_offset) {
      uint64_t __pyx_v_result;
      uint8_t __pyx_v_i;
      uint64_t __pyx_r;
    /* … */
      /* function exit code */
      __pyx_L0:;
      return __pyx_r;
    }

    +413:     cdef uint64_t result = 0

      __pyx_v_result = 0;

     414:     cdef uint8_t i

    +415:     for i in range(0, 8, 1):

      for (__pyx_t_1 = 0; __pyx_t_1 < 8; __pyx_t_1+=1) {
        __pyx_v_i = __pyx_t_1;

    +416:         result = (result << 8) | buffer[offset[0] + i]

        __pyx_v_result = ((__pyx_v_result << 8) | (__pyx_v_buffer[((__pyx_v_offset[0]) + __pyx_v_i)]));
      }

    +417:     offset[0] += sizeof(uint64_t)

      __pyx_t_2 = 0;
      (__pyx_v_offset[__pyx_t_2]) = ((__pyx_v_offset[__pyx_t_2]) + (sizeof(uint64_t)));

    +418:     return result

      __pyx_r = __pyx_v_result;
      goto __pyx_L0;

     419:

    +420: cdef int8_t read_int8(unsigned char *buffer,  Py_ssize_t *offset):

    static int8_t __pyx_f_19amqp10_codec_faster_14message_faster_read_int8(unsigned char *__pyx_v_buffer, Py_ssize_t *__pyx_v_offset) {
      int8_t __pyx_v_result;
      int8_t __pyx_r;
    /* … */
      /* function exit code */
      __pyx_L0:;
      return __pyx_r;
    }

    +421:     cdef int8_t result = buffer[offset[0]]

      __pyx_v_result = (__pyx_v_buffer[(__pyx_v_offset[0])]);

    +422:     offset[0] += sizeof(int8_t)

      __pyx_t_1 = 0;
      (__pyx_v_offset[__pyx_t_1]) = ((__pyx_v_offset[__pyx_t_1]) + (sizeof(int8_t)));

    +423:     return result

      __pyx_r = __pyx_v_result;
      goto __pyx_L0;

     424:

    +425: cdef int16_t read_short(unsigned char *buffer,  Py_ssize_t *offset):

    static int16_t __pyx_f_19amqp10_codec_faster_14message_faster_read_short(unsigned char *__pyx_v_buffer, Py_ssize_t *__pyx_v_offset) {
      int16_t __pyx_v_result;
      uint8_t __pyx_v_i;
      int16_t __pyx_r;
    /* … */
      /* function exit code */
      __pyx_L0:;
      return __pyx_r;
    }

    +426:     cdef int16_t result = 0

      __pyx_v_result = 0;

     427:     cdef uint8_t i

    +428:     for i in range(0, 2, 1):

      for (__pyx_t_1 = 0; __pyx_t_1 < 2; __pyx_t_1+=1) {
        __pyx_v_i = __pyx_t_1;

    +429:         result = (result << 8) | buffer[offset[0] + i]

        __pyx_v_result = ((__pyx_v_result << 8) | (__pyx_v_buffer[((__pyx_v_offset[0]) + __pyx_v_i)]));
      }

    +430:     offset[0] += sizeof(int16_t)

      __pyx_t_2 = 0;
      (__pyx_v_offset[__pyx_t_2]) = ((__pyx_v_offset[__pyx_t_2]) + (sizeof(int16_t)));

    +431:     return result

      __pyx_r = __pyx_v_result;
      goto __pyx_L0;

     432:

    +433: cdef int32_t read_int32(unsigned char *buffer,  Py_ssize_t *offset):

    static int32_t __pyx_f_19amqp10_codec_faster_14message_faster_read_int32(unsigned char *__pyx_v_buffer, Py_ssize_t *__pyx_v_offset) {
      int32_t __pyx_v_result;
      uint8_t __pyx_v_i;
      int32_t __pyx_r;
    /* … */
      /* function exit code */
      __pyx_L0:;
      return __pyx_r;
    }

    +434:     cdef int32_t result = 0

      __pyx_v_result = 0;

     435:     cdef uint8_t i

    +436:     for i in range(0, 4, 1):

      for (__pyx_t_1 = 0; __pyx_t_1 < 4; __pyx_t_1+=1) {
        __pyx_v_i = __pyx_t_1;

    +437:         result = (result << 8) | buffer[offset[0] + i]

        __pyx_v_result = ((__pyx_v_result << 8) | (__pyx_v_buffer[((__pyx_v_offset[0]) + __pyx_v_i)]));
      }

    +438:     offset[0] += sizeof(int32_t)

      __pyx_t_2 = 0;
      (__pyx_v_offset[__pyx_t_2]) = ((__pyx_v_offset[__pyx_t_2]) + (sizeof(int32_t)));

    +439:     return result

      __pyx_r = __pyx_v_result;
      goto __pyx_L0;

     440:

    +441: cdef int64_t read_int64(unsigned char* buffer, Py_ssize_t *offset):

    static int64_t __pyx_f_19amqp10_codec_faster_14message_faster_read_int64(unsigned char *__pyx_v_buffer, Py_ssize_t *__pyx_v_offset) {
      int64_t __pyx_v_result;
      uint8_t __pyx_v_i;
      int64_t __pyx_r;
    /* … */
      /* function exit code */
      __pyx_L0:;
      return __pyx_r;
    }

    +442:     cdef int64_t result = 0

      __pyx_v_result = 0;

     443:     cdef uint8_t i

    +444:     for i in range(0, 8, 1):

      for (__pyx_t_1 = 0; __pyx_t_1 < 8; __pyx_t_1+=1) {
        __pyx_v_i = __pyx_t_1;

    +445:         result = (result << 8) | buffer[offset[0] + i]

        __pyx_v_result = ((__pyx_v_result << 8) | (__pyx_v_buffer[((__pyx_v_offset[0]) + __pyx_v_i)]));
      }

    +446:     offset[0] += sizeof(int64_t)

      __pyx_t_2 = 0;
      (__pyx_v_offset[__pyx_t_2]) = ((__pyx_v_offset[__pyx_t_2]) + (sizeof(int64_t)));

    +447:     return result

      __pyx_r = __pyx_v_result;
      goto __pyx_L0;

     448:

    +449: cdef float read_float(unsigned char *buffer, Py_ssize_t *offset) except *:

    static float __pyx_f_19amqp10_codec_faster_14message_faster_read_float(unsigned char *__pyx_v_buffer, Py_ssize_t *__pyx_v_offset) {
      float __pyx_v_result;
      uint8_t *__pyx_v_p_result;
      PyObject *__pyx_v_i = NULL;
      float __pyx_r;
    /* … */
      /* function exit code */
      __pyx_L1_error:;
      __Pyx_XDECREF(__pyx_t_2);
      __Pyx_XDECREF(__pyx_t_3);
      __Pyx_AddTraceback("amqp10_codec_faster.message_faster.read_float", __pyx_clineno, __pyx_lineno, __pyx_filename);
      __pyx_r = -1;
      __pyx_L0:;
      __Pyx_XDECREF(__pyx_v_i);
      __Pyx_RefNannyFinishContext();
      return __pyx_r;
    }

     450:     cdef float result

    +451:     cdef uint8_t* p_result = <uint8_t*>&result

      __pyx_v_p_result = ((uint8_t *)(&__pyx_v_result));

    +452:     for i in range(0, 4, 1):

      for (__pyx_t_1 = 0; __pyx_t_1 < 4; __pyx_t_1+=1) {
        __pyx_t_2 = __Pyx_PyInt_From_long(__pyx_t_1); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 452, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_2);
        __Pyx_XDECREF_SET(__pyx_v_i, __pyx_t_2);
        __pyx_t_2 = 0;

    +453:         p_result[3 - i] = buffer[offset[0] + i]

        __pyx_t_2 = PyInt_FromSsize_t((__pyx_v_offset[0])); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 453, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_2);
        __pyx_t_3 = PyNumber_Add(__pyx_t_2, __pyx_v_i); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 453, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_3);
        __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
        __pyx_t_4 = __Pyx_PyIndex_AsSsize_t(__pyx_t_3); if (unlikely((__pyx_t_4 == (Py_ssize_t)-1) && PyErr_Occurred())) __PYX_ERR(0, 453, __pyx_L1_error)
        __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
        __pyx_t_3 = __Pyx_PyInt_SubtractCObj(__pyx_int_3, __pyx_v_i, 3, 0, 0); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 453, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_3);
        __pyx_t_5 = __Pyx_PyIndex_AsSsize_t(__pyx_t_3); if (unlikely((__pyx_t_5 == (Py_ssize_t)-1) && PyErr_Occurred())) __PYX_ERR(0, 453, __pyx_L1_error)
        __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
        (__pyx_v_p_result[__pyx_t_5]) = (__pyx_v_buffer[__pyx_t_4]);
      }

    +454:     offset[0] += 4

      __pyx_t_1 = 0;
      (__pyx_v_offset[__pyx_t_1]) = ((__pyx_v_offset[__pyx_t_1]) + 4);

    +455:     return result

      __pyx_r = __pyx_v_result;
      goto __pyx_L0;

     456:

    +457: cdef double read_double(unsigned char* buffer, Py_ssize_t *offset):

    static double __pyx_f_19amqp10_codec_faster_14message_faster_read_double(unsigned char *__pyx_v_buffer, Py_ssize_t *__pyx_v_offset) {
      double __pyx_v_result;
      uint8_t *__pyx_v_p_result;
      PyObject *__pyx_v_i = NULL;
      double __pyx_r;
    /* … */
      /* function exit code */
      __pyx_L1_error:;
      __Pyx_XDECREF(__pyx_t_2);
      __Pyx_XDECREF(__pyx_t_3);
      __Pyx_AddTraceback("amqp10_codec_faster.message_faster.read_double", __pyx_clineno, __pyx_lineno, __pyx_filename);
      __pyx_r = -1;
      __pyx_L0:;
      __Pyx_XDECREF(__pyx_v_i);
      __Pyx_RefNannyFinishContext();
      return __pyx_r;
    }

     458:     cdef double result

    +459:     cdef uint8_t* p_result = <uint8_t*>&result

      __pyx_v_p_result = ((uint8_t *)(&__pyx_v_result));

    +460:     for i in range(0, 8, 1):

      for (__pyx_t_1 = 0; __pyx_t_1 < 8; __pyx_t_1+=1) {
        __pyx_t_2 = __Pyx_PyInt_From_long(__pyx_t_1); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 460, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_2);
        __Pyx_XDECREF_SET(__pyx_v_i, __pyx_t_2);
        __pyx_t_2 = 0;

    +461:         p_result[7 - i] = buffer[offset[0] + i]

        __pyx_t_2 = PyInt_FromSsize_t((__pyx_v_offset[0])); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 461, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_2);
        __pyx_t_3 = PyNumber_Add(__pyx_t_2, __pyx_v_i); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 461, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_3);
        __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
        __pyx_t_4 = __Pyx_PyIndex_AsSsize_t(__pyx_t_3); if (unlikely((__pyx_t_4 == (Py_ssize_t)-1) && PyErr_Occurred())) __PYX_ERR(0, 461, __pyx_L1_error)
        __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
        __pyx_t_3 = __Pyx_PyInt_SubtractCObj(__pyx_int_7, __pyx_v_i, 7, 0, 0); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 461, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_3);
        __pyx_t_5 = __Pyx_PyIndex_AsSsize_t(__pyx_t_3); if (unlikely((__pyx_t_5 == (Py_ssize_t)-1) && PyErr_Occurred())) __PYX_ERR(0, 461, __pyx_L1_error)
        __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
        (__pyx_v_p_result[__pyx_t_5]) = (__pyx_v_buffer[__pyx_t_4]);
      }

    +462:     offset[0] += 8

      __pyx_t_1 = 0;
      (__pyx_v_offset[__pyx_t_1]) = ((__pyx_v_offset[__pyx_t_1]) + 8);

    +463:     return result

      __pyx_r = __pyx_v_result;
      goto __pyx_L0;

     464:

    +465: cdef object read_string(unsigned char *buffer, Py_ssize_t *offset, uint32_t length):

    static PyObject *__pyx_f_19amqp10_codec_faster_14message_faster_read_string(unsigned char *__pyx_v_buffer, Py_ssize_t *__pyx_v_offset, uint32_t __pyx_v_length) {
      PyObject *__pyx_v_data_string = 0;
      PyObject *__pyx_r = NULL;
    /* … */
      /* function exit code */
      __pyx_L1_error:;
      __Pyx_XDECREF(__pyx_t_1);
      __Pyx_XDECREF(__pyx_t_2);
      __Pyx_AddTraceback("amqp10_codec_faster.message_faster.read_string", __pyx_clineno, __pyx_lineno, __pyx_filename);
      __pyx_r = 0;
      __pyx_L0:;
      __Pyx_XDECREF(__pyx_v_data_string);
      __Pyx_XGIVEREF(__pyx_r);
      __Pyx_RefNannyFinishContext();
      return __pyx_r;
    }

     466:     cdef object data_string

     467:

    +468:     data_string = bytes(buffer[offset[0]:offset[0]+length]).decode("utf-8")

      __pyx_t_1 = __Pyx_PyBytes_FromStringAndSize(((const char*)__pyx_v_buffer) + (__pyx_v_offset[0]), ((__pyx_v_offset[0]) + __pyx_v_length) - (__pyx_v_offset[0])); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 468, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_1);
      __pyx_t_2 = __Pyx_PyObject_CallOneArg(((PyObject *)(&PyBytes_Type)), __pyx_t_1); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 468, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_2);
      __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
      __pyx_t_1 = __Pyx_decode_bytes(__pyx_t_2, 0, PY_SSIZE_T_MAX, NULL, NULL, PyUnicode_DecodeUTF8); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 468, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_1);
      __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
      __pyx_v_data_string = __pyx_t_1;
      __pyx_t_1 = 0;

    +469:     offset[0] += length

      __pyx_t_3 = 0;
      (__pyx_v_offset[__pyx_t_3]) = ((__pyx_v_offset[__pyx_t_3]) + __pyx_v_length);

    +470:     return data_string

      __Pyx_XDECREF(__pyx_r);
      __Pyx_INCREF(__pyx_v_data_string);
      __pyx_r = __pyx_v_data_string;
      goto __pyx_L0;

     471:

    +472: cdef bint read_bool(unsigned char *buffer, Py_ssize_t *offset):

    static int __pyx_f_19amqp10_codec_faster_14message_faster_read_bool(unsigned char *__pyx_v_buffer, Py_ssize_t *__pyx_v_offset) {
      int __pyx_v_result;
      int __pyx_r;
    /* … */
      /* function exit code */
      __pyx_L0:;
      return __pyx_r;
    }

    +473:     cdef bint result = <bint> buffer[offset[0]]

      __pyx_v_result = ((__pyx_v_buffer[(__pyx_v_offset[0])]) != 0);

    +474:     offset[0] += 1

      __pyx_t_1 = 0;
      (__pyx_v_offset[__pyx_t_1]) = ((__pyx_v_offset[__pyx_t_1]) + 1);

    +475:     return result

      __pyx_r = __pyx_v_result;
      goto __pyx_L0;

     476:

    +477: cdef read_timestamp(unsigned char* buffer, Py_ssize_t* offset):

    static PyObject *__pyx_f_19amqp10_codec_faster_14message_faster_read_timestamp(unsigned char *__pyx_v_buffer, Py_ssize_t *__pyx_v_offset) {
      int64_t __pyx_v_value;
      struct tm __pyx_v_t;
      PyObject *__pyx_r = NULL;
    /* … */
      /* function exit code */
      __pyx_L1_error:;
      __Pyx_XDECREF(__pyx_t_3);
      __Pyx_XDECREF(__pyx_t_4);
      __Pyx_XDECREF(__pyx_t_5);
      __Pyx_XDECREF(__pyx_t_6);
      __Pyx_AddTraceback("amqp10_codec_faster.message_faster.read_timestamp", __pyx_clineno, __pyx_lineno, __pyx_filename);
      __pyx_r = 0;
      __pyx_L0:;
      __Pyx_XGIVEREF(__pyx_r);
      __Pyx_RefNannyFinishContext();
      return __pyx_r;
    }

     478:     cdef int64_t value

    +479:     value = read_int64(buffer, offset)

      __pyx_t_1 = __pyx_f_19amqp10_codec_faster_14message_faster_read_int64(__pyx_v_buffer, __pyx_v_offset); if (unlikely(__pyx_t_1 == ((int64_t)-1) && PyErr_Occurred())) __PYX_ERR(0, 479, __pyx_L1_error)
      __pyx_v_value = __pyx_t_1;

    +480:     cdef tm t = datetime_from_unix_milliseconds(value)

      __pyx_t_2 = __pyx_f_19amqp10_codec_faster_14message_faster_datetime_from_unix_milliseconds(__pyx_v_value); if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 480, __pyx_L1_error)
      __pyx_v_t = __pyx_t_2;

     481:

    +482:     return dt(year=t.tm_year + 1900, month=t.tm_mon + 1, day=t.tm_mday,

      __Pyx_XDECREF(__pyx_r);
      __Pyx_GetModuleGlobalName(__pyx_t_3, __pyx_n_s_dt); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 482, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_3);
      __pyx_t_4 = __Pyx_PyDict_NewPresized(7); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 482, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_4);
      __pyx_t_5 = __Pyx_PyInt_From_long((__pyx_v_t.tm_year + 0x76C)); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 482, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_5);
      if (PyDict_SetItem(__pyx_t_4, __pyx_n_s_year, __pyx_t_5) < 0) __PYX_ERR(0, 482, __pyx_L1_error)
      __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
      __pyx_t_5 = __Pyx_PyInt_From_long((__pyx_v_t.tm_mon + 1)); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 482, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_5);
      if (PyDict_SetItem(__pyx_t_4, __pyx_n_s_month, __pyx_t_5) < 0) __PYX_ERR(0, 482, __pyx_L1_error)
      __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
      __pyx_t_5 = __Pyx_PyInt_From_int(__pyx_v_t.tm_mday); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 482, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_5);
      if (PyDict_SetItem(__pyx_t_4, __pyx_n_s_day, __pyx_t_5) < 0) __PYX_ERR(0, 482, __pyx_L1_error)
      __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
    /* … */
      __pyx_t_6 = __Pyx_PyObject_Call(__pyx_t_3, __pyx_empty_tuple, __pyx_t_4); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 482, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_6);
      __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
      __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
      __pyx_r = __pyx_t_6;
      __pyx_t_6 = 0;
      goto __pyx_L0;

    +483:             hour=t.tm_hour, minute=t.tm_min, second=t.tm_sec, tzinfo=timezone.utc)

      __pyx_t_5 = __Pyx_PyInt_From_int(__pyx_v_t.tm_hour); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 483, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_5);
      if (PyDict_SetItem(__pyx_t_4, __pyx_n_s_hour, __pyx_t_5) < 0) __PYX_ERR(0, 482, __pyx_L1_error)
      __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
      __pyx_t_5 = __Pyx_PyInt_From_int(__pyx_v_t.tm_min); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 483, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_5);
      if (PyDict_SetItem(__pyx_t_4, __pyx_n_s_minute, __pyx_t_5) < 0) __PYX_ERR(0, 482, __pyx_L1_error)
      __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
      __pyx_t_5 = __Pyx_PyInt_From_int(__pyx_v_t.tm_sec); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 483, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_5);
      if (PyDict_SetItem(__pyx_t_4, __pyx_n_s_second, __pyx_t_5) < 0) __PYX_ERR(0, 482, __pyx_L1_error)
      __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
      __Pyx_GetModuleGlobalName(__pyx_t_5, __pyx_n_s_timezone); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 483, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_5);
      __pyx_t_6 = __Pyx_PyObject_GetAttrStr(__pyx_t_5, __pyx_n_s_utc); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 483, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_6);
      __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
      if (PyDict_SetItem(__pyx_t_4, __pyx_n_s_tzinfo, __pyx_t_6) < 0) __PYX_ERR(0, 482, __pyx_L1_error)
      __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;

     484:

     485:

    +486: cdef tm datetime_from_unix_milliseconds(time_t ms):

    static struct tm __pyx_f_19amqp10_codec_faster_14message_faster_datetime_from_unix_milliseconds(time_t __pyx_v_ms) {
      time_t __pyx_v_t;
      struct tm __pyx_v_date;
      struct tm __pyx_r;
    /* … */
      /* function exit code */
      __pyx_L0:;
      return __pyx_r;
    }

    +487:     cdef time_t t = <time_t> (ms / 1000)

      __pyx_v_t = ((time_t)(((double)__pyx_v_ms) / 1000.0));

     488:     cdef tm date

    +489:     gmtime_r(&t, &date)

      (void)(gmtime_r((&__pyx_v_t), (&__pyx_v_date)));

     490:

    +491:     return date

      __pyx_r = __pyx_v_date;
      goto __pyx_L0;

     492:

     493:

    +494: cdef unsigned char[:] write_data(unsigned char *msg_body, Py_ssize_t message_body_length):

    static __Pyx_memviewslice __pyx_f_19amqp10_codec_faster_14message_faster_write_data(unsigned char *__pyx_v_msg_body, Py_ssize_t __pyx_v_message_body_length) {
      Py_ssize_t __pyx_v_buffer_size;
      unsigned char *__pyx_v_buffer;
      Py_ssize_t __pyx_v_offset;
      __Pyx_memviewslice __pyx_r = { 0, 0, { 0 }, { 0 }, { 0 } };
    /* … */
      /* function exit code */
      __pyx_L1_error:;
      __Pyx_XDECREF(__pyx_t_3);
      __PYX_XCLEAR_MEMVIEW(&__pyx_t_4, 1);
      __pyx_r.data = NULL;
      __pyx_r.memview = NULL;
      __Pyx_AddTraceback("amqp10_codec_faster.message_faster.write_data", __pyx_clineno, __pyx_lineno, __pyx_filename);
      goto __pyx_L2;
      __pyx_L0:;
      if (unlikely(!__pyx_r.memview)) {
        PyErr_SetString(PyExc_TypeError, "Memoryview return value is not initialized");
      }
      __pyx_L2:;
      __Pyx_RefNannyFinishContext();
      return __pyx_r;
    }

    +495:     cdef Py_ssize_t buffer_size = calc_buffer_size(message_body_length)

      __pyx_t_1 = __pyx_f_19amqp10_codec_faster_14message_faster_calc_buffer_size(__pyx_v_message_body_length); if (unlikely(__pyx_t_1 == ((Py_ssize_t)-1) && PyErr_Occurred())) __PYX_ERR(0, 495, __pyx_L1_error)
      __pyx_v_buffer_size = __pyx_t_1;

    +496:     cdef unsigned char* buffer = <unsigned char *> malloc(buffer_size)

      __pyx_v_buffer = ((unsigned char *)malloc(__pyx_v_buffer_size));

    +497:     cdef Py_ssize_t offset = 0

      __pyx_v_offset = 0;

     498:

    +499:     try:

      /*try:*/ {

    +500:        write_descriptor(buffer, &offset)

        __pyx_f_19amqp10_codec_faster_14message_faster_write_descriptor(__pyx_v_buffer, (&__pyx_v_offset)); if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 500, __pyx_L4_error)

     501:

    +502:        if message_body_length <= 255:

        __pyx_t_2 = (__pyx_v_message_body_length <= 0xFF);
        if (__pyx_t_2) {
    /* … */
          goto __pyx_L6;
        }

    +503:            write_byte(buffer, &offset, 0xa0)

          __pyx_f_19amqp10_codec_faster_14message_faster_write_byte(__pyx_v_buffer, (&__pyx_v_offset), 0xa0); if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 503, __pyx_L4_error)

    +504:            write_byte(buffer, &offset, message_body_length)

          __pyx_f_19amqp10_codec_faster_14message_faster_write_byte(__pyx_v_buffer, (&__pyx_v_offset), __pyx_v_message_body_length); if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 504, __pyx_L4_error)

     505:        else:

    +506:            write_byte(buffer, &offset, 0xb0)

        /*else*/ {
          __pyx_f_19amqp10_codec_faster_14message_faster_write_byte(__pyx_v_buffer, (&__pyx_v_offset), 0xb0); if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 506, __pyx_L4_error)

    +507:            write_uint32(buffer, &offset, message_body_length)

          __pyx_f_19amqp10_codec_faster_14message_faster_write_uint32(__pyx_v_buffer, (&__pyx_v_offset), __pyx_v_message_body_length); if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 507, __pyx_L4_error)
        }
        __pyx_L6:;

     508:

    +509:        write_body(buffer, &offset, msg_body, message_body_length)

        __pyx_f_19amqp10_codec_faster_14message_faster_write_body(__pyx_v_buffer, (&__pyx_v_offset), __pyx_v_msg_body, __pyx_v_message_body_length); if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 509, __pyx_L4_error)

     510:

    +511:        return <bytearray>buffer[:offset]

        __pyx_t_3 = __Pyx_PyByteArray_FromStringAndSize(((const char*)__pyx_v_buffer) + 0, __pyx_v_offset - 0); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 511, __pyx_L4_error)
        __Pyx_GOTREF(__pyx_t_3);
        __pyx_t_4 = __Pyx_PyObject_to_MemoryviewSlice_ds_unsigned_char(__pyx_t_3, PyBUF_WRITABLE); if (unlikely(!__pyx_t_4.memview)) __PYX_ERR(0, 511, __pyx_L4_error)
        __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
        __pyx_r = __pyx_t_4;
        __pyx_t_4.memview = NULL;
        __pyx_t_4.data = NULL;
        goto __pyx_L3_return;
      }

     512:

     513:     finally:

    +514:        free(buffer)

      /*finally:*/ {
        __pyx_L4_error:;
        /*exception exit:*/{
          __Pyx_PyThreadState_declare
          __Pyx_PyThreadState_assign
          __pyx_t_8 = 0; __pyx_t_9 = 0; __pyx_t_10 = 0; __pyx_t_11 = 0; __pyx_t_12 = 0; __pyx_t_13 = 0;
          __Pyx_XDECREF(__pyx_t_3); __pyx_t_3 = 0;
          __PYX_XCLEAR_MEMVIEW(&__pyx_t_4, 1);
          __pyx_t_4.memview = NULL; __pyx_t_4.data = NULL;
          if (PY_MAJOR_VERSION >= 3) __Pyx_ExceptionSwap(&__pyx_t_11, &__pyx_t_12, &__pyx_t_13);
          if ((PY_MAJOR_VERSION < 3) || unlikely(__Pyx_GetException(&__pyx_t_8, &__pyx_t_9, &__pyx_t_10) < 0)) __Pyx_ErrFetch(&__pyx_t_8, &__pyx_t_9, &__pyx_t_10);
          __Pyx_XGOTREF(__pyx_t_8);
          __Pyx_XGOTREF(__pyx_t_9);
          __Pyx_XGOTREF(__pyx_t_10);
          __Pyx_XGOTREF(__pyx_t_11);
          __Pyx_XGOTREF(__pyx_t_12);
          __Pyx_XGOTREF(__pyx_t_13);
          __pyx_t_5 = __pyx_lineno; __pyx_t_6 = __pyx_clineno; __pyx_t_7 = __pyx_filename;
          {
            free(__pyx_v_buffer);
          }
          if (PY_MAJOR_VERSION >= 3) {
            __Pyx_XGIVEREF(__pyx_t_11);
            __Pyx_XGIVEREF(__pyx_t_12);
            __Pyx_XGIVEREF(__pyx_t_13);
            __Pyx_ExceptionReset(__pyx_t_11, __pyx_t_12, __pyx_t_13);
          }
          __Pyx_XGIVEREF(__pyx_t_8);
          __Pyx_XGIVEREF(__pyx_t_9);
          __Pyx_XGIVEREF(__pyx_t_10);
          __Pyx_ErrRestore(__pyx_t_8, __pyx_t_9, __pyx_t_10);
          __pyx_t_8 = 0; __pyx_t_9 = 0; __pyx_t_10 = 0; __pyx_t_11 = 0; __pyx_t_12 = 0; __pyx_t_13 = 0;
          __pyx_lineno = __pyx_t_5; __pyx_clineno = __pyx_t_6; __pyx_filename = __pyx_t_7;
          goto __pyx_L1_error;
        }
        __pyx_L3_return: {
          __pyx_t_14 = __pyx_r;
          free(__pyx_v_buffer);
          __pyx_r = __pyx_t_14;
          goto __pyx_L0;
        }
      }

     515:

    +516: cdef Py_ssize_t calc_buffer_size(Py_ssize_t message_body_length):

    static Py_ssize_t __pyx_f_19amqp10_codec_faster_14message_faster_calc_buffer_size(Py_ssize_t __pyx_v_message_body_length) {
      Py_ssize_t __pyx_v_result;
      Py_ssize_t __pyx_r;
    /* … */
      /* function exit code */
      __pyx_L0:;
      return __pyx_r;
    }

    +517:     cdef Py_ssize_t result = DESCRIBED_FORMAT_CODE_SIZE + sizeof(char)

      __pyx_v_result = (3 + (sizeof(char)));

     518:

    +519:     if message_body_length <= 255:

      __pyx_t_1 = (__pyx_v_message_body_length <= 0xFF);
      if (__pyx_t_1) {
    /* … */
        goto __pyx_L3;
      }

    +520:         result += sizeof(char)

        __pyx_v_result = (__pyx_v_result + (sizeof(char)));

     521:     else:

    +522:         result += sizeof(uint32_t)

      /*else*/ {
        __pyx_v_result = (__pyx_v_result + (sizeof(uint32_t)));
      }
      __pyx_L3:;

     523:

    +524:     result += message_body_length

      __pyx_v_result = (__pyx_v_result + __pyx_v_message_body_length);

     525:

    +526:     return result

      __pyx_r = __pyx_v_result;
      goto __pyx_L0;

     527:

     528:

    +529: cdef void write_descriptor(unsigned char* dest, Py_ssize_t* offset):

    static void __pyx_f_19amqp10_codec_faster_14message_faster_write_descriptor(unsigned char *__pyx_v_dest, Py_ssize_t *__pyx_v_offset) {
    /* … */
      /* function exit code */
    }

    +530:     dest[offset[0]] = 0x00

      (__pyx_v_dest[(__pyx_v_offset[0])]) = 0x00;

    +531:     dest[offset[0] + 1] = 0x53

      (__pyx_v_dest[((__pyx_v_offset[0]) + 1)]) = 0x53;

    +532:     dest[offset[0] + 2] = 0x75

      (__pyx_v_dest[((__pyx_v_offset[0]) + 2)]) = 0x75;

    +533:     offset[0] += DESCRIBED_FORMAT_CODE_SIZE

      __pyx_t_1 = 0;
      (__pyx_v_offset[__pyx_t_1]) = ((__pyx_v_offset[__pyx_t_1]) + 3);

     534:

     535:

    +536: cdef void write_byte(unsigned char* dest, Py_ssize_t* offset, unsigned char value):

    static void __pyx_f_19amqp10_codec_faster_14message_faster_write_byte(unsigned char *__pyx_v_dest, Py_ssize_t *__pyx_v_offset, unsigned char __pyx_v_value) {
    /* … */
      /* function exit code */
    }

    +537:     dest[offset[0]] = value

      (__pyx_v_dest[(__pyx_v_offset[0])]) = __pyx_v_value;

    +538:     offset[0] += 1

      __pyx_t_1 = 0;
      (__pyx_v_offset[__pyx_t_1]) = ((__pyx_v_offset[__pyx_t_1]) + 1);

     539:

    +540: cdef void write_body(unsigned char* dest, Py_ssize_t* offset, unsigned char* body, Py_ssize_t body_len):

    static void __pyx_f_19amqp10_codec_faster_14message_faster_write_body(unsigned char *__pyx_v_dest, Py_ssize_t *__pyx_v_offset, unsigned char *__pyx_v_body, Py_ssize_t __pyx_v_body_len) {
    /* … */
      /* function exit code */
      goto __pyx_L0;
      __pyx_L1_error:;
      __Pyx_XDECREF(__pyx_t_2);
      __Pyx_AddTraceback("amqp10_codec_faster.message_faster.write_body", __pyx_clineno, __pyx_lineno, __pyx_filename);
      __pyx_L0:;
      __Pyx_RefNannyFinishContext();
    }

     541:

    +542:     if dest == NULL:

      __pyx_t_1 = (__pyx_v_dest == NULL);
      if (unlikely(__pyx_t_1)) {
    /* … */
      }

    +543:         raise MemoryError("Memory allocation failed")

        __pyx_t_2 = __Pyx_PyObject_Call(__pyx_builtin_MemoryError, __pyx_tuple__10, NULL); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 543, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_2);
        __Pyx_Raise(__pyx_t_2, 0, 0, 0);
        __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
        __PYX_ERR(0, 543, __pyx_L1_error)
    /* … */
      __pyx_tuple__10 = PyTuple_Pack(1, __pyx_kp_u_Memory_allocation_failed); if (unlikely(!__pyx_tuple__10)) __PYX_ERR(0, 543, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_tuple__10);
      __Pyx_GIVEREF(__pyx_tuple__10);

     544:

    +545:     memcpy(dest + offset[0], body, body_len)

      (void)(memcpy((__pyx_v_dest + (__pyx_v_offset[0])), __pyx_v_body, __pyx_v_body_len));

    +546:     offset[0] += body_len

      __pyx_t_3 = 0;
      (__pyx_v_offset[__pyx_t_3]) = ((__pyx_v_offset[__pyx_t_3]) + __pyx_v_body_len);

     547:

    +548: cdef void write_uint32(unsigned char* dest, Py_ssize_t* offset, Py_ssize_t body_len):

    static void __pyx_f_19amqp10_codec_faster_14message_faster_write_uint32(unsigned char *__pyx_v_dest, Py_ssize_t *__pyx_v_offset, Py_ssize_t __pyx_v_body_len) {
    /* … */
      /* function exit code */
    }

    +549:     dest[offset[0]] = (body_len >> 24) & 0xFF

      (__pyx_v_dest[(__pyx_v_offset[0])]) = ((__pyx_v_body_len >> 24) & 0xFF);

    +550:     dest[offset[0] + 1] = (body_len >> 16) & 0xFF

      (__pyx_v_dest[((__pyx_v_offset[0]) + 1)]) = ((__pyx_v_body_len >> 16) & 0xFF);

    +551:     dest[offset[0] + 2] = (body_len >> 8) & 0xFF

      (__pyx_v_dest[((__pyx_v_offset[0]) + 2)]) = ((__pyx_v_body_len >> 8) & 0xFF);

    +552:     dest[offset[0] + 3] = body_len & 0xFF

      (__pyx_v_dest[((__pyx_v_offset[0]) + 3)]) = (__pyx_v_body_len & 0xFF);

    +553:     offset[0] += sizeof(uint32_t)

      __pyx_t_1 = 0;
      (__pyx_v_offset[__pyx_t_1]) = ((__pyx_v_offset[__pyx_t_1]) + (sizeof(uint32_t)));